using System;
using System.Web.UI;
using System.Web.UI.Design;
using System.Web.UI.WebControls;
using System.ComponentModel;
using System.ComponentModel.Design;
using RepPP.Toolkit;
using RepPP;

namespace RepPP.Toolkit.Web {
    //********************************************************************************
    //
    /// <summary>
    /// Implement a TextBox control which is attached to the Rep++ field meta-data
    /// </summary>
    //
    //********************************************************************************
	[ToolboxData("<{0}:FldTextBox runat=server></{0}:FldTextBox>")]
	[DefaultProperty("Text")]
	public class FldTextBox : System.Web.UI.WebControls.TextBox, IFldEditableControl {
        /// <summary>Field validator attached to this control</summary>
	    protected FldValidator          m_fldValidator;
	    /// <summary>Field control utility class</summary>
	    protected FldControlUtil        m_fldControlUtil;

        //********************************************************************************
        //
		/// <summary>
		/// ctor:               Class constructor
		/// </summary>
		//
        //********************************************************************************
		public FldTextBox() {
		    m_fldControlUtil    = new FldControlUtil(this, true);
		    ValidatorPosition   = FldValidator.AutoPos.After;
		}

        //********************************************************************************
        //
		/// <summary>
		/// Dispose:            Dispose the control
		/// </summary>
		//
        //********************************************************************************
        public override void Dispose() {
            if (m_fldValidator != null) {
                m_fldValidator.Dispose();
            }
            if (m_fldControlUtil != null) {
                m_fldControlUtil.Dispose();
            }
            base.Dispose();
        }

        //********************************************************************************
        //
		/// <summary>
		/// RepPPReInit:        Called when Rep++ is reinitialized
		/// </summary>
		//
        //********************************************************************************
        public void RepPPReInit() {
        }

        //********************************************************************************
        //
		/// <summary>
		/// RepPPReset:         Called when Rep++ is reset in design mode
		/// </summary>
		//
        //********************************************************************************
        public void RepPPReset() {
        }

        //********************************************************************************
        //
        /// <summary>
        /// TriggerComponentChange:     Trigger the event indicating a component property has changed
        /// </summary>
        //
        //********************************************************************************
        public virtual void TriggerComponentChange() {
            if (m_fldControlUtil != null) {
                m_fldControlUtil.TriggerComponentChange();
            }
        }

        //********************************************************************************
        //
        /// <summary>
        /// FieldFullName:              Full name of the field attached to the TextBox
        /// </summary>
        //
        //********************************************************************************
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Visible)]
        [PersistenceMode(PersistenceMode.Attribute)]
        [Editor(typeof(FldControlUtil.FldControlEditor), typeof(System.Drawing.Design.UITypeEditor))]
        [Browsable(true)]
        [Bindable(true)]
        [Category("Data")]
        [Description("Full name of the field attached to the TextBox")]
		public FldFullName FieldFullName {
		    get {
		        return(m_fldControlUtil.FieldFullName);
		    }
		    set {
		        m_fldControlUtil.FieldFullName = value;
		    }
		}

        //********************************************************************************
        //
        /// <summary>
        /// Application:            Gets the Rep++ application
        /// </summary>
        //
        //********************************************************************************
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Browsable(false)]
		public Application Application {
		    get {
		        return(m_fldControlUtil.Application);
		    }
		}

        //********************************************************************************
        //
        /// <summary>
        /// Field:              Field attached to the TextBox
        /// </summary>
        //
        //********************************************************************************
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Browsable(false)]
		public Field Field {
		    get {
		        return(m_fldControlUtil.Field);
		    }
		    set {
		        m_fldControlUtil.Field = value;
		    }
		}

        //********************************************************************************
        //
        /// <summary>
        /// ID:         ID of the control
        /// </summary>
        //
        //********************************************************************************
        public override string ID {
            get {
                return base.ID;
            }
            set {
                base.ID = value;
                if (m_fldValidator != null) {
                    m_fldValidator.ControlToValidate = value;
                }
            }
        }

        //********************************************************************************
        //
        /// <summary>
        /// ValidatorPosition:      Position of the automatic validator
        /// </summary>
        //
        //********************************************************************************
        [Category("Layout")]
        [Bindable(true)]
        [DefaultValue(FldValidator.AutoPos.After)]
        [Description("Position of the automatic validator")]
        public virtual FldValidator.AutoPos ValidatorPosition {
            get {
                return((m_fldValidator != null) ? m_fldValidator.AutoPosition : FldValidator.AutoPos.None);
            }
            set {
                if (value == FldValidator.AutoPos.None) {
                    if (m_fldValidator != null) {
                        m_fldValidator.Dispose();
                        m_fldValidator = null;
                    }
                } else {
                    if (m_fldValidator == null) {
                        m_fldValidator                   = new FldValidator(this);
                        m_fldValidator.ControlToValidate = ID;
                    }
                    m_fldValidator.AutoPosition = value;
                }
            }
        }

        //********************************************************************************
        //
        /// <summary>
        /// AttachedLine:             Attached group instance line
        /// </summary>
        //
        //********************************************************************************
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Browsable(false)]
        [Bindable(false)]
        [DefaultValue(-1)]
        [Description("Attached group instance line index")]
		public virtual int AttachedLine {
            get {
                int    iRetVal;
                object  obj;
                
                obj = ViewState["AttachedLine"];
                if (obj != null) {
                    iRetVal = (int)obj;
                } else {
                    iRetVal = -1;
                }
                return(iRetVal);
            }
            set {
                ViewState["AttachedLine"] = value;
            }
		}

        //********************************************************************************
        //
        /// <summary>
        /// Render:                 Render the control
        /// </summary>
        /// <param name="writer">   HTML writer</param>
        //
        //********************************************************************************
        protected override void Render(HtmlTextWriter writer) {
            if (Visible) {
                base.Render(writer);
                if (m_fldValidator != null) {
                    if (Field != null) {
                        m_fldValidator.InitFromFather(this);
                        m_fldValidator.RenderControl(writer);
                    } else {
                        m_fldValidator.Dispose();
                        m_fldValidator = null;
                    }
                }
            }
        }

        //********************************************************************************
        //
        /// <summary>
        /// Text:               Text of the TextBox
        /// </summary>
        //
        //********************************************************************************
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Browsable(false)]
        [Bindable(false)]
        public override string Text {
            get {
                string          strRetVal;
                Field           fld;
                bool            bIsDesignMode;

                bIsDesignMode   = m_fldControlUtil.IsDesignMode;
                fld             = m_fldControlUtil.Field;
                if (fld == null) {
                    if (bIsDesignMode) {
                        strRetVal = m_fldControlUtil.FieldFullName.GroupName + "." +
                                    m_fldControlUtil.FieldFullName.FieldName;
                    } else {
                        strRetVal = "";
                    }
                } else {
                    if (bIsDesignMode) {
                        strRetVal = fld.Group.Name + "." + fld.Name;
                    } else if (AttachedLine > -1) {
                        strRetVal = fld.Group.ActiveGroupInstance.GetFieldValue(fld, AttachedLine, true);
                    } else {
                        strRetVal = fld.ExtValue;
                    }
                    if (strRetVal != String.Empty                &&
                        (fld.Type == FieldType.sdFieldHexa       || 
                         fld.Type == FieldType.sdFieldMoney      || 
                         fld.Type == FieldType.sdFieldNumeric    || 
                         fld.Type == FieldType.sdFieldNumericDec || 
                         fld.Type == FieldType.sdFieldPercentage || 
                         fld.Type == FieldType.sdFieldPercentageDec)){
                        strRetVal = strRetVal.TrimStart();
                    }
                }
                return(strRetVal);
            }
            set {
                Field           fld;
                
                fld = m_fldControlUtil.Field;
                if (fld != null) {
                    if (AttachedLine > -1) {
                        fld.Group.ActiveGroupInstance.SetFieldValue(fld, 
                                                                    AttachedLine,
                                                                    true,
                                                                    RepPP.SetFieldOpt.sdSetNormal,
                                                                    value);
                    } else {
                        fld.ExtValue = value;
                    }
                }
            }
        }

        //********************************************************************************
        //
        /// <summary>
        /// ReadOnly:       Determines if the control is read-only
        /// </summary>
        //
        //********************************************************************************
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Browsable(false)]
        [Bindable(false)]
        public override bool ReadOnly {
            get {
                bool     bRetVal;
                Field    fld;
                object  obj;
                
                obj = ViewState["ReadOnly"];
                if (obj != null) {
                    bRetVal = (bool)obj;
                } else {
                    bRetVal = false;
                }
                if (!bRetVal) {
                    fld = m_fldControlUtil.Field;
                    bRetVal = (fld == null) ? false : !fld.IsSelectable;
                }
                return(bRetVal);
            }
            set {
                ViewState["ReadOnly"] = value;
            }
        }

        //********************************************************************************
        //
        /// <summary>
        /// Visible:        Determines if the control is visible
        /// </summary>
        //
        //********************************************************************************
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [PersistenceMode(PersistenceMode.InnerProperty)]
        [Browsable(false)]
        [Bindable(false)]
        public override bool Visible {
            get {
                bool     bRetVal;
                Field    fld;
                
                fld = m_fldControlUtil.Field;
                bRetVal = (fld == null || m_fldControlUtil.IsDesignMode) ? true : fld.IsVisible;
                return(bRetVal);
            }
            set {
                throw new System.NotSupportedException();
            }
        }

        //********************************************************************************
        //
        /// <summary>
        /// MaxLength:      Determines the maximum length of the value
        /// </summary>
        //
        //********************************************************************************
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Browsable(false)]
        [Bindable(false)]
        public override int MaxLength {
            get {
                int     iRetVal;
                Field   fld;
                
                fld     = m_fldControlUtil.Field;
                iRetVal = (fld == null) ? 16 : fld.MaxSize;
                return(iRetVal);
            }
            set {
                throw new System.NotSupportedException();
            }
        }

        //********************************************************************************
        //
        /// <summary>
        /// TextMode:       Determine the type of TextBox
        /// </summary>
        //
        //********************************************************************************
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Browsable(false)]
        [Bindable(false)]
        public override TextBoxMode TextMode {
            get {
                TextBoxMode     eRetVal;
                Field           fld;
                
                fld     = m_fldControlUtil.Field;
                if (fld == null) {
                    eRetVal = TextBoxMode.SingleLine;
                } else {
                    if (fld.Type == FieldType.sdFieldMemo) {
                        eRetVal = TextBoxMode.MultiLine;
                    } else {
                        eRetVal = (fld.IsPassword) ? TextBoxMode.Password : TextBoxMode.SingleLine;
                    }
                }
                return(eRetVal);
            }
            set {
                throw new System.NotSupportedException();
            }
        }

        //********************************************************************************
        //
        /// <summary>
        /// AddMaskAttributes:          Adds the required attributes to implement an input mask
        /// </summary>
        /// <param name="writer">       HTML writer</param>
        //
        //********************************************************************************
        private void AddMaskAttributes(HtmlTextWriter writer) {
            string strFldName;

            if (ValidatorPosition == FldValidator.AutoPos.None) {
                ValidatorPosition = FldValidator.AutoPos.After;
            }
            strFldName = FieldFullName.GroupName + "_" + FieldFullName.FieldName;
            writer.AddAttribute("onkeydown",    "RepPP_OnKeyDown_"          + strFldName + "(event, this)");
            writer.AddAttribute("onkeypress",   "RepPP_OnKeyPress_"         + strFldName + "(event, this)");
            writer.AddAttribute("onclick",      "RepPP_OnClick_"            + strFldName + "(event, this)");
            writer.AddAttribute("onfocus",      "RepPP_OnFocus_"            + strFldName + "(this)");
            writer.AddAttribute("ondrag",       "return RepPP_OnIgnore_"    + strFldName + "()");
            writer.AddAttribute("ondrop",       "return RepPP_OnIgnore_"    + strFldName + "()");
            writer.AddAttribute("oncut",        "return RepPP_OnIgnore_"    + strFldName + "()");
            writer.AddAttribute("onpaste",      "return RepPP_OnIgnore_"    + strFldName + "()");
            writer.AddAttribute("onblur",       "RepPP_OnBlur_"             + strFldName + "(this)");
        }

        //********************************************************************************
        //
        /// <summary>
        /// AddAttributesToRender:      Add the 'Size' if we need it. Might add attributes
        ///                             for input mask.
        /// </summary>
        /// <param name="writer">       HTML writer</param>
        //
        //********************************************************************************
        protected override void AddAttributesToRender(HtmlTextWriter writer) {
            base.AddAttributesToRender(writer);
            if (Width.IsEmpty) {
                writer.AddAttribute(HtmlTextWriterAttribute.Size,
                                    GetAutoSize().ToString());
            }
            if (!m_fldControlUtil.IsDesignMode &&
                Field != null && 
                Field.Type == FieldType.sdFieldFormatString) {
                AddMaskAttributes(writer);
            }
        }

        //********************************************************************************
        //
        /// <summary>
        /// GetAutoSize:                Compute the automatic size
        /// </summary>
        /// <returns>
        /// Automatic size
        /// </returns>
        //
        //********************************************************************************
        protected virtual int GetAutoSize() {
            int     iRetVal;
            Field   fld;
                
            fld = m_fldControlUtil.Field;
            if (fld == null) {
                iRetVal = 32;
            } else {
                iRetVal = fld.MaxSize;
            }
            iRetVal = Math.Min(MaxAutoSize, iRetVal) + 4;
            return(iRetVal);
        }

        //********************************************************************************
        //
        /// <summary>
        /// MaxControlSize:         Maximum size for automatic sizing
        /// </summary>
        //
        //********************************************************************************
        [Category("Layout")]
        [Bindable(true)]
        [DefaultValue(40)]
        [Description("Maximum size for automatically size control")]
        public virtual int MaxAutoSize {
            get {
                int     iRetVal;
                object  objAuto;
                
                objAuto = ViewState["MaxAutoSize"];
                if (objAuto != null) {
                    iRetVal = (int)objAuto;
                } else {
                    iRetVal = 40;
                }
                return(iRetVal);
            }
            set {
                ViewState["MaxAutoSize"] = value;
            }
        }
    } // Class
} // Namespace
