using System;
using System.Collections;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Windows.Forms;

namespace RepPP.Toolkit.Window {

    //*********************************************************	    
    //
	/// <summary>
	/// Implement a wrapper around the SQL Blob control
	/// </summary>
    //
    //*********************************************************	    
	public class BlobCtl : System.Windows.Forms.UserControl	{
	    // SQL-Design Blob control message
	    private enum SDC : uint {
	        USER               = Win32.WM.USER + 1000,
            BLOB_GETHANDLE     = USER + 0,
            BLOB_SETHANDLE     = USER + 1,
            BLOB_GETSTYLE      = USER + 2,
            BLOB_SETSTYLE      = USER + 3,
            BLOB_GETUSERFLAG   = USER + 4,
            BLOB_SETUSERFLAG   = USER + 5,
        };


		private System.ComponentModel.Container components = null;
		private IntPtr                          m_wndBlobCtl;       // Child window control

        //*********************************************************	    
        //
        /// <summary>
        /// ctor:                           Class constructor
        /// </summary>
        //
        //*********************************************************	    
		public BlobCtl() {
			InitializeComponent();
			m_wndBlobCtl = (IntPtr)0;
			HandleCreated += new EventHandler(OnHandleCreated);
			HandleDestroyed += new EventHandler(OnHandleDestroyed);
		}

        //*********************************************************	    
        //
        /// <summary>
        /// Dispose:                         Dispose the control
        /// </summary>
        /// <param name="bDisposing">       true if dispose, false if GC</param>
        //
        //*********************************************************	    
        protected override void Dispose(bool bDisposing) {
            if (bDisposing) {
                //
            }
            base.Dispose(bDisposing);
        }

        //*********************************************************	    
        //
        /// <summary>
        /// CreatePictCtlv:                  Creates the child control
        /// </summary>
        //
        //*********************************************************	    
        private void CreatePictCtlv() {
            System.Drawing.Rectangle    rectClient;
            IntPtr                      inst;
            
            rectClient   = ClientRectangle;
            inst         = Win32.User32.GetWindowLong(Handle, Win32.GWL.HINSTANCE);
            m_wndBlobCtl = Win32.User32.CreateWindowEx(Win32.WS_EX.NONE,
                                                       "BLOBCTL",
                                                       "",
                                                       Win32.WS.CHILD | Win32.WS.VISIBLE | Win32.WS.BORDER,
                                                       0,
                                                       0,
                                                       rectClient.Width,
                                                       rectClient.Height,
                                                       Handle,
                                                       100,
                                                       (IntPtr)0, //inst,
                                                       null);
        }

        //*********************************************************	    
        //
        /// <summary>
        /// GetBlobFromHandle:      Find the blob object from its handle
        /// </summary>
        /// <param name="iHandle">  Blob handle</param>
        /// <returns>
        /// Blob object or null if not found
        /// </returns>
        //
        //*********************************************************	    
        private RepPP.Blob GetBlobFromHandle(int iHandle) {
            RepPP.Blob          blobRetVal = null;
            RepPP.IApplication  app;
            
            app = RepPP.Application.GetApplication();
            foreach (RepPP.Blob blob in app.Blobs) {
                if (blob.Handle == iHandle) {
                    blobRetVal = blob;
                    break;
                }
            }
            return(blobRetVal);
        }

        //*********************************************************	    
        //
        /// <summary>
        /// Blob:                   Gets/set the blob handle
        /// </summary>
        //
        //*********************************************************	    
        public RepPP.Blob Blob {
            get {
                RepPP.Blob  blobRetVal = null;
                IntPtr      hnd;
                
                hnd = (IntPtr)((m_wndBlobCtl == (IntPtr)0) ? 0 : Win32.User32.SendMessage(m_wndBlobCtl,
                                                                                          (int)SDC.BLOB_GETHANDLE,
                                                                                          0,
                                                                                          0));
                if (hnd != (IntPtr)0) {
                    blobRetVal = GetBlobFromHandle((int)hnd);
                }
                return(blobRetVal);
            }
            set {
                if (m_wndBlobCtl != (IntPtr)0) {
                    Win32.User32.SendMessage(m_wndBlobCtl,
                                             (int)SDC.BLOB_SETHANDLE,
                                             0,
                                             (value == null) ? 0 : (int)value.Handle);
                }
            }
        }

        //*********************************************************	    
        //
        /// <summary>
        ///  Style:             The blob control style
        /// </summary>
        //
        //*********************************************************	    
        public int Style {
            get {
                int     iStyle = 0;
                
                if (m_wndBlobCtl != (IntPtr)0) {
                    iStyle = Win32.User32.SendMessage(m_wndBlobCtl,
                                                      (int)SDC.BLOB_GETSTYLE,
                                                      0,
                                                      0);
                }
                return(iStyle);
            }
            set {
                if (m_wndBlobCtl != (IntPtr)0) {
                    Win32.User32.SendMessage(m_wndBlobCtl,
                                             (int)SDC.BLOB_SETSTYLE,
                                             0,
                                             value);
                }
            }
        }

        //*********************************************************	    
        //
        /// <summary>
        /// OnHandleCreated:        Called when the control handle is created
        /// </summary>
        /// <param name="sender">   Sender object</param>
        /// <param name="e">        Event parameter</param>
        //
        //*********************************************************	    
        private void OnHandleCreated(object sender, EventArgs e) {
            CreatePictCtlv();
        }

        //*********************************************************	    
        //
        /// <summary>
        /// OnHandleDestroyed:      Called when the control handle is destroyed
        /// </summary>
        /// <param name="sender">   Sender object</param>
        /// <param name="e">        Event parameter</param>
        //
        //*********************************************************	    
        private void OnHandleDestroyed(object sender, EventArgs e) {
            m_wndBlobCtl = (IntPtr)0;
        }

		#region Component Designer generated code
		/// <summary> 
		/// Required method for Designer support - do not modify 
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			components = new System.ComponentModel.Container();
		}
        #endregion

    }
}
