//**********************************************************************
//
//    Module:             ASPNetConnect.cs
//
//    Author:             Maher Najah
//    Version:            1.00.00
//    Creation:           2004-10-18
//    Modification:       2004-10-18
//
//    Description:        Implementing Rep++ ASP .Net Web Wizard entry object
//
//**********************************************************************
using System.Runtime.InteropServices;
using EnvDTE;
using System.Windows.Forms;
using System;
using RepPP.VSNetWizard;
#if VC8
//using System.Collections.Generic;
//using Microsoft.VisualStudio.TemplateWizard;
#endif

namespace RepPP.VSNetWizard.ASPNet {
#if VC8
	internal class Connect : ConnectBase {
        //**********************************************************************
        //
        /// <summary>
        /// CreateMainForm:                     Create main form. Method factory
        /// </summary>
        /// <param name="dte">                  Visual studio object</param>
        /// <param name="strProjectName">       Project name</param>
        /// <param name="strProjectDirName">    Project directory name</param>
        /// <param name="eLang">                Program language</param>
        /// <param name="eGenMode">             Wizard mode(item or application)</param>
        /// <returns>
        /// Wizard main form
        /// </returns>
        //       
        //**********************************************************************        
        internal override frmMainBase CreateMainForm(EnvDTE.DTE        dte,
                                                     string            strProjectName,
                                                     string            strProjectDirName,
                                                     ProgramLanguageE  eLang,
                                                     GenerationModeE   eGenMode) {
            string  strRealProjectName;
            string  strEndNameChar;

            // The web project name must ends with "/" if it's a http web site and with "\"
            // if it'a a file sytem web site
            if (strProjectDirName.ToLower().StartsWith("http://") || strProjectDirName.ToLower().StartsWith("ftp://")) {
                strEndNameChar = "/";
            } else {
                strEndNameChar = "\\";
            }
            if (strProjectDirName[strProjectDirName.Length - 1] == strEndNameChar[0]) {
                strRealProjectName = strProjectDirName;
            } else {
                strRealProjectName = strProjectDirName + strEndNameChar;
            }
            return(new frmMain(dte,
                               strRealProjectName,
                               strProjectDirName,
                               eLang,
                               eGenMode));
        }
    }
#else
	/// <summary>
	/// Connect to visual studio
	/// </summary>
    [GuidAttribute(Global.ASPNET_WIZARD_GUID), ProgIdAttribute(Global.ASPNET_WIZARD_PRGID)]
    public class Connect : EnvDTE.IDTWizard	{

        //******************************************************************
        //
        /// <summary>
        /// ctor:                       Class constructor
        /// </summary>
        //
        //******************************************************************
		public Connect() {
		}
        //**********************************************************************
        //
        /// <summary>
        /// Execute:        Occurs when a wizard is launched from either the Add Item or the New 
        ///                 Project dialog box
        /// </summary>
        /// <param name="vsApp">  Pointer to DTE</param>
        /// <param name="hwndOwner">    The hWnd handle for the parent of the wizard's window</param>
        /// <param name="ContextParams">An array of context parameters</param>
        /// <param name="CustomParams"> An array  of user defined parameters</param>
        /// <param name="retval">       The results of the wizard</param>
        //       
        //**********************************************************************
        public void Execute(object          vsApp,
                            int             hwndOwner,
                            ref object[]    ContextParams,
                            ref object[]    CustomParams,
                            ref             wizardResult retval) {
            frmMain             frm;
            GenerationModeE     eGenType;
            ProgramLanguageE    eLang;
            string              strParam;

            strParam = CustomParams[0].ToString();
            if (strParam.IndexOf("LANGUAGE = VB") != -1) {
                eLang = ProgramLanguageE.sdVisualBasic;
            } else {
                eLang = ProgramLanguageE.sdCSharp;
            }
            strParam = CustomParams[1].ToString();
            if (strParam.IndexOf("TYPE = APPLICATION") != -1) {
                eGenType = GenerationModeE.sdApplication;
            } else {
                eGenType = GenerationModeE.sdItem;
            }
            if (eGenType == GenerationModeE.sdApplication) {
                frm = new frmMain(vsApp as DTE, 
                                  ContextParams[1].ToString(), 
                                  ContextParams[2].ToString(), 
                                  eLang, 
                                  eGenType);
            } else {
                frm = new frmMain(vsApp as DTE,
                                  ContextParams[1].ToString(),
                                  ContextParams[3].ToString(),
                                  eLang,
                                  eGenType);
            }
            using (frm) {
                frm.ShowDialog();
            }
        }
	} // class Connect
#endif
} // namespace
