//**********************************************************************
//
//   Module:             Utility.cs
//
//   Author:             Maher Najah
//   Version:            1.00.00
//   Creation:           2004-10-18
//   Modification:       2004-10-18
//
//   Description:        Utilities
//
//**********************************************************************
using System;
using System.Collections;
using System.Xml;
using System.Resources;
using Microsoft.Win32;
using System.IO;
using System.Windows.Forms;
using sdfwwebcsnet;
using RepPP.Toolkit;
using EnvDTE;

namespace RepPP.VSNetWizard {
    /// <summary>
    /// Utilty class
    /// </summary>
    internal class Utility {
        //******************************************************************
        //
        /// <summary>
        /// ReplaceFileModeE:   Define the replacing mode for existing files
        /// </summary>
        //
        //******************************************************************
        public enum ReplaceFileModeE {
            /// <summary>Ask before replacing an existing file</summary>
            sdAskBeforeReplace      = 1,
            /// <summary>Replace existing files without asking</summary>
            sdReplaceWithoutAsk     = 2,
            /// <summary>Don't replace existing files</summary>
            sdDoNotReplace          = 3
        }

        //******************************************************************
        //
        /// <summary>
        /// GenTypedInstTypeE:      Generation of typed instances classes type
        /// </summary>
        //
        //******************************************************************
        public enum GenTypedInstTypeE {
            /// <summary>Do not generate typed instances classes</summary>
            None                    = 0,
            /// <summary>Generate only typed instances</summary>
            TypedInstOnly           = 1,
            /// <summary>Generate typed instances with web services adapters</summary>
            TypedInstAndWSAdapter   = 2
        }
        /// <summary>Typed instances folder name</summary>
        public static string TYPED_INST_FOLDER_NAME = "TypedInstances";

        //*********************************************************     
        //
        /// <summary>
        /// FindProjectItem:                Find a project item in a project
        /// </summary>
        /// <param name="projectItems">     Project items collection</param>
        /// <param name="strItemName">      Project item name</param>
        /// <returns>
        /// Project item or null if it doesn't exist
        /// </returns>
        //  
        //*********************************************************     
        public static EnvDTE.ProjectItem FindProjectItem(EnvDTE.ProjectItems projectItems, string strItemName) {
            EnvDTE.ProjectItem projectItem = null;

            foreach (EnvDTE.ProjectItem prjItem in projectItems) {
                if (prjItem.Name == strItemName) {
                    projectItem = prjItem;
                    break;
                } else if (prjItem.ProjectItems != null && prjItem.ProjectItems.Count > 0) {
                    projectItem = FindProjectItem(prjItem.ProjectItems, strItemName);
                    if (projectItem != null) {
                        break;
                    }
                }
            }
            return(projectItem);
        }

        //*********************************************************     
        //
        /// <summary>
        /// FindProjectItem:            Find a project item in a project
        /// </summary>
        /// <param name="project">      Visual studio project</param>
        /// <param name="strItemName">  Project item name</param>
        /// <returns>
        /// Project item or null if it doesn't exist
        /// </returns>
        //  
        //*********************************************************     
        public static EnvDTE.ProjectItem FindProjectItem(EnvDTE.Project project, string strItemName) {
            return(FindProjectItem(project.ProjectItems, strItemName));
        }

        //*********************************************************     
        //
        /// <summary>
        /// DeleteProjectItem:              Delete a project item from a project
        /// </summary>
        /// <param name="project">          Visual studio project</param>
        /// <param name="strItemName">      Project item namee</param>
        //  
        //*********************************************************     
        public static void DeleteProjectItem(EnvDTE.Project project, string strItemName) {
            EnvDTE.ProjectItem prjItem;

            prjItem = FindProjectItem(project, strItemName);
            if (prjItem != null) {
                prjItem.Delete();
            }
        }

        //*********************************************************     
        //
        /// <summary>
        /// CreateWebProject:               Create a new visual studio web project
        /// </summary>
        /// <param name="vsApp">            Visual studio application</param>
        /// <param name="eLang">            Programming language</param>
        /// <param name="strPrjName">       Project name</param>
        /// <param name="strPrjFullName">   Project full name</param>
        /// <returns>
        /// The created project
        /// </returns>
        //  
        //*********************************************************     
        public static EnvDTE.Project CreateWebProject(EnvDTE.DTE        vsApp,
                                                      ProgramLanguageE  eLang,
                                                      ref string        strPrjName,
                                                      ref string        strPrjFullName) {
            string              strTemplate;
            EnvDTE.Project      project;
            int                 iIndex;
            object[]            parameters = {"{0F90E1D0-4999-11D1-B6D1-00A0C90F2744}", // WizardType
                                              strPrjName,                               // ProjectName
                                              strPrjFullName,                           // LocalDirectory
                                              "",                                       // InstallationDirectory 
                                              false,                                    // FExclusive
                                              "",                                       // SolutionName
                                              false};                                   // Silent

#if VC8
            EnvDTE80.DTE2       dte2;
            EnvDTE80.Solution2  soln2;

            dte2  = vsApp as EnvDTE80.DTE2;
            soln2 = dte2.Solution as EnvDTE80.Solution2;
#endif
            switch (eLang) {
            case ProgramLanguageE.sdCSharp:
#if VC8
                strTemplate = soln2.GetProjectTemplate("WebApplication.zip", "Web\\CSharp");
#else
                strTemplate = vsApp.Solution.get_TemplatePath(VSLangProj.PrjKind.prjKindCSharpProject) + "CSharpWebApp.vsz";
#endif
                break;
            case ProgramLanguageE.sdVisualBasic:
#if VC8
                strTemplate = soln2.GetProjectTemplate("WebApplication.zip", "Web\\VisualBasic");
#else
                strTemplate = vsApp.Solution.get_TemplatePath(VSLangProj.PrjKind.prjKindVBProject) + "WebApplication.vsz";
#endif
                break;
            default:
                strTemplate = String.Empty;
                break;
            }
            iIndex  = vsApp.Solution.Projects.Count;
            vsApp.LaunchWizard(strTemplate, ref parameters);
            // Reset the project name variable because it could be changed by AddFromTemplate
            // if the directory name specified is already exist
            project        = vsApp.Solution.Item(iIndex + 1); // the item method is 1 base !
            strPrjName     = project.Name;
            strPrjFullName = project.FullName;
#if VC8
            DeleteProjectItem(project, "Default.aspx");
#else
            DeleteProjectItem(project, "WebForm1.aspx");
#endif

            return(project);
        }

        //*********************************************************     
        //
        /// <summary>
        /// CreateWindowsProject:           Create a new visual studio windows project
        /// </summary>
        /// <param name="vsApp">            Visual studio application</param>
        /// <param name="eLang">            Programming language</param>
        /// <param name="strPrjName">       Project name</param>
        /// <param name="strPrjFullName">   Project full name</param>
        /// <returns>
        /// The created project
        /// </returns>
        //  
        //*********************************************************     
        public static EnvDTE.Project CreateWindowsProject(EnvDTE.DTE        vsApp,
                                                          ProgramLanguageE  eLang,
                                                          ref string        strPrjName,
                                                          ref string        strPrjFullName) {
            string              strTemplate;
            EnvDTE.Project      project;
            int                 iIndex;
            string              strExtension = "";
            object[]            parameters   = {"{0F90E1D0-4999-11D1-B6D1-00A0C90F2744}",  // WizardType
                                                 strPrjName,                               // ProjectName
                                                 strPrjFullName,                           // LocalDirectory
                                                 "",                                       // InstallationDirectory 
                                                 false,                                    // FExclusive
                                                 "",                                       // SolutionName
                                                 false};                                   // Silent
#if VC8
            EnvDTE80.DTE2       dte2;
            EnvDTE80.Solution2  soln2;

            dte2  = vsApp as EnvDTE80.DTE2;
            soln2 = dte2.Solution as EnvDTE80.Solution2;
#endif
            switch (eLang) {
            case ProgramLanguageE.sdCSharp:
                strExtension = ".cs";
#if VC8
                strTemplate = soln2.GetProjectTemplate("WindowsApplication.zip", "CSharp");
#else
                strTemplate  = vsApp.Solution.get_TemplatePath(VSLangProj.PrjKind.prjKindCSharpProject) + "CSharpEXE.vsz";
#endif
                break;
            case ProgramLanguageE.sdVisualBasic:
                strExtension = ".vb";
#if VC8
                strTemplate = soln2.GetProjectTemplate("WindowsApplication.zip", "VisualBasic");
#else
                strTemplate  = vsApp.Solution.get_TemplatePath(VSLangProj.PrjKind.prjKindVBProject) + "WindowsApplication.vsz";
#endif
                break;
            default:
                strTemplate = String.Empty;
                break;
            }
            iIndex  = vsApp.Solution.Projects.Count;
            vsApp.LaunchWizard(strTemplate, ref parameters);
            // Reset the project name variable because it could be changed by AddFromTemplate
            // if the directory name specified is already exist
            project        = vsApp.Solution.Item(iIndex + 1); // the item method is 1 base !
            strPrjName     = project.Name;
            strPrjFullName = project.FullName;
            // Delete Form1
            DeleteProjectItem(project, "Form1" + strExtension);
            return(project);
        }

        //**********************************************************************
        //
        /// <summary>
        /// GetProject:                 Get the DTE project object
        /// </summary>
        /// <param name="vsApp">        Visual studio application</param>
        /// <param name="strPrjName">   Project name</param>
        /// <returns>
        /// The project
        /// </returns>
        //
        //**********************************************************************
        public static EnvDTE.Project GetProject(EnvDTE.DTE vsApp, string strPrjName) {
            EnvDTE.Project prjRetVal = null;
            
            foreach (EnvDTE.Project prj in vsApp.Solution.Projects) {
                if (prj.Name == strPrjName) {
                    prjRetVal = prj;
                    break;
                }
            }
            return(prjRetVal);
        }

        //*********************************************************
        //
        /// <summary>
        /// FindXmlNode:                Find an xml node in an xml document
        /// </summary>
        /// <param name="xmlDoc">       xml document</param>
        /// <param name="node">         Node in which to search the child. null for root</param>
        /// <param name="strName">      Node name to find</param>
        /// <returns>
        /// Node or null if document is not loaded.
        /// </returns>
        //
        //*********************************************************
        public static XmlNode FindXmlNode(XmlDocument xmlDoc, XmlNode node, string strName) {
            XmlNode     nodeRetVal = null;
            XmlNodeList nodeList;
            
            if (xmlDoc != null) {
                strName  = strName.ToLower();
                nodeList = (node == null) ? xmlDoc.ChildNodes : node.ChildNodes;
                foreach (XmlNode nodeChild in nodeList) {
                    if (nodeChild.Name.ToLower() == strName) {
                        nodeRetVal = nodeChild;
                        break;
                    }
                }
                if (nodeRetVal == null) {
                    nodeRetVal = xmlDoc.CreateNode(XmlNodeType.Element, strName, "");
                    if (node == null) {
                        xmlDoc.ChildNodes[0].AppendChild(nodeRetVal);
                    } else {
                        node.AppendChild(nodeRetVal);
                    }
                }
            }
            return(nodeRetVal);
        }

        //*********************************************************
        //
        /// <summary>
        /// FindXmlNode:                Find an xml node in an xml document
        /// </summary>
        /// <param name="xmlDoc">       xml document</param>
        /// <param name="node">         Node in which to search the child. null for root</param>
        /// <param name="strNodeName">  Node name to find</param>
        /// <param name="strAttrName">  Attribute name to find</param>
        /// <param name="strAttrValue"> Attribute value</param>
        /// <returns>
        /// Node or null if not found
        /// </returns>
        //
        //*********************************************************
        public static XmlNode FindXmlNode(XmlDocument   xmlDoc, 
                                          XmlNode       node,
                                          string        strNodeName,
                                          string        strAttrName,
                                          string        strAttrValue) {
            XmlNode         nodeRetVal = null;
            XmlNodeList     nodeList;
            XmlAttribute    attr;
            
            if (xmlDoc != null) {
                strNodeName  = strNodeName.ToLower();
                strAttrName  = strAttrName.ToLower();
                nodeList     = (node == null) ? xmlDoc.ChildNodes : node.ChildNodes;
                foreach (XmlNode nodeChild in nodeList) {
                    if (nodeChild.Name.ToLower() == strNodeName) {
                        attr = nodeChild.Attributes[strAttrName];
                        if (attr != null && attr.Value == strAttrValue) {
                            nodeRetVal = nodeChild;
                            break;
                        }
                    }
                }
                if (nodeRetVal == null) {
                    nodeRetVal = xmlDoc.CreateNode(XmlNodeType.Element, strNodeName, "");
                    if (node == null) {
                        xmlDoc.ChildNodes[0].AppendChild(nodeRetVal);
                    } else {
                        node.AppendChild(nodeRetVal);
                    }
                }
            }
            return(nodeRetVal);
        }

        //*********************************************************
        //
        /// <summary>
        /// AddXmlNodeAttribute:        Add an xml attribute to an xml node
        /// </summary>
        /// <param name="xmlDoc">       xml document</param>
        /// <param name="node">         xml node</param>
        /// <param name="strAttrName">  xml attribute name</param>
        /// <param name="strAttrValue"> xml attribute value</param>
        /// <returns>
        /// xml attribute.
        /// </returns>
        //
        //*********************************************************
        public static XmlAttribute AddXmlNodeAttribute(XmlDocument  xmlDoc,
                                                       XmlNode      xmlNode,
                                                       string       strAttrName,
                                                       string       strAttrValue) {
            XmlAttribute xmlAttrRetVal;
            
            xmlAttrRetVal       = xmlDoc.CreateAttribute(strAttrName);
            xmlAttrRetVal.Value = strAttrValue;
            xmlNode.Attributes.Append(xmlAttrRetVal);
            return(xmlAttrRetVal);
        }

        //*********************************************************
        //
        /// <summary>
        /// GetXmlNodeAttributeValue:       Get the value of an xml attribute. empty if not found
        /// </summary>
        /// <param name="xmlNode">          xml node</param>
        /// <param name="strAttrName">      xml attribute name</param>
        /// <param name="strDefValue">      The value to return if the attribute is not defined</param>
        /// <returns>
        /// Attribute value
        /// </returns>
        //
        //*********************************************************
        public static string GetXmlNodeAttributeValue(XmlNode xmlNode, string strAttrName, string strDefValue) {
            string          strRetVal;
            XmlAttribute    xmlAttr;
            
            xmlAttr = xmlNode.Attributes[strAttrName];
            if (xmlAttr != null) {
                strRetVal = xmlAttr.Value;
            } else {
                strRetVal = strDefValue;
            }
            return(strRetVal);
        }

        //******************************************************************
        //
        /// <summary>
        /// SetRegistryKeyValue:        Set a registry key value
        /// </summary>
        /// <param name="strKey">       Registry key</param>
        /// <param name="strName">      Sub key name</param>
        /// <param name="strValue">     Sub key value</param>
        //
        //******************************************************************
        public static void SetRegistryKeyValue(string strKey, string strName, string strValue) {
            RegistryKey key = null;

            try {
                key = Registry.CurrentUser.OpenSubKey(strKey, true);
                if (key == null) {
                    key = Registry.CurrentUser.CreateSubKey(strKey);
                }
                if (key != null) {
                    key.SetValue(strName, strValue);
                }
            } finally {
                if (key != null) {
                    key.Close();
                }
            }
        }

        //******************************************************************
        //
        /// <summary>
        /// GetRegistryKeyValue:        Get a value of a registry key
        /// </summary>
        /// <param name="strKey">       Registry key</param>
        /// <param name="strName">      Sub key name</param>
        /// <returns>
        /// The value of the registry key
        /// </returns>
        //
        //******************************************************************
        public static string GetRegistryKeyValue(string strKey, string strName) {
            string      strRetVal = String.Empty;
            RegistryKey key       = null;

            try {
                key = Registry.CurrentUser.OpenSubKey(strKey);
                if (key != null) {
                    strRetVal = key.GetValue(strName, "").ToString();
                }
            } finally {
                if (key != null) {
                    key.Close();
                }
            }
            return(strRetVal);
        }

        //******************************************************************
        //
        /// <summary>
        /// GetRepPPDir:        Get rep++ install directory
        /// </summary>
        /// <returns>
        /// Rep++ install directory
        /// </returns>
        //
        //******************************************************************
        public static string GetRepPPDir() {
            string      strRetVal = String.Empty;
            RegistryKey key;

            using (key = Registry.LocalMachine.OpenSubKey(Global.REGKEY_INSTALLDIR)) {
                strRetVal = key.GetValue("", "").ToString();
            }
            return(strRetVal);
        }

        //******************************************************************
        //
        /// <summary>
        /// GetRepPPBinDir:    Get rep++ public bin directory
        /// </summary>
        /// <returns>
        /// Rep++ public bin directory
        /// </returns>
        //
        //******************************************************************
        public static string GetRepPPBinDir() {
            string strRetVal;
            string strBinDir;

            strRetVal = GetRepPPDir();
            if (strRetVal != String.Empty) {
#if VC70 == true
                strBinDir = "bin\\sdwin32\\V10\\public";
#else
#if VC71 == true

                strBinDir = "bin\\sdwin32\\V11\\public";
#else
                strBinDir = "bin\\sdwin32\\V20\\public";
#endif
#endif
                strRetVal = Path.Combine(strRetVal, strBinDir);
            }
            return(strRetVal);
        }

        //**********************************************************************
        //
        /// <summary>
        /// GetFormTemplateFileName:    Get the file name for the form template
        /// </summary>
        /// <param name="bForDesign">   True to indicates that the template is for the design</param>
        /// <param name="eLang">        The programming language</param>
        /// <returns>
        /// Template file name
        /// </returns>
        //
        //**********************************************************************
        public static string GetFormTemplateFileName(bool bForDesign, ProgramLanguageE  eLang) {
            string  strRetVal;
            string  strExt;

            strExt = (eLang == ProgramLanguageE.sdCSharp) ? ".cs" : ".vb";
            strRetVal = Utility.GetRepPPDir();
#if VC70 == true
                strRetVal = Path.Combine(strRetVal, "bin\\sdwin32\\V10\\private\\FormTemplate");
#else
#if VC71 == true
                strRetVal = Path.Combine(strRetVal, "bin\\sdwin32\\V11\\private\\FormTemplate");
#else
                if (bForDesign) {
                    strRetVal = Path.Combine(strRetVal, "bin\\sdwin32\\V20\\private\\FormTemplate.Designer");
                } else {
                    strRetVal = Path.Combine(strRetVal, "bin\\sdwin32\\V20\\private\\FormTemplate");
                }
#endif
#endif
                return(strRetVal + strExt);

        }

        //**********************************************************************
        //
        /// <summary>
        /// CreateSessionFolder:         Create the rep++ session folder and set the 
        ///                              security access for ASPNET user
        /// </summary>
        /// <param name="strFullPath">   Project path</param>
        /// <returns>
        /// The project
        /// </returns>
        //
        //**********************************************************************
        public static bool CreateSessionFolder(string strFullPath) {
            string  strFolderName;

            strFolderName = Path.Combine(strFullPath, "RepPPSession");
            if (!Directory.Exists(strFolderName)) {
                Directory.CreateDirectory(strFolderName);
            }
            return(SCFileSecurity.SetFileAccessRights(strFolderName, 
                                                      "ASPNET",
                                                      (int)(FileAccessTypeE.sdGenericAll)));
        }

        //**********************************************************************
        //
        /// <summary>
        /// GetProjectDirectoryName:        Get the project directory name 
        /// </summary>
        /// <param name="project">          Project</param>
        /// <returns>
        /// The project directory name
        /// </returns>
        //
        //**********************************************************************
        public static string GetProjectDirectoryName(EnvDTE.Project project) {
            string strRetVal;

#if VC8
            strRetVal = project.Properties.Item("FullPath").Value.ToString();
#else
            strRetVal = Path.GetDirectoryName(project.FullName);
#endif
            return(strRetVal);
        }

        //**********************************************************************
        //
        /// <summary>
        /// AddProjectFolder:               Add a folder to the project
        /// </summary>
        /// <param name="project">          Project</param>
        /// <param name="strFolderName">    Folder name</param>
        /// <returns>
        /// The project
        /// </returns>
        //
        //**********************************************************************
        public static void AddProjectFolder(EnvDTE.Project project, string strFolderName) {
            string strFullDirName;

            strFullDirName = Path.Combine(GetProjectDirectoryName(project), strFolderName);
            if (!Directory.Exists(strFullDirName)) {
                if (strFolderName.IndexOf("\\") == -1) {
                    project.ProjectItems.AddFolder(strFolderName, "");
                } else {
                    Directory.CreateDirectory(strFullDirName);
                }
            }
        }

        //*********************************************************     
        //
        /// <summary>
        /// GetProjectRootNamespace:    Get the project root namespace
        /// </summary>
        /// <param name="project">      Visual studio project</param>
        //
        //*********************************************************     
        public static string GetProjectRootNamespace(EnvDTE.Project project) {
            string              strRetVal = String.Empty;
            EnvDTE.Properties   props;

            // In some project types (ASP.NET 2.0) the RootNamespace is not defined
            // in the properties collection of the project
            try {
                props = project.Properties;
                if (props.Item("RootNamespace") != null) {
                    strRetVal = props.Item("RootNamespace").Value.ToString();
                }
            } catch {
            }
            return(strRetVal);
        }

        //*********************************************************     
        //
        /// <summary>
        /// GetProjectRootNamespace:    Get the project root namespace
        /// </summary>
        /// <param name="vsApp">        Visual studio application</param>
        /// <param name="strPrjName">   Project name</param>
        //
        //*********************************************************     
        public static string GetProjectRootNamespace(EnvDTE.DTE vsApp, string strProjectName) {
            EnvDTE.Project      project;

            project = GetProject(vsApp, strProjectName);
            return(GetProjectRootNamespace(project));
        }

        //*********************************************************     
        //
        /// <summary>
        /// SetProjectStartPage:        Set the start page of the project
        /// </summary>
        /// <param name="vsApp">        Visual studio application</param>
        /// <param name="strPrjName">   Project name</param>
        /// <param name="strPage">      Page name</param>
        //
        //*********************************************************     
        public static void SetProjectStartPage(EnvDTE.DTE vsApp, string strPrjName, string strPage) {
            EnvDTE.Project      project;
            EnvDTE.Properties   props;
            

            project                         = GetProject(vsApp, strPrjName);
#if VC8
            props                           = project.Properties;
            props.Item("StartAction").Value = 1;
#else
            props                           = project.ConfigurationManager.Item("Debug", ".NET").Properties;
#endif
            props.Item("StartPage").Value   = strPage;
        }

        //*********************************************************     
        //
        /// <summary>
        /// CreateTextFile:                  Create a file name
        /// </summary>
        /// <param name="strFullFileName">   File full name</param>
        /// <param name="eReplaceMode">      Replacing file mode</param>
        //
        //*********************************************************     
        public static StreamWriter CreateTextFile(string strFullFileName, ReplaceFileModeE eReplaceMode) {
            StreamWriter    writer    = null;
            bool            bContinue = false;

            try {
                if (!File.Exists(strFullFileName)) {
                    bContinue = true;
                } else {
                    switch (eReplaceMode) {
                    case ReplaceFileModeE.sdAskBeforeReplace:
                        if (MessageBox.Show("The file " + strFullFileName + " already exists.\r\n" +
                            " Do you want ro replace it?",
                            "Rep++ Wizard",
                            MessageBoxButtons.YesNo,
                            MessageBoxIcon.Question) == DialogResult.Yes) {
                            File.Delete(strFullFileName);
                            bContinue = true;
                        }
                        break;
                    case ReplaceFileModeE.sdReplaceWithoutAsk:
                        File.Delete(strFullFileName);
                        bContinue = true;
                        break;
                    case ReplaceFileModeE.sdDoNotReplace:
                        break;
                    }
                }
                if (bContinue) {
                    writer = File.CreateText(strFullFileName);
                }
            } catch (System.Exception ex) {
                MessageBox.Show(ex.Message,
                                "Rep++ Wizard",
                                MessageBoxButtons.OK,
                                MessageBoxIcon.Warning);
                writer = null;
            }
            return(writer);
        }

        //*********************************************************     
        //
        /// <summary>
        /// CopyFile:                           Copy file
        /// </summary>
        /// <param name="strSrcFullFileName">   Source file full name</param>
        /// <param name="strSrcFullFileName">   Destination file full name</param>
        /// <param name="eReplaceMode">         Replacing file mode</param>
        //
        //*********************************************************     
        public static void CopyFile(string strSrcFullFileName, string strDestFullFileName, ReplaceFileModeE eReplaceMode) {
            bool    bContinue = false;

            try {
                if (!File.Exists(strDestFullFileName)) {
                    bContinue = true;
                } else {
                    switch (eReplaceMode) {
                    case ReplaceFileModeE.sdAskBeforeReplace:
                        if (MessageBox.Show("The file " + strDestFullFileName + " already exists.\r\n" +
                            " Do you want ro replace it?",
                            "Rep++ Wizard",
                            MessageBoxButtons.YesNo,
                            MessageBoxIcon.Question) == DialogResult.Yes) {
                            File.Delete(strDestFullFileName);
                            bContinue = true;
                        }
                        break;
                    case ReplaceFileModeE.sdReplaceWithoutAsk:
                        File.Delete(strDestFullFileName);
                        bContinue = true;
                        break;
                    case ReplaceFileModeE.sdDoNotReplace:
                        break;
                    }
                }
                if (bContinue) {
                    File.Copy(strSrcFullFileName, strDestFullFileName);
                    File.SetAttributes(strDestFullFileName, File.GetAttributes(strDestFullFileName) & ~FileAttributes.ReadOnly);
                }
            } catch (System.Exception ex) {
                MessageBox.Show(ex.Message,
                                "Rep++ Wizard",
                                MessageBoxButtons.OK,
                                MessageBoxIcon.Warning);
            }
        }

        //*********************************************************     
        //
        /// <summary>
        /// GetProjectDirectoryName:    Get the project directory name
        /// </summary>
        /// <param name="vsApp">        Visual studio application</param>
        /// <param name="strPrjName">   Project name</param>
        /// <returns>
        /// Project directory name
        /// </returns>
        //
        //*********************************************************     
        public static string GetProjectDirectoryName(EnvDTE.DTE vsApp, string strPrjName) {
            return(GetProjectDirectoryName(GetProject(vsApp, strPrjName)));
        }

        //*********************************************************     
        //
        /// <summary>
        /// GenCardTypedInstance:               Genearte card typed instance 
        /// </summary>
        /// <param name="project">              Visual studio project</param>
        /// <param name="strCrdClassPrefix">    Prefix for generated group class name</param>
        /// <param name="strGrpClassPrefix">    Prefix for generated group class name</param>
        /// <param name="strGrpPropertyPrefix"> Prefix for generated group property name</param>
        /// <param name="strFldPropertyPrefix"> Prefix for generated field property name</param>
        /// <param name="strNamespace">         Namespace</param>
        /// <param name="strRootNamespace">     Root namespace of the project</param>
        /// <param name="strCrdBaseClassName">  Base class name</param>
        /// <param name="strGrpBaseClassName">  Group base class name</param>
        /// <param name="generator">            Generator object</param>
        /// <param name="bGenWS">               true to generate Web Service structures</param>
        /// <param name="crd">                  Card</param>
        /// <param name="eReplaceMode">         Replace existing files mode</param>
        //
        //*********************************************************     
        public static void GenCardTypedInstance(EnvDTE.Project          project,
                                                string                  strCrdClassPrefix,
                                                string                  strGrpClassPrefix,
                                                string                  strGrpPropertyPrefix,
                                                string                  strFldPropertyPrefix,
                                                string                  strNamespace,
                                                string                  strRootNamespace,
                                                string                  strCrdBaseClassName,
                                                string                  strGrpBaseClassName,
                                                TypedInstanceGenBase    generator,
                                                bool                    bGenWS,
                                                RepPP.Card              crd,
                                                ReplaceFileModeE        eReplaceMode,
                                                string                  strSubFolderName,
                                                bool                    bGenGroupTypedInstance) {
            string              strCardFileName;
            string              strUserCardFileName;
            string              strDirName;
            string              strFileExt;
            string              strText;
            StreamWriter        writer;
            string              strTIFolderName;
            string[]            arrGroupName;

            if (bGenGroupTypedInstance) {
                arrGroupName = GetGroupNameList(crd);
                foreach (string strGroupName in arrGroupName) {
                    GenGroupTypedInstance(project, 
                                          strCrdClassPrefix,
                                          strGrpClassPrefix,
                                          strGrpPropertyPrefix,
                                          strFldPropertyPrefix,
                                          strNamespace,
                                          strRootNamespace,
                                          strGrpBaseClassName,
                                          generator,
                                          bGenWS,
                                          crd.Application.Groups[strGroupName],
                                          eReplaceMode,
                                          strSubFolderName);
                                          
                }
            }
            if (strSubFolderName != string.Empty) {
                strTIFolderName = Path.Combine(strSubFolderName, TYPED_INST_FOLDER_NAME);
            } else {
                strTIFolderName = TYPED_INST_FOLDER_NAME;
            }
            AddProjectFolder(project, strTIFolderName);
            strDirName       = Path.Combine(GetProjectDirectoryName(project), strTIFolderName);
            // Add the typed card intance class (_ccCardName)
            strFileExt       = generator is TypedInstanceGenForCS ? ".cs" : ".vb";
            strCardFileName  = generator.BuildCardFileName(TypedInstanceGenBase.TYPED_CARD_INST_PREFIX + strCrdClassPrefix, crd, strFileExt);
            
            strCardFileName  = Path.Combine(strDirName, strCardFileName);
            writer           = Utility.CreateTextFile(strCardFileName, eReplaceMode);
            if (writer != null) {
                using (writer) {
                    strText = generator.GenerateTypedCardInstance(crd, 
                                                                  strCrdClassPrefix,
                                                                  strGrpClassPrefix,
                                                                  strGrpPropertyPrefix,
                                                                  strFldPropertyPrefix,
                                                                  strNamespace,
                                                                  strRootNamespace,
                                                                  strCrdBaseClassName,
                                                                  strGrpBaseClassName,
                                                                  bGenWS);
                    writer.Write(strText);
                }
                project.ProjectItems.AddFromFile(strCardFileName);
            }
            // Add the User custom typed card instance class
            strUserCardFileName = generator.BuildCardFileName(strCrdClassPrefix, crd, strFileExt);
            if (FindProjectItem(project, strUserCardFileName) == null) {
                strUserCardFileName = Path.Combine(strDirName, strUserCardFileName);
                writer              = Utility.CreateTextFile(strUserCardFileName, ReplaceFileModeE.sdDoNotReplace);
                if (writer != null) {
                    using (writer) {
                        strText = generator.GenerateUserTypedCardInstance(crd, 
                                                                          strCrdClassPrefix,
                                                                          strNamespace,
                                                                          strRootNamespace);
                        writer.Write(strText);
                    }
                    project.ProjectItems.AddFromFile(strUserCardFileName);
                }
            }
        }

        //*********************************************************     
        //
        /// <summary>
        /// GenGroupTypedInstance:          Generate group typed instance 
        /// </summary>
        /// <param name="project">          Visual studio project</param>
        /// <param name="strNamespace">     Namespace</param>
        /// <param name="strRootNamespace"> Root namespace of the project</param>
        /// <param name="strBaseClassName"> Base class name</param>
        /// <param name="generator">        Generator object</param>
        /// <param name="bGenWS">           true to generate Web Service structures</param>
        /// <param name="grp">              Group</param>
        /// <param name="eReplaceMode">     Replace existing files mode</param>
        //
        //*********************************************************     
        public static void GenGroupTypedInstance(EnvDTE.Project         project,
                                                 string                 strCrdClassPrefix,
                                                 string                 strGrpClassPrefix,
                                                 string                 strGrpPropertyPrefix,
                                                 string                 strFldPropertyPrefix,
                                                 string                 strNamespace,
                                                 string                 strRootNamespace,
                                                 string                 strBaseClassName,
                                                 TypedInstanceGenBase   generator,
                                                 bool                   bGenWS,
                                                 RepPP.Group            grp,
                                                 ReplaceFileModeE       eReplaceMode,
                                                 string                 strSubFolderName) {

            string              strGroupFileName;
            string              strUserGroupFileName;
            string              strDirName;
            string              strFileExt;
            string              strText;
            StreamWriter        writer;
            string              strTIFolderName;

            if (strSubFolderName != string.Empty) {
                strTIFolderName = Path.Combine(strSubFolderName, TYPED_INST_FOLDER_NAME);
            } else {
                strTIFolderName = TYPED_INST_FOLDER_NAME;
            }
            AddProjectFolder(project, strTIFolderName);
            strDirName   = Path.Combine(GetProjectDirectoryName(project), strTIFolderName);
            // Add the typed group instance class (_gcGroupName)
            strFileExt        = generator is TypedInstanceGenForCS ? ".cs" : ".vb";
            strGroupFileName  = generator.BuildGroupFileName(TypedInstanceGenBase.TYPED_GROUP_INST_PREFIX + strGrpClassPrefix, grp, strFileExt);
            strGroupFileName  = Path.Combine(strDirName, strGroupFileName);
            writer            = Utility.CreateTextFile(strGroupFileName, eReplaceMode);
            if (writer != null) {
                using (writer) {
                    strText = generator.GenerateTypedGroupInstance(grp, 
                                                                   strCrdClassPrefix,
                                                                   strGrpClassPrefix,
                                                                   strGrpPropertyPrefix,
                                                                   strFldPropertyPrefix,
                                                                   strNamespace,
                                                                   strRootNamespace,
                                                                   strBaseClassName,
                                                                   bGenWS);
                    writer.Write(strText);
                }
                project.ProjectItems.AddFromFile(strGroupFileName);
            }
            // Add the User custom typed group instance class
            strUserGroupFileName = generator.BuildGroupFileName(strGrpClassPrefix, grp, strFileExt);
            if (FindProjectItem(project, strUserGroupFileName) == null) {
                strUserGroupFileName = Path.Combine(strDirName, strUserGroupFileName);
                writer               = Utility.CreateTextFile(strUserGroupFileName, ReplaceFileModeE.sdDoNotReplace);
                if (writer != null) {
                    using (writer) {
                        strText = generator.GenerateUserTypedGroupInstance(grp, 
                                                                           strGrpClassPrefix,
                                                                           strNamespace,
                                                                           strRootNamespace);
                        writer.Write(strText);
                    }
                    project.ProjectItems.AddFromFile(strUserGroupFileName);
                }
            }
        }

        //*********************************************************     
        //
        /// <summary>
        /// GenTypedInstanceConfigFile:         Generates the file containing the configuration for update
        /// </summary>
		/// <param name="proect">               Project</param>
        /// <param name="strSysName">           System name</param>
        /// <param name="strAppName">           Program name</param>
        /// <param name="strConName">           Connection name</param>
        /// <param name="strUsrName">           User name</param>
        /// <param name="eLangCode">            Language code</param>
        /// <param name="strCrdClassPrefix">    Prefix for generated group class name</param>
        /// <param name="strGrpClassPrefix">    Prefix for generated group class name</param>
        /// <param name="strGrpPropertyPrefix"> Prefix for generated group property name</param>
        /// <param name="strFldPropertyPrefix"> Prefix for generated field property name</param>
		/// <param name="strNameSpace">         Namespace</param>
        /// <param name="strRootNameSpace">     Root namespace of the project</param>
		/// <param name="strCardBaseClass">     Card base class if found</param>
		/// <param name="strGroupBaseClass">    Group base class</param>
		/// <param name="bGenWS">               true to generates Web Services structures</param>
        //
        //*********************************************************     
        public static void GenTypedInstanceConfigFile(EnvDTE.Project        project,
		                                              string                strSysName,
		                                              string                strPrgName,
		                                              string                strConName,
		                                              string                strUsrName,
		                                              LanguageCode          eLangCode,
                                                      string                strCrdClassPrefix,
                                                      string                strGrpClassPrefix,
                                                      string                strGrpPropertyPrefix,
                                                      string                strFldPropertyPrefix,
                                                      string                strNamespace,
                                                      string                strRootNamespace,
                                                      string                strCardBaseClassName,
                                                      string                strGroupBaseClassName,
                                                      bool                  bGenWS) {
		    EnvDTE.ProjectItem      projItem;
		    ProjectFolderInterface  projFolderIntf;
		    
		    projItem        = Utility.FindProjectItem(project, TYPED_INST_FOLDER_NAME);
		    projFolderIntf  = new ProjectFolderInterface(projItem);
		    TypedInstanceGenBase.SaveConfigInfo(projFolderIntf,
		                                        strSysName,
		                                        strPrgName,
		                                        strConName,
		                                        strUsrName,
		                                        eLangCode,
                                                strCrdClassPrefix,
                                                strGrpClassPrefix,
                                                strGrpPropertyPrefix,
                                                strFldPropertyPrefix,
		                                        strNamespace,
                                                strRootNamespace,
		                                        strCardBaseClassName,
		                                        strGroupBaseClassName,
		                                        bGenWS);
        }

        //******************************************************************
        //
		/// <summary>
		/// ExtractConfigInfo:                  Extract configuration information from the XML file
		/// </summary>
		/// <param name="proect">               Project</param>
        /// <param name="strSysName">           System name</param>
        /// <param name="strAppName">           Program name</param>
        /// <param name="strConName">           Connection name</param>
        /// <param name="strUsrName">           User name</param>
        /// <param name="eLangCode">            Language code</param>
        /// <param name="strCrdClassPrefix">    Prefix for generated group class name</param>
        /// <param name="strGrpClassPrefix">    Prefix for generated group class name</param>
        /// <param name="strGrpPropertyPrefix"> Prefix for generated group property name</param>
        /// <param name="strFldPropertyPrefix"> Prefix for generated field property name</param>
		/// <param name="strNameSpace">         Namespace</param>
        /// <param name="strRootNameSpace">     Root namespace of the project</param>
		/// <param name="strCardBaseClass">     Card base class if found</param>
		/// <param name="strGroupBaseClass">    Group base class</param>
		/// <param name="bGenWS">               true to generates Web Services structures</param>
        //
        //******************************************************************
		public static void ExtractConfigInfo(EnvDTE.Project    project,
		                                     out string        strSysName,
		                                     out string        strAppName,
		                                     out string        strConName,
		                                     out string        strUsrName,
		                                     out LanguageCode  eLangCode,
                                             out string        strCrdClassPrefix,
                                             out string        strGrpClassPrefix,
                                             out string        strGrpPropertyPrefix,
                                             out string        strFldPropertyPrefix,
		                                     out string        strNameSpace,
                                             out string        strRootNameSpace,
		                                     out string        strCardBaseClass,
		                                     out string        strGroupBaseClass,
		                                     out bool          bGenWS) {
		    EnvDTE.ProjectItem      projItem;
		    ProjectFolderInterface  projFolderIntf;

		    strSysName              = "";
		    strAppName              = "";
		    strConName              = "";
		    strUsrName              = "";
		    eLangCode               = LanguageCode.sdDefault;
            strCrdClassPrefix       = "";
            strGrpClassPrefix       = "";
            strGrpPropertyPrefix    = "";
            strFldPropertyPrefix    = "";
		    strNameSpace            = "";
            strRootNameSpace        = "";
		    strCardBaseClass        = "";
		    strGroupBaseClass       = "";
		    bGenWS                  = false;
            projItem                = Utility.FindProjectItem(project, TYPED_INST_FOLDER_NAME);
            if (projItem != null) {
		        projFolderIntf  = new ProjectFolderInterface(projItem);
                try {
                    TypedInstanceGenBase.ExtractConfigInfo(projFolderIntf,
                                                           out strSysName,
                                                           out strAppName,
                                                           out strConName,
                                                           out strUsrName,
                                                           out eLangCode,
                                                           out strCrdClassPrefix,
                                                           out strGrpClassPrefix,
                                                           out strGrpPropertyPrefix,
                                                           out strFldPropertyPrefix,
                                                           out strNameSpace,
                                                           out strRootNameSpace,
                                                           out strCardBaseClass,
                                                           out strGroupBaseClass,
                                                           out bGenWS);
                } catch {
                }
            }
        }

        //**********************************************************************
        //
        /// <summary>
        /// CopyDirectory:              Copy a directory items to a destination directory
        /// </summary>
        /// <param name="strSrcDir">    Source directory</param>
        /// <param name="strDestDir">   Destination directory</param>
        //
        //**********************************************************************
        public static void CopyDirectory(string strSrcDir, string strDestDir) {
            CopyDirectory(strSrcDir, strDestDir, null);
        }

        //**********************************************************************
        //
        /// <summary>
        /// CopyDirectory:                      Copy a directory items to a destination directory
        /// </summary>
        /// <param name="strSrcDir">            Source directory</param>
        /// <param name="strDestDir">           Destination directory</param>
        /// <param name="arrFilesToNotCopy">    List of files in root directory to not copy</param>
        //
        //**********************************************************************
        public static void CopyDirectory(string strSrcDir, string strDestDir, ArrayList arrFilesToNotCopy) {
            string strSrcItemName;
            string strDestItemFullName;

            if (!Directory.Exists(strSrcDir)) {
                throw new System.Exception("The directory '" + strSrcDir + " doesn't exist");
            }
            if (!Directory.Exists(strDestDir)) {
                throw new System.Exception("The directory '" + strDestDir + " doesn't exist");
            }
            foreach(string strItem in Directory.GetFileSystemEntries(strSrcDir)) {
                strSrcItemName      = Path.GetFileName(strItem);
                strDestItemFullName = Path.Combine(strDestDir, strSrcItemName);
                if (File.Exists(strItem) == true             && 
                    File.Exists(strDestItemFullName) == false) {
                    if (arrFilesToNotCopy == null || arrFilesToNotCopy.Contains(strSrcItemName) == false) {
                        File.Copy(strItem, strDestItemFullName, false);
                    }
                } else if (Directory.Exists(strItem)) {
                    if (!Directory.Exists(strDestItemFullName)) {
                        Directory.CreateDirectory(strDestItemFullName);
                    }
                    CopyDirectory(strItem, strDestItemFullName);
                }
            }
        }

        //*********************************************************     
        //
        /// <summary>
        /// GetNotDefinedCardName:       Return a not defined card name
        /// </summary>
        //  
        //*********************************************************    
        public static string GetNotDefinedCardName(RepPP.IApplication app) {
            string  strRetVal;
            int     iIndex;

            strRetVal = "$DUMMY";
            iIndex    = 0;
            while (app.Cards.Find(strRetVal) != null) {
                strRetVal = "$DUMMY" + iIndex;
                iIndex++;
            }
            return(strRetVal);
        }

        //*********************************************************     
        //
        /// <summary>
        /// GetNotDefinedCardName:       Return a not defined card name
        /// </summary>
        //  
        //*********************************************************    
        public static string GetNotDefinedGroupName(RepPP.IApplication app) {
            string  strRetVal;
            int     iIndex;

            strRetVal = "$DUMMY";
            iIndex    = 0;
            while (app.Groups.Find(strRetVal) != null) {
                strRetVal = "$DUMMY" + iIndex;
                iIndex++;
            }
            return(strRetVal);
        }

        //*********************************************************     
        //
        /// <summary>
        /// GetAssemblyVersion:       Get the assembly version
        /// </summary>
        /// <returns>
        /// The assembly version
        /// </returns>
        //  
        //*********************************************************    
        public static string GetAssemblyVersion() {
            string                      strRetVal = String.Empty;
            System.Reflection.Assembly  assembly;

            assembly = typeof(Utility).Assembly;
            if (assembly != null) {
                strRetVal = assembly.GetName().Version.ToString();
            }
            return(strRetVal);
        }

        //*********************************************************     
        //
        /// <summary>
        /// GetFileNameWithoutExtension:       Return the file name without the extension
        ///                                    Treat the case of .aspx.cs
        /// </summary>
        /// <returns>
        /// The file name without the extension
        /// </returns>
        //  
        //*********************************************************    
        public static string GetFileNameWithoutExtension(string strFileName) {
            string  strRetVal;
            int     iIndex;

            iIndex = strFileName.IndexOf(".");
            if (iIndex != -1) {
                strRetVal = strFileName.Substring(0, iIndex);
            } else {
                strRetVal = strFileName;
            }
            return(strRetVal);
        }

        //*********************************************************     
        //
        /// <summary>
        /// GetFileExtension:       Return the file extension
        ///                         Treat the case of .aspx.cs
        /// </summary>
        /// <returns>
        /// The file extension
        /// </returns>
        //  
        //*********************************************************    
        public static string GetFileExtension(string strFileName) {
            string  strRetVal;
            int     iIndex;

            iIndex = strFileName.IndexOf(".");
            if (iIndex != -1) {
                strRetVal = strFileName.Substring(iIndex);
            } else {
                strRetVal = String.Empty;
            }
            return(strRetVal);
        }

        //*********************************************************     
        //
        /// <summary>
        /// SuffixFileName:             Suffix a file name
        /// </summary>
        /// <param name="strFileName">  File name</param>
        /// <param name="strSuffix">    Suffix</param>
        /// <returns>
        /// suffixed file name
        /// </returns>
        //  
        //*********************************************************    
        public static string SuffixFileName(string strFileName, string strSuffix) {
            return(GetFileNameWithoutExtension(strFileName) + 
                   strSuffix +
                   GetFileExtension(strFileName));
        }

        //*********************************************************     
        //
        /// <summary>
        /// GetFullPath:                    Get a full path according of a specified current directory
        /// </summary>
        /// <param name="strCurrentDir">    Current directory</param>
        /// <param name="strPath">          Path</param>
        /// <returns>
        /// Full path
        /// </returns>
        //  
        //*********************************************************    
        public static string GetFullPath(string strCurrentDir, string strPath) {
            string strRetVal;
            string strDir;

            strDir                       = Environment.CurrentDirectory;
            Environment.CurrentDirectory = strCurrentDir;
            strRetVal                    = Path.GetFullPath(strPath);
            Environment.CurrentDirectory = strDir;
            return(strRetVal);
        }

        //*********************************************************     
        //
        /// <summary>
        /// AddAssemblyAttribute:       Add an attribute to an assembly
        /// </summary>
        /// <param name="project">      Project</param>
        /// <param name="strAttr">      String definig the attribute with the parameters</param>
        /// <param name="strExt">       The extention of the assembly info file</param>
        //  
        //*********************************************************    
        public static void AddAssemblyAttribute(EnvDTE.Project project, string strAttr, string strExt) {
            string          strFileName;
            StreamReader    reader;
            StreamWriter    writer;
            bool            bWrite;
            ProjectItem     projectItem;

            projectItem = Utility.FindProjectItem(project, "AssemblyInfo" + strExt);
            if (projectItem != null) {
                strFileName  = projectItem.get_FileNames(1);
                using (reader = File.OpenText(strFileName)) {
                    bWrite = (reader.ReadToEnd().IndexOf(strAttr) == -1);
                }
                if (bWrite) {
                    using (writer = File.AppendText(strFileName)) {
                        if (strExt == ".cs") {
                            writer.WriteLine("\r\n[assembly: " + strAttr + "]");
                        } else {
                            writer.WriteLine("\r\n<Assembly: " + strAttr + ">");
                        }
                    }
                }
            }
        }

        //*********************************************************     
        //
        /// <summary>
        /// FindCodeElement:            Find a code element using its kind
        /// </summary>
        /// <param name="elements">     Collection of code elements</param>
        /// <param name="kind">         Kind of the code element to find</param>
        /// <returns>
        /// Code element object
        /// </returns>
        //  
        //*********************************************************    
        public static object FindCodeElement(EnvDTE.CodeElements elements, EnvDTE.vsCMElement kind) {
            object      oRetVal = null;
            int         iIndex  = 1;
            CodeElement element;

            while (oRetVal == null && iIndex <= elements.Count) {
                element = elements.Item(iIndex);
                if (element.Kind == kind) {
                    oRetVal = element;
                }
                iIndex++;
            }
            return(oRetVal);
        }

        //******************************************************************
        //
        /// <summary>
        /// IsRepPPInitialized:       Get whether or not rep++ application is initialized
        /// </summary>
        //
        //******************************************************************
        public static bool IsRepPPInitialized() {
            bool                bRetVal = false;
            RepPP.Application   app;

            app = RepPP.Application.GetApplication();
            if (app != null) {
                bRetVal = app.IsProgramStarted();
            }
            return(bRetVal);
        }

        //*********************************************************     
        //
        /// <summary>
        /// UpdateInfoResxFile:             Update the rep++ info resx file
        /// </summary>
        /// <param name="vsApp">            Visual studio object</param>
        /// <param name="strPrjName">       Project name</param>
        /// <param name="app">              Rep++ application</param>
        /// <param name="bUseResDispencer"> True to use the resource dispencer</param>
        //
        //*********************************************************
        public static void UpdateInfoResxFile(EnvDTE.DTE            vsApp, 
                                              string                strPrjName,
                                              RepPP.IApplication    app,
                                              bool                  bUseResDispencer) {
            EnvDTE.Project      project;
            string              strFileName;
            StreamWriter        writer;
            ResXResourceWriter  resWriter;

            project     = Utility.GetProject(vsApp, strPrjName);
            strFileName = GetProjectDirectoryName(project);
#if VC8
            Utility.AddProjectFolder(project, "App_GlobalResources");
            strFileName = Path.Combine(strFileName, "App_GlobalResources");
#endif
            strFileName = Path.Combine(strFileName, "RepPPInfo.resx");
            if (!File.Exists(strFileName)) {
                using (writer = File.CreateText(strFileName)) {
                }
                project.ProjectItems.AddFromFile(strFileName);
            }
            using (resWriter = new ResXResourceWriter(strFileName)) {
                resWriter.AddResource("ConnName",     app.ConnectionName);
                resWriter.AddResource("UserName",     app.UserName);
                resWriter.AddResource("SysName",      app.SystemName);
                resWriter.AddResource("PrgName",      app.ProgramName);
                resWriter.AddResource("Pwd",          "");
                resWriter.AddResource("Language",     ((int)app.LanguageCode).ToString());
                resWriter.AddResource("Method",       bUseResDispencer ? "1" : "0");
                resWriter.AddResource("PromptLogin",  "0");
            }
        }

        //*********************************************************     
        //
        /// <summary>
        /// GetDataConnectionName:          Get the data connection name attached to the 
        ///                                 repository connection
        /// </summary>
        /// <param name="strRepConnName">   Repository connection name</param>
        //
        //*********************************************************
        public static string GetDataConnectionName(string strRepConnName) {
            string      strRetVal = String.Empty;
            string      strKey;
            RegistryKey key;

            strKey = Global.REGKEY_INSTALLDIR.Replace("InstallDir", "DataConnections");
            key    = Registry.LocalMachine.OpenSubKey(strKey);
            if (key != null) {
                strRetVal = key.GetValue(strRepConnName, "").ToString();
                if (strRetVal == strRepConnName) {
                    strRetVal = String.Empty;
                }
                key.Close();
            }
            return(strRetVal);
        }
     
        //******************************************************************
        //
        /// <summary>
        /// GetGroupNameList:               Get the group names list
        /// </summary>
        /// <param name="arrCardGroup">     Collection of card groups</param>
        /// <param name="arrGroupName">     Array list of group names used as the return value</param>
        //
        //******************************************************************   
        private static void GetGroupNameList(RepPP.CardGroups arrCardGroup, ref ArrayList arrGroupName) {
            foreach(RepPP.CardGroup crdgrp in arrCardGroup) {
                arrGroupName.Add(crdgrp.Group.Name);
                if (crdgrp.ChildCardGroups.Count > 0) {
                    GetGroupNameList(crdgrp.ChildCardGroups, ref arrGroupName);
                }
            }
        }

        //******************************************************************
        //
        /// <summary>
        /// GetGroupNameList:               Get the group names list for a card
        /// </summary>
        /// <param name="strCardName">      Card name</param>
        /// <returns>
        /// Array of group names
        /// </returns>
        //
        //******************************************************************   
        public static string[] GetGroupNameList(RepPP.Card crd) {
            string[]            arrRetVal;
            ArrayList           arrGroupName;

            arrGroupName    = new ArrayList();
            GetGroupNameList(crd.ChildCardGroups, ref arrGroupName);
            arrRetVal = new string[arrGroupName.Count];
            arrGroupName.CopyTo(arrRetVal);
            return(arrRetVal);
        }

        //*********************************************************
        //
        /// <summary>
        /// CheckForTypedInstNameClash:         Checks if name clash exist with generated field and group name with base class
        /// </summary>
        /// <param name="app">                  Rep++ application object</param>
        /// <param name="arrCardNames">        Array of card names to check</param>
        /// <param name="arrGroupNames">        Array of group names to check</param>
        /// <param name="strBaseCardClass">     Name of base class for generated card instance</param>
        /// <param name="strBaseGroupClass">    Name of base class for generated group instance</param>
        /// <param name="strCrdClsPrefix">      Prefix to use with class name</param>
        /// <param name="strGrpClsPrefix">      Prefix to use with group name</param>
        /// <param name="strGrpPropPrefix">     Prefix to use for property to access group instance</param>
        /// <param name="strFldPropPrefix">     Prefix to use for property to access field instance</param>
        /// <param name="bChekForWS">           True to check the name clash with the web services classes and methods</param>
        /// <returns>
        /// true:   Ok
        /// false:  Problem. Name clash
        /// </returns>
        /// <remarks>
        /// 1.  Must ensure the name of all classes generated cards and groups don't clash.
        /// 2.  Must ensure that all properties accessing child group instances in card class don't clash with base class.
        /// 3.  Must ensure that all properties for each group class don't clash with base class.
        /// </remarks>
        //
        //*********************************************************        
        public static bool CheckForTypedInstNameClash(RepPP.Application     app,
                                                      ArrayList             arrCardNames,
                                                      ArrayList             arrGroupNames,
                                                      string                strBaseCardClass,
                                                      string                strBaseGroupClass,
                                                      string                strCrdClsPrefix,
                                                      string                strGrpClsPrefix,
                                                      string                strGrpPropPrefix,
                                                      string                strFldPropPrefix,
                                                      bool                  bChekForWS) {
            bool                        bRetVal;
            TypedInstanceGenBase        generator;
            RepPP.Card[]                arrCards;
            RepPP.Group[]               arrGroups;
            int                         iIndex;
            string                      strName;
            frmTypedInstNameClashLog    frmLog;

            using (frmLog = new frmTypedInstNameClashLog()) {
                if (bChekForWS && 
                    (strCrdClsPrefix.StartsWith("WS")  || 
                     strGrpClsPrefix.StartsWith("WS")  ||
                     strGrpPropPrefix.StartsWith("WS") ||
                     strGrpPropPrefix.StartsWith("WS")) ) {
                    frmLog.MessageText = "WS is a reserved prefix. Using this prefix can cause name clash.";
                    bRetVal = false;

                } else {
                    arrCards = new Card[arrCardNames.Count];
                    for (iIndex = 0; iIndex < arrCardNames.Count; iIndex++) {
                        strName          = arrCardNames[iIndex].ToString();
                        arrCards[iIndex] = app.Cards[strName];
                    }
                    arrGroups = new Group[arrGroupNames.Count];
                    for (iIndex = 0; iIndex < arrGroupNames.Count; iIndex++) {
                        strName           = arrGroupNames[iIndex].ToString();
                        arrGroups[iIndex] = app.Groups[strName];
                    }
                    generator = new TypedInstanceGenForCS();
                    bRetVal = generator.CheckForNameClash(frmLog,
                                                          arrCards,
                                                          arrGroups,
                                                          typeof(RepPP.TypedCardInstanceBase),
                                                          typeof(RepPP.TypedGroupInstanceBase),
                                                          strCrdClsPrefix,
                                                          strGrpClsPrefix,
                                                          strGrpPropPrefix,
                                                          strFldPropPrefix);
                }
                if (!bRetVal) {
                    frmLog.ShowDialog();
                }
            }
            return(bRetVal);
        }

        //*********************************************************     
        //
        /// <summary>
        /// GenTyedInstParam:     Class to define typed instances generation parameters      
        /// </summary>
        //  
        //*********************************************************    
        internal class GenTypedInstParam {
            public  GenTypedInstTypeE   m_eGenType;
            public  string              m_strNamespace;
            public  string              m_strRootNamespace;
            public  string              m_strCardInstBaseClass;
            public  string              m_strGroupInstBaseClass;
            public  string              m_strCardInstClassPrefix;
            public  string              m_strGroupInstClassPrefix;
            public  string              m_strGroupInstPropPrefix;
            public  string              m_strFieldPropPrefix;

            //*********************************************************     
            //
            /// <summary>
            /// ctor      
            /// </summary>
            /// <param name="eGenType">                 Generation type</param>
            /// <param name="strNamespace">             Namespace of the generated types</param>
            /// <param name="strRootNamespace">         Root namespace used if no namespace is defined for the typed instances</param>
            /// <param name="strCardInstBaseClass">     Base class for card typed instances</param>
            /// <param name="strGroupInstBaseClass">    Base class for group typed instances</param>
            /// <param name="strCardInstClassPrefix">   Prefix of the yped card instance class name</param>
            /// <param name="strGroupInstClassPrefix">  Prefix of the typed group instance class name</param>
            /// <param name="strGroupInstPropPrefix">   Prefix of the group instance property name</param>
            /// <param name="strFieldPropPrefix">       Prefix of the field property name</param>
            //  
            //*********************************************************                
            public GenTypedInstParam(GenTypedInstTypeE   eGenType,
                                     string              strNamespace,
                                     string              strRootNamespace,
                                     string              strCardInstBaseClass,
                                     string              strGroupInstBaseClass,
                                     string              strCardInstClassPrefix,
                                     string              strGroupInstClassPrefix,
                                     string              strGroupInstPropPrefix,
                                     string              strFieldPropPrefix) {
                m_eGenType                  = eGenType;
                m_strNamespace              = strNamespace;
                m_strRootNamespace          = strRootNamespace;
                m_strCardInstBaseClass      = strCardInstBaseClass;
                m_strGroupInstBaseClass     = strGroupInstBaseClass;
                m_strGroupInstBaseClass       = strGroupInstBaseClass;
                m_strCardInstClassPrefix      = strCardInstClassPrefix;
                m_strGroupInstClassPrefix     = strGroupInstClassPrefix;
                m_strGroupInstPropPrefix      = strGroupInstPropPrefix;
                m_strFieldPropPrefix          = strFieldPropPrefix;
            }
        } // Class GenTypedInstParam
    } // Class Utility
} // Namespace