using System;
using System.Collections;
using System.Windows.Forms;
using RepPP;
using EnvDTE;
using System.Xml;
using System.IO;
using Microsoft.Win32;
using RepPP.Toolkit;
using RepPP.VSNetWizard;

namespace RepPP.VSNetWizard.Windows
{
	/// <summary>
	/// Summary description for WinGeneratorBase.
	/// </summary>
	internal class WinGeneratorBase
	{
	    // Constants
	    protected const int                     HORIZ_MARGE_SPACE    = 12;       // Margin espace on point
        protected const int                     VERT_MARGE_SPACE     = 12;       // Margin espace on point
	    protected const double                  POINTS_PER_CHAR      = 5.6;      // Points per char
	    protected const int                     MAX_STAT_WIDTH       = 200;      // Max static field width
	    protected const int                     FORM_WIDTH           = 500;      // The form width
	    protected const int                     TAB_NAME_HEIGHT      = 26;       // Tab name height
	    protected const int                     ALL_CHILD            = - 1;      // All child
	    protected const int                     DEFAULT_CTL_HEIGHT   = 22;       // Default rep++ control height
	    protected const int                     DEFAULT_RADIO_HEIGHT = 16;       // Default height for a radio button or check box (one item)
	    protected const int                     DEFAULT_LIST_HEIGHT  = 60;       // Default rep++ control list height
	    protected const int                     DEFAULT_GRID_HEIGHT  = 150;      // Default grid height
	    // Variables
//	    protected DTE                   m_oDTE;                          // The DTE object
        protected EnvDTE.DTE                    m_vsApp;                         // Visual studio instance object
	    protected RepPP.IApplication            m_oRepPP;                        // The rep++ object
	    protected Label                         m_lblStatus;                     // The status label in the form wizard
	    protected int                           m_iTabIndex;                     // The tab index for the next control added to the current form
	    protected bool                          m_bUseDotNetBar      = false;    // Use or not .Net Bar if generated forms
	    protected Utility.GenTypedInstParam     m_genTypedInstParam;             // Generate typed instances parameters
        protected ArrayList                     m_arrFormName        = null;     // Array of generated form names
        public WinGeneratorBase()
		{
		}

        //**********************************************************************
        //
        // Constructor
        //   In: 
        //       vsApp       :   Visual studio application</param>
        //       app         :   Rep++ application object</param>
        //       VSInst      :   DTE
        //       oRep        :   The Rep++ Application
        //       lblStatus   :   Status label  
        //       bUseBar     :   True to use .Net Bar components
        //       bGenWrapper :   True to generate group instance wrapper
        //   Returns:
        //
        //**********************************************************************
        public WinGeneratorBase(EnvDTE.DTE                  vsApp,
                                RepPP.IApplication          oRep,
                                Label                       lblStatus, 
                                bool                        bUseBar,
                                Utility.GenTypedInstParam   genTypedInstParam) {

            m_vsApp             = vsApp;
            m_oRepPP            = oRep;
            m_lblStatus         = lblStatus;
            m_bUseDotNetBar     = bUseBar;
            m_genTypedInstParam = genTypedInstParam;
            m_arrFormName       = new ArrayList();
        }

        //**********************************************************************
        //
        // Create New Project and set references
        //   In: 
        //       strProjectDir :     The project directory
        //       strProjectName:     The project name
        //   Returns:
        //       The created project
        //
        //**********************************************************************
        protected virtual Project CreateProject(string strProjectDir, string strProjectName) {
            return null;
        }

        //**********************************************************************
        //
        /// <summary>
        /// AddRepPPRefToProject:           Add a rep++ reference to the project
        /// </summary>
        /// <param name="prj">              The project</param>
        /// <param name="strBinPath">       Rep++ bin path name</param>
        /// <param name="strRefName">       Reference name</param>
        /// <returns>
        /// True:   Reference added
        /// False:  Error
        /// </returns>
        //
        //**********************************************************************
        private bool AddRepPPRefToProject(VSLangProj.VSProject prj, string strBinPath, string strRefName) {
            bool    bRetVal = true;
            string  strDllPath;

		    if (prj.References.Find(strRefName) == null) {
			    strDllPath = Path.Combine(strBinPath, strRefName + ".dll");
                if (File.Exists(strDllPath)) {
			        prj.References.Add(strDllPath);
                } else {
                    bRetVal = false;
                    MessageBox.Show("Rep++ dll not found: " + strDllPath,
                                    "Rep++ Windows Wizard", 
                                    MessageBoxButtons.OK,
                                    MessageBoxIcon.Error);
                }
		    }
            return(bRetVal);
        }

        //**********************************************************************
        //
        // Initalize Project references and imports
        //   In: 
        //       strProjectName:     The project name
        //       bUseSelectBuffer:   True to use a selection buffer
        //   Returns:
        //
        //**********************************************************************
        protected bool InitProject(string strProjectname, bool bUseSelectBuffer) {
            bool                    bRetVal = true;
	        Project                 oPrj;
	        VSLangProj.VSProject    oVSPrj;
	        string                  strBinFolder;

	        oPrj = GetProject(strProjectname);
            if (m_genTypedInstParam.m_eGenType != Utility.GenTypedInstTypeE.None) {
                Utility.AddAssemblyAttribute(oPrj, 
                                             "RepPP.AssemblyIncludeTypes",
                                             GetLanguage() == 0 ? ".vb" : ".cs");
            }
	        oVSPrj = (VSLangProj.VSProject)oPrj.Object;
	        // Add references
	        if (GetLanguage() == 0 && oVSPrj.References.Find("Microsoft.VisualBasic") == null) {
		        oVSPrj.References.Add("Microsoft.VisualBasic");
	        }
	        if (oVSPrj.References.Find("System") == null) {
		        oVSPrj.References.Add("System");
	        }
	        if (oVSPrj.References.Find("System.Data") == null) {
		        oVSPrj.References.Add("System.Data");
	        }
	        if (oVSPrj.References.Find("System.Drawing") == null) {
		        oVSPrj.References.Add("System.Drawing");
	        }
	        if (oVSPrj.References.Find("System.Windows.Forms") == null) {
		        oVSPrj.References.Add("System.Windows.Forms");
	        }
	        // GPC4212
	        // Use the version of the framework and the toolkit without it being in the GAC
            strBinFolder = Utility.GetRepPPBinDir();
            if (strBinFolder != String.Empty) {
			    // GPC4592: Add the reference to sddnet using the full pathname
                bRetVal = AddRepPPRefToProject(oVSPrj, strBinFolder, "sddnet");
                if (bRetVal) {
                    bRetVal = AddRepPPRefToProject(oVSPrj, strBinFolder, "RepPP.Toolkit.V1");
                    if (bRetVal) {
                        bRetVal = AddRepPPRefToProject(oVSPrj, strBinFolder, "RepPP.Framework.Window.V2");
                    }
                }
                //if (bUseSelectBuffer && m_bUseDotNetBar) {
                //    if (oVSPrj.References.Find("RepPP.Toolkit.Ext") == null) {
                //        strDllName = Path.Combine(strBinFolder, "RepPP.Toolkit.Ext.V1.dll");
                //        oVSPrj.References.Add(strDllName);
                //    }
                //    if (oVSPrj.References.Find("RepPP.Framework.Window.Ext") == null) {
                //        strDllName = Path.Combine(strBinFolder, "RepPP.Framework.Window.Ext.V1.dll");
                //        oVSPrj.References.Add(strDllName);
                //    }
                //    if (oVSPrj.References.Find("DevComponents.DotNetBar") == null) {
                //        strDllName = "DevComponents.DotNetBar.dll";
                //        oVSPrj.References.Add(strDllName);
                //    }
                //}
			    // Add imports
			    if (bRetVal && oVSPrj.Imports != null) {
				    if (!FindImport(oVSPrj, "RepPP.Framework.Window")) {
					    oVSPrj.Imports.Add("RepPP.Framework.Window");
				    }
				    if (!FindImport(oVSPrj, "RepPP.Toolkit")) {
					    oVSPrj.Imports.Add("RepPP.Toolkit");
				    }
				    if (!FindImport(oVSPrj, "RepPP")) {
					    oVSPrj.Imports.Add("RepPP");
				    }
				    if (!FindImport(oVSPrj, "System.Collections")) {
					    oVSPrj.Imports.Add("System.Collections");
				    }
				    if (!FindImport(oVSPrj, "System.Data")) {
					    oVSPrj.Imports.Add("System.Data");
				    }
				    if (!FindImport(oVSPrj, "System.Diagnostics")) {
					    oVSPrj.Imports.Add("System.Diagnostics");
				    }
				    if (!FindImport(oVSPrj, "System.Drawing")) {
					    oVSPrj.Imports.Add("System.Drawing");
				    }
				    if (!FindImport(oVSPrj, "System.Windows.Forms")) {
					    oVSPrj.Imports.Add("System.Windows.Forms");
				    }
                    //if (bUseSelectBuffer && m_bUseDotNetBar) {
                    //    if (!FindImport(oVSPrj, "RepPP.Toolkit.Window.Ext")) {
                    //        oVSPrj.Imports.Add("RepPP.Toolkit.Window.Ext");
                    //    }
                    //    if(!FindImport(oVSPrj, "DevComponents.DotNetBar")) {
                    //        oVSPrj.Imports.Add("DevComponents.DotNetBar");
                    //    }
                    //}
                }
	        } else {
                bRetVal = false;
		        MessageBox.Show("Rep++ isn't installed in this machine");
	        }
            return(bRetVal);
        }

        //**********************************************************************
        //
        // Check if the namespace is imported in the project
        //   In: 
        //       oVsPrj   :    The project nobject
        //       strImport:    The namespace
        //   Returns:
        //       The created project
        //
        //**********************************************************************
        private bool FindImport(VSLangProj.VSProject oVsPrj, string strImport) {
	        bool bRetVal;

	        bRetVal = false;
	        foreach (string strItem in oVsPrj.Imports) {
		        if (strItem == strImport) {
			        bRetVal = true;
			        break;
		        }
	        }
	        return bRetVal;
        }

        //**********************************************************************
        //
        // Create Rep++ Application
        //   In: 
        //       strProjectDir  :    The project directory
        //       strProjectName :    The project name
        //       oRootNode      :    The Root Node of the configurated TreeView
        //   Returns:
        //
        //**********************************************************************
        public bool CreateApplication(string    strProjectDir,             
                                      string    strProjectName, 
                                      TreeNode  oRootNode) {
            bool    bRetVal = true;

	        try {
		        if (CreateProject(strProjectDir, strProjectName) != null) {
			        bRetVal = AddCardForm(strProjectName, oRootNode);
		        } else {
                    bRetVal = false;
                }
	        } catch(System.Exception ex) {
                bRetVal = false;
		        MessageBox.Show(ex.ToString(), "Rep++ Wizard");
	        }
            return(bRetVal);
        }

        //**********************************************************************
        //
        // Add a selection buffer form to the project
        //   In: 
        //       strProjectName :    The project name
        //       strCardName :       The Card name
        //       strSBFormName  :    The selection buffer form name
        //       strSBCardName  :    The selection buffer card name
        //       strChildFormName :  The child form name
        //       strClassWrapName:   The wrapper class name for the card instance
        //   Returns:
        //
        //**********************************************************************
        protected virtual void AddMainSBForm(string strProjectName,
                                             string strCardName,
                                             string strSBFormName,
                                             string strSBCardName,
                                             string strChildFormName,
                                             string strClassWrapName) 
        {
        }

        //**********************************************************************
        //
        /// <summary>
        /// SetTypedInstNamespace:          Set the namespace for the typed instances
        /// </summary>
        /// <param name="strProjectName">   Project Name</param>
        //
        //**********************************************************************
        protected virtual void SetTypedInstNamespace(string strProjectName) {
        }

        //**********************************************************************
        //
        // Add Card Form to the project
        //   In: 
        //       strProjectName :    The project name
        //       oRootNode      :    The Root Node of the configurated TreeView
        //   Returns:
        //
        //**********************************************************************
        public bool AddCardForm(string strProjectName, TreeNode oRootNode) {
            bool        bRetVal = true;
	        string      strFormName;
	        string      strPureFormName;
	        string      strCtlName;
	        int         iHeight;
	        string      strCardName;
	        bool        bUseSelectBuffer;
	        string      strMainPanelName;
	        string      strClassWrapName;
            RepPP.Card  crd;

	        try {
                SetTypedInstNamespace(strProjectName);
		        // init project references and imports
                bUseSelectBuffer = ((string)((object[])oRootNode.Tag)[11]) != "";
		        bRetVal          = InitProject(strProjectName, bUseSelectBuffer);
                if (bRetVal) {
                    Utility.UpdateInfoResxFile(m_vsApp, strProjectName, m_oRepPP, false);
		            strFormName = ((Object[]) oRootNode.Tag)[1].ToString();
		            strFormName = GetUniqueFormName(strProjectName, strFormName);    

                    crd         = ((RepPP.CardGroup)((object[])oRootNode.Tag)[0]).Card;
                    strCardName = crd.Name;
                    if (m_genTypedInstParam.m_eGenType != Utility.GenTypedInstTypeE.None) {
                        if (m_genTypedInstParam.m_strNamespace != String.Empty) {
		                    strClassWrapName = m_genTypedInstParam.m_strNamespace + "." + m_genTypedInstParam.m_strCardInstClassPrefix + crd.ClassName;
                        } else {
                            strClassWrapName = m_genTypedInstParam.m_strCardInstClassPrefix + crd.ClassName;
                        }
                    } else {
                        strClassWrapName = "";
                    }
		            // Add Form to the project
		            AddForm(strProjectName, 
                            strFormName, 
                            ((Object[])oRootNode.Tag)[4].ToString(), 
                            new object[] {"AutoScaleBaseSize", "ClientSize", "Name"}, 
                            new object[] {"Object", "Object", "String"},
                            new object[] {"Size(5, 13)", "Size(500, 300)", 
                            strFormName});
		            // Add Rep++ info component to the form
		            strCtlName = "repInfo";
		            AddControl(strProjectName, 
                               strFormName, 
                               strCtlName, 
                               "RepPP.RepPPInfo", 
                               null, 
                               null,
                               null);
		            if (m_lblStatus != null) {
			            m_lblStatus.Text = "";
		            }
		            strPureFormName = ((strFormName.Length > 3 && strFormName.Substring(0, 3) == "frm") ? strFormName.Substring(3) : strFormName);
		            if (!bUseSelectBuffer) {
			            // Add frame for the root group
			            strCtlName = GetUniqueCtlName(strProjectName, 
                                                      strFormName, 
                                                      "grp" + strPureFormName);
			            AddControl(strProjectName, 
                                   strFormName, 
                                   strCtlName, 
                                   "GroupBox", 
                                   new object[] {"FlatStyle", "Location", "Name", "Text", "Size"}, 
                                   new object[] {"Integer", "Object", "String", "String", "Object"}, 
                                   new object[] {"FlatStyle.System", "Point(12, 56)", strCtlName, strPureFormName, "Size(476, 232)"});
			            strMainPanelName = strCtlName;
		            } else {
			            // Add the main form if a selection buffer must be used
			            AddMainSBForm(strProjectName, 
                                      strCardName, 
                                      strFormName + "Main", 
                                      ((Object[])oRootNode.Tag)[11].ToString(), 
                                      strFormName, 
                                      strClassWrapName);
			            if (m_bUseDotNetBar) {
				            // Add DotNetBat XML file(frmBaseSBEditor.dotNetBarManagerMain.xml)
				            AddDNetBarXMLFile(strProjectName);
			            }
			            // Add panel main
			            AddControl(strProjectName, 
                                   strFormName,
                                   "panelMain",
                                   "Panel",
                                   new object[] {"Name", "Dock", "Size", "AutoScroll"},
                                   new object[] {"String", "Integer", "Object", "Integer"},
                                   new object[] {"panelMain", "System.Windows.Forms.DockStyle.Fill", "Size(476, 232)", "true"},
                                   null, 
                                   "Controls",
                                   "Control",
                                   true);
			            strMainPanelName = "panelMain";
		            }
		            AddBeginFormCode(strProjectName, 
                                     strFormName, 
                                     ((Object[])oRootNode.Tag)[4].ToString(), 
                                     strCardName, 
                                     bUseSelectBuffer, 
                                     strClassWrapName);
		            // set root Group flag to false to not generate card group clean up code
		            iHeight = GenerateGroup(strProjectName, 
                                            strFormName, 
                                            oRootNode, 
                                            strMainPanelName, 
                                            false, 
                                            bUseSelectBuffer);
		            // Update Form's height
		            SetProperty(strProjectName, 
                                strFormName, 
                                "", 
                                "ClientSize", 
                                "Object", 
                                "Size(" + FORM_WIDTH + ", " + (iHeight + 64 + 24) + ")");
		            // Add typed instance for the card instance
		            if (m_genTypedInstParam.m_eGenType != Utility.GenTypedInstTypeE.None) {
                        GenCardTypedInstance(strProjectName, strCardName);                
		            }
		            if (m_lblStatus != null) {
			            m_lblStatus.Text = "";
		            }
                }
	        } catch (System.Exception ex) {
                bRetVal = false;
		        MessageBox.Show(ex.ToString(), "Rep++ Wizard");
	        }
            if (bRetVal) {
                SaveForms(strProjectName);
            }
            return(bRetVal);
        }

        //**********************************************************************
        //
        // Add Group Form to the project
        //   In: 
        //       strProjectName :    The project name
        //       oNode          :    The Root Node of the configurated TreeView
        //   Returns:
        //
        //**********************************************************************
        public bool AddGroupForm(string strProjectName, TreeNode oNode) {
            bool    bRetVal = true;
	        string  strFormName;
	        string  strCtlName;
	        int     iHeight;
	        string  strGridName = "";
	        string  strPureFormName;

	        try {
                SetTypedInstNamespace(strProjectName);
		        // init project references and imports
		        bRetVal = InitProject(strProjectName, false);
                if (bRetVal) {
                    Utility.UpdateInfoResxFile(m_vsApp, strProjectName, m_oRepPP, false);
		            strFormName = ((Object[])oNode.Tag)[1].ToString();
		            strFormName = GetUniqueFormName(strProjectName, strFormName);
		            // Add Form to the project
		            AddForm(strProjectName, 
                            strFormName, 
                            ((Object[])oNode.Tag)[4].ToString(), 
                            new object[] {"AutoScaleBaseSize", "ClientSize", "Name"}, 
                            new object[] {"Object", "Object", "String"}, 
                            new object[] {"Size(5, 13)", "Size(500, 300)", 
                            strFormName});
		            // Add Rep++ info component to the form
                    AddControl(strProjectName, 
                               strFormName, 
                               "repInfo", 
                               "RepPP.RepPPInfo", 
                               null, 
                               null,
                               null);
		            // Add frame for the root group
		            strPureFormName = ((strFormName.Length > 3 && strFormName.Substring(0, 3) == "frm") ? strFormName.Substring(3):strFormName);
		            strCtlName = GetUniqueCtlName(strProjectName, 
                                                  strFormName, 
                                                  "grp" + strPureFormName);
		            AddControl(strProjectName, 
                               strFormName, 
                               strCtlName, 
                               "GroupBox", 
                               new object[] {"FlatStyle", "Location", "Name", "Text", "Size"}, 
                               new object[] {"Integer", "Object", "String", "String", "Object"}, 
                               new object[] {"FlatStyle.System", "Point(12, 28)", strCtlName, strPureFormName, "Size(476, 232)"});
		            if ((int)((object[])oNode.Tag)[2] == 0) {
			            iHeight = AddRepPPFldGroup(strProjectName, 
                                                   strFormName,
                                                   (((RepPP.Group)((object[])oNode.Tag)[0])).Name, 
                                                   strCtlName, 
                                                   476, 
                                                   new object[] {((Object[])oNode.Tag)[6], ((Object[])oNode.Tag)[7], ((Object[])oNode.Tag)[8], ((Object[])oNode.Tag)[9], ((Object[])oNode.Tag)[10]},
                                                   false);
		            } else if ((int)((object[])oNode.Tag)[2] == 1) {
			            iHeight = AddGridGroup(strProjectName, 
                                               strFormName,
                                               "",
                                               (((RepPP.Group)((object[])oNode.Tag)[0])).Name, 
                                               strCtlName, 
                                               476,
                                               (int)((object[])oNode.Tag)[10],
                                               ref strGridName);
                                               
		            } else {
			            iHeight = AddRepPPTkFldGroup(strProjectName, 
                                                     strFormName, 
                                                     (((RepPP.Group)((object[])oNode.Tag)[0])).Name, 
                                                     strCtlName, 
                                                     476, 
                                                     new object[] {((Object[])oNode.Tag)[6], ((Object[])oNode.Tag)[7], ((Object[])oNode.Tag)[8], ((Object[])oNode.Tag)[9], ((Object[])oNode.Tag)[10]});
		            }
		            // Update frame's height
		            SetProperty(strProjectName, 
                                strFormName, 
                                strCtlName, 
                                "Size", 
                                "Object", 
                                "Size(476, " + iHeight + ")");
		            // Update form's height
		            SetProperty(strProjectName, 
                                strFormName, 
                                "", 
                                "ClientSize", 
                                "Object", 
                                "Size(" + FORM_WIDTH + ", " + (iHeight + (2 * VERT_MARGE_SPACE)) + ")");
		            if (m_genTypedInstParam.m_eGenType != Utility.GenTypedInstTypeE.None) {
                        GenGroupTypedInstance(strProjectName, ((RepPP.Group)((Object[])oNode.Tag)[0]).Name);
		            }
                }
	        } catch (System.Exception ex) {
                bRetVal = false;
		        MessageBox.Show(ex.ToString(), "Rep++ Wizard");
	        }
            if (bRetVal) {
                SaveForms(strProjectName);
            }
            return(bRetVal);
        }

        //**********************************************************************
        //
        /// <summary>
        /// SaveForms:                      Save generated forms
        /// </summary>
        /// <param name="strProjectName">   Project name</param>
        //
        //**********************************************************************        
        private void SaveForms(string strProjectName) {
#if VC8
            Project         prj;
            ProjectItem     item;
            
            try {
                prj = GetProject(strProjectName);
                prj.SaveAs(prj.FullName);
                foreach (string strFormName in m_arrFormName) {
                    item = Utility.FindProjectItem(prj, strFormName);
                    //item.Open("{7651A701-06E5-11D1-8EBD-00A0C90F26EA}");
                    item.Open("{7651A702-06E5-11D1-8EBD-00A0C90F26EA}");
                    //item.SaveAs(item.get_FileNames(0));
                    item.Save(item.get_FileNames(0));
                    item.Document.Close(EnvDTE.vsSaveChanges.vsSaveChangesNo);
                }
                VSLangProj.VSProject vsprj = prj.Object as VSLangProj.VSProject;
                vsprj.Refresh();
            } catch {
            }
#endif
        }

        //**********************************************************************
        //
        // Generate Group 
        //   In: 
        //       strProjectName:        The project name
        //       strFormName:           The card name corresponding to the project
        //       oNode:                 Card's Node of the configurated TreeView
        //       strParentName:         The Group Box or the Tab Page in which the 
        //                              fiels of the card should be generated
        //       bIsInPopupChildForm:   Indicates if the current form is a popup child form
        //       bUseSelectBuffer:      True to indicates that a selection buffer is used
        //   Returns:
        //       The necessary height to design the Group fields in the form 
        //
        //**********************************************************************
        private int GenerateGroup(string    strProjectName,
                                  string    strFormName,
                                  TreeNode  oNode,
                                  string    strFatherName,
                                  bool      bIsInPopupChildForm,
                                  bool      bUseSelectBuffer) {
            int         iRetVal             = 0;
            RepPP.Group oGroup;
            int         iXFather            = 0;
            int         iYFather            = 0;
            string      strTmp;
            string      strGrpName;
            string      strCtlName;
            string      strGridName         = "";
            int         iGroupHeight        = 0;
            string      strNewFormName      = "";
            string      strFatherCrdGrpCtl;
            int         iIndex;
            int         iHeight;
            string      strToolbarSize;
            string      strCardName;

            strTmp = GetProperty(strProjectName, 
                                 strFormName, 
                                 strFatherName, 
                                 "Size");
            if (strTmp != "") {
                BreakUpSize(strTmp, 
                            ref iXFather, 
                            ref iYFather);
                iRetVal = iYFather;
            }
            strGrpName  = ((RepPP.CardGroup)((object[])oNode.Tag)[0]).Group.Name;
            strCardName = ((RepPP.CardGroup)((object[])oNode.Tag)[0]).Card.Name;
            if (m_lblStatus != null) {
                m_lblStatus.Text = "Generating " + strGrpName + " card group...";
                System.Windows.Forms.Application.DoEvents();
            }
            oGroup = m_oRepPP.Groups.Find(strGrpName);
            if (oGroup == null) {
                MessageBox.Show("Unable to find the group '" + strGrpName + "'");
            } else {
                // Add card group Control
                strCtlName = GetUniqueCtlName(strProjectName, strFormName, "toolbar" + strGrpName);
                ((Object[])oNode.Tag)[5] = "m_cgrpHandler" + strGrpName;
                if ((int)((object[])oNode.Tag)[10] == 0) {
                    iHeight = 24;
                    strToolbarSize = "RepPP.Framework.Window.CardGroupToolbar.ToolBarSize.Small";
                } else {
                    iHeight = 38;
                    strToolbarSize = "RepPP.Framework.Window.CardGroupToolbar.ToolBarSize.Big";
                }
                AddControl(strProjectName, 
                           strFormName, 
                           strCtlName, 
                           "RepPP.Framework.Window.CardGroupToolbar",
                            new object[] {"ToolBarButtonSize", "AutoSize", "Location", "Name", "Size", "TabStop"},
                            new object[] {"Integer", "Integer", "Object", "String", "Object", "Integer"}, 
                            new object[] {strToolbarSize, "false", "Point(16, 16)", strCtlName, "Size(320, " + iHeight + ")", "false"},
                            strFatherName);
                if (oNode.Parent != null) {
                    // check if the child and the father card group control are in the
                    // same form
                    if ((int)((object[])oNode.Parent.Tag)[3] == 0) {
                        strFatherCrdGrpCtl = ((Object[])oNode.Parent.Tag)[5].ToString();
                    } else {
                        strFatherCrdGrpCtl = "";
                    }
                } else {
                    strFatherCrdGrpCtl = "";
                }
                if ((int)((object[])oNode.Tag)[2] == 0) {    // Represent with RepPPField and RepPPStat control
                    iGroupHeight = AddRepPPFldGroup(strProjectName,
                                                    strFormName,
                                                    strGrpName,
                                                    strFatherName,
                                                    iXFather,
                                                    new object[] {((Object[])oNode.Tag)[6], ((Object[])oNode.Tag)[7], ((Object[])oNode.Tag)[8], ((Object[])oNode.Tag)[9], ((Object[])oNode.Tag)[10]},
                                                    false);
                    AddCardGroupInitCode(strProjectName,
                                            strFormName,
                                            strCtlName,
                                            strGrpName,
                                            strFatherCrdGrpCtl,
                                            "",
                                            bIsInPopupChildForm,
                                            oNode.Index,
                                            bUseSelectBuffer);
                } else if ((int)((object[])oNode.Tag)[2] == 1) {    // Represent with a datagrid
                    iGroupHeight = AddGridGroup(strProjectName, 
                                                strFormName,
                                                strCardName,
                                                strGrpName, 
                                                strFatherName, 
                                                iXFather, 
                                                (int)((object[])oNode.Tag)[10],
                                                ref strGridName);
                   AddCardGroupInitCode(strProjectName,
                                            strFormName, 
                                            strCtlName, 
                                            strGrpName, 
                                            strFatherCrdGrpCtl, 
                                            strGridName, 
                                            bIsInPopupChildForm, 
                                            oNode.Index, 
                                            bUseSelectBuffer);
                } else {   // Represent with SCFld??? controls
                    iGroupHeight = AddRepPPTkFldGroup(strProjectName,
                                                        strFormName, 
                                                        strGrpName, 
                                                        strFatherName, 
                                                        iXFather, 
                                                        new object[] {((Object[])oNode.Tag)[6], ((Object[])oNode.Tag)[7], ((Object[])oNode.Tag)[8], ((Object[])oNode.Tag)[9], ((Object[])oNode.Tag)[10]});
                    AddCardGroupInitCode(strProjectName,
                                         strFormName, 
                                         strCtlName,
                                         strGrpName,
                                         strFatherCrdGrpCtl,
                                         "", 
                                         bIsInPopupChildForm,
                                         oNode.Index,
                                         bUseSelectBuffer);
                }
            }
            // Add child card group
            if (oNode.Nodes.Count > 0) {
                switch ((int)((object[])oNode.Tag)[3]) {
                case 0 : // Same form
                    iRetVal = iGroupHeight + VERT_MARGE_SPACE + AddChildGroup(strProjectName, 
                                                                              strFormName, 
                                                                              oNode, 
                                                                              ALL_CHILD, 
                                                                              strFatherName, 
                                                                              iGroupHeight, 
                                                                              iXFather, 
                                                                              bIsInPopupChildForm, 
                                                                              bUseSelectBuffer);
                    break;
                case 1:  // A new form for all - One button
                    strTmp = ((RepPP.CardGroup)((object[])oNode.Nodes[0].Tag)[0]).Group.Name;
                    for (iIndex = 0; iIndex < oNode.Nodes.Count - 1; iIndex++) {
                        strTmp = strTmp + "-" + ((RepPP.CardGroup)((object[])oNode.Nodes[iIndex].Tag)[0]).Group.Name;
                    }
                    strCtlName = GetUniqueCtlName(strProjectName, strFormName, "btnChild");
                    AddControl(strProjectName, strFormName, strCtlName, "Button",
                               new object[] {"Location", "Name", "Size", "Text"},
                               new object[] {"Object", "String", "Object", "String"},
                               new object[] {"Point(" + (iXFather - (HORIZ_MARGE_SPACE + 96)) + ", " + iGroupHeight + ")", strCtlName, "Size(96, 24)", strTmp},
                               strFatherName);
                    AddAllChildToNewForm(strProjectName, 
                                         oNode, 
                                         ref strNewFormName, 
                                         bUseSelectBuffer);
                    // Add a call to the child form
                    AddCallToChildForm(strProjectName, 
                                       strFormName, 
                                       strNewFormName, 
                                       strCtlName, 
                                       ((object[])oNode.Tag)[5].ToString(), 
                                       bUseSelectBuffer, 
                                       IsMainFormB(oNode));
                    iRetVal = iGroupHeight + 24 + VERT_MARGE_SPACE;
                    break;
                case 2: // A new form for each - n buttons
                    object[] aChildFormNames = new object[oNode.Nodes.Count];
                    AddEachChildToNewForm(strProjectName, 
                                          oNode, 
                                          ref aChildFormNames, 
                                          bUseSelectBuffer);
                    for (iIndex = 0; iIndex < oNode.Nodes.Count; iIndex++) {
                        // Add button to call child form
                        strTmp     = ((RepPP.CardGroup)((object[])oNode.Nodes[iIndex].Tag)[0]).Group.Name;
                        strCtlName = GetUniqueCtlName(strProjectName, strFormName, "btnChild");
                        AddControl(strProjectName, strFormName, strCtlName, "Button", 
                                   new object[] {"Location", "Name", "Size", "Text"}, 
                                   new object[] {"Object", "String", "Object", "String"}, 
                                   new object[] {"Point(" + (iXFather - (iIndex + 1) * (HORIZ_MARGE_SPACE + 96)) + ", " + iGroupHeight + ")", strCtlName, "Size(96, 24)", strTmp},
                                   strFatherName);
                        // Add a call to the child form (button_click)
                        AddCallToChildForm(strProjectName, 
                                           strFormName, 
                                           aChildFormNames[iIndex].ToString(), 
                                           strCtlName, 
                                           ((object[])oNode.Tag)[5].ToString(), 
                                           bUseSelectBuffer, 
                                           IsMainFormB(oNode));
                    }
                    iRetVal = iGroupHeight + 24 + VERT_MARGE_SPACE;
                    break;
                case 3: // A new form for all on dblclick line - nothing visual
                    break;
                }
            } else {
                iRetVal = iGroupHeight;
            }
            // Update father's height
            SetProperty(strProjectName, 
                        strFormName, 
                        strFatherName,
                        "Size",
                        "Object",
                        "Size(" + iXFather + ", " + iRetVal + ")");
            return iRetVal;
        }

        //**********************************************************************
        //
        // Check if the form specified by the node is the main project form
        //   In: 
        //       nodeForm:   treenode
        //   Returns:
        //       True:
        //       False:
        //
        //**********************************************************************
        private bool IsMainFormB(TreeNode nodeForm)
        {
	        bool        bRetVal;
	        TreeNode    node;

	        node = nodeForm.Parent;
	        bRetVal = true;
	        while(( node != null ) && bRetVal) {
		        bRetVal = ((int)((object[])node.Tag)[3] == 0);
		        node = node.Parent;
	        }
	        return(bRetVal);
        }

        //**********************************************************************
        //
        // Add a code to call child form from the parent form
        //   In: 
        //       strProjectName :    The project name
        //       strFormName    :    The parent form name
        //       strChildform   :    The child form name
        //       strBtnNam      :    The button control name
        //       strCrdgrpFather:    The father card group control name
        //                           it's used to initialize the child card group control
        //       bUseSelectBuffer:   True to generate project or forms with selection buffer
        //       bInMainForm:        True to indicates that the call is in the main form
        //   Returns:
        //       The necessary height to design the Group fields in the form 
        //
        //**********************************************************************
        public virtual void AddCallToChildForm(string strProjectName, 
                                               string strFormName, 
                                               string strChildName, 
                                               string strBtnName, 
                                               string strCrdgrpFather, 
                                               bool   bUseSelectBuffer, 
                                               bool   bInMainForm)
        {
        }

        //**********************************************************************
        //
        // Add all child to a new form
        //   In: 
        //       strProjectName :    The project name
        //       oFatherNode    :    Father Card's Node of the configurated TreeView
        //       strFormName    :    [out] the new form name
        //   Returns:
        //
        //**********************************************************************
        private void AddAllChildToNewForm(string     strProjectName, 
                                          TreeNode   oFatherNode, 
                                          ref string strFormName, 
                                          bool       bUseSelectBuffer)
        {
	        string          strBaseFormName;
	        int             iChildHeight;
	        int             iIndex;
	        string[]        arrCardName;
	        RepPP.CardGroup crdgrp;

	        strFormName     = ((object[])oFatherNode.Nodes[0].Tag)[1].ToString();
	        strFormName     = GetUniqueFormName(strProjectName, strFormName);
	        strBaseFormName = ((object[])oFatherNode.Nodes[0].Tag)[4].ToString();
            arrCardName     = new string[oFatherNode.Nodes.Count];
	        iIndex          = 0;
	        foreach(TreeNode node in oFatherNode.Nodes) {
  		        crdgrp = (RepPP.CardGroup)((object[])node.Tag)[0];
		        arrCardName[iIndex] = crdgrp.Name;
		        iIndex = iIndex + 1;
	        }
	        // Add new form to the project
	        AddForm(strProjectName, 
                    strFormName, 
                    strBaseFormName, 
                    new object[] {"AutoScaleBaseSize", "ClientSize", "Name", "StartPosition"}, 
                    new object[] {"Object", "Object", "String", "Integer"}, 
                    new object[] {"Size(5, 13)", "Size(500, 300)", strFormName, "FormStartPosition.CenterParent"});
		    // Add Rep++ info component to the form
            AddControl(strProjectName, 
                       strFormName, 
                       "repInfo", 
                       "RepPP.RepPPInfo", 
                       null, 
                       null,
                       null);
	        // Add form code
	        AddBeginChildCode(strProjectName, 
                              strFormName, 
                              strBaseFormName, 
                              arrCardName, 
                              bUseSelectBuffer);
	        iChildHeight = AddChildGroup(strProjectName, 
                                         strFormName, 
                                         oFatherNode, 
                                         ALL_CHILD, 
                                         "", 
                                         VERT_MARGE_SPACE, 
                                         FORM_WIDTH, 
                                         true, 
                                         bUseSelectBuffer);
	        AddEndChildCode(strProjectName, strFormName, bUseSelectBuffer);
	        // Add Ok Button
	        AddControl(strProjectName, 
                       strFormName, 
                       "butOk", 
                       "Button", 
                       new object[] {"Location", "Name", "Size", "Text", "DialogResult"}, 
                       new object[] {"Object", "String", "Object", "String", "Integer"}, 
                       new object[] {"Point(" + (FORM_WIDTH / 2 - 50) + ", " + (iChildHeight + 2 * VERT_MARGE_SPACE) + ")", "butOk", "Size(100, 24)", "Ok", "System.Windows.Forms.DialogResult.OK"});
	        SetProperty(strProjectName, 
                        strFormName, 
                        "butOk", 
                        "TabIndex", 
                        "Integer", 
                        "0");
	        // Set the ok button as an accept button
	        SetProperty(strProjectName, 
                        strFormName, 
                        "", 
                        "AcceptButton", 
                        "Integer", 
                        "this.butOk");
	        // Update Form's height
	        SetProperty(strProjectName, 
                        strFormName, 
                        "", 
                        "ClientSize", 
                        "Object", 
                        "Size(" + FORM_WIDTH + ", " + (iChildHeight + (2 * VERT_MARGE_SPACE) + 24 + 30) + ")");
        }

        //**********************************************************************
        //
        // Add each child to a new form
        //   In: 
        //       strProjectName :    The project name
        //       oFatherNode    :    Father Card's Node of the configurated TreeView
        //   Returns:
        //
        //**********************************************************************
        private void AddEachChildToNewForm(string       strProjectName, 
                                           TreeNode     oFatherNode,
                                           ref object[] aChildformNames,
                                           bool         bUseSelectBuffer)
        {
	        string          strFormName;
	        string          strBaseFormName;
	        int             iChildHeight;
	        int             iIndex = 0;
	        RepPP.CardGroup crdgrp;

	        if (oFatherNode.Nodes.Count > 0) {
                foreach (TreeNode nodeChild in oFatherNode.Nodes) {
                    strFormName = ((object[]) nodeChild.Tag)[1].ToString();
			        strFormName = GetUniqueFormName(strProjectName, strFormName);
			        strBaseFormName = ((object[]) nodeChild.Tag)[4].ToString();
			        aChildformNames[iIndex] = strFormName;
			        // Add new form to the project
			        AddForm(strProjectName, 
                            strFormName, 
                            strBaseFormName, 
                            new object[] {"AutoScaleBaseSize", "ClientSize", "Name", "StartPosition"}, 
                            new object[] {"Object", "Object", "String", "Integer"}, 
                            new object[] {"Size(5, 13)", "Size(500, 300)", strFormName, "FormStartPosition.CenterParent"});
		            // Add Rep++ info component to the form
                    AddControl(strProjectName, 
                               strFormName, 
                               "repInfo", 
                               "RepPP.RepPPInfo", 
                               null, 
                               null,
                               null);
			        // Add form code
                    crdgrp = (RepPP.CardGroup)((object[]) nodeChild.Tag)[0];
                    AddBeginChildCode(strProjectName, 
                                      strFormName, 
                                      strBaseFormName, 
                                      new String[] {crdgrp.Group.Name}, bUseSelectBuffer);
			        iChildHeight = AddChildGroup(strProjectName, 
                                                 strFormName, 
                                                 oFatherNode, 
                                                 iIndex, 
                                                 "", 
                                                 VERT_MARGE_SPACE, 
                                                 FORM_WIDTH, 
                                                 true, 
                                                 bUseSelectBuffer);
			        AddEndChildCode(strProjectName, 
                                    strFormName, 
                                    bUseSelectBuffer);
			        // Add Ok Button                    
			        AddControl(strProjectName, 
                               strFormName, 
                               "butOk", 
                               "Button", 
                               new object[] {"Location", "Name", "Size", "Text", "DialogResult"}, 
                               new object[] {"Object", "String", "Object", "String", "Integer"}, 
                               new object[] {"Point(" + (FORM_WIDTH / 2 - 50) + ", " + (iChildHeight + 2 * VERT_MARGE_SPACE) + ")", "butOk", "Size(100, 24)", "Ok", "System.Windows.Forms.DialogResult.OK"});
			        // Set the tabindex of butOk
			        SetProperty(strProjectName, 
                                strFormName, 
                                "butOk", 
                                "TabIndex", 
                                "Integer", 
                                "0");
			        // Set the ok button as an accept button
			        SetProperty(strProjectName, 
                                strFormName, 
                                "", 
                                "AcceptButton", 
                                "Integer", 
                                "this.butOk");
			        // Update Form's height
			        SetProperty(strProjectName, 
                                strFormName, 
                                "", 
                                "ClientSize", 
                                "Object", 
                                "Size(" + FORM_WIDTH + ", " + (iChildHeight + 2 * VERT_MARGE_SPACE + 24 + 36) + ")"); // 24 for the status bar
                    iIndex++;
		        }
	        }
        }

        //**********************************************************************
        //
        // Add child groups 
        //   In: 
        //       strProjectName :       The project name
        //       strFormName    :       The form name
        //       bMainForm      :       true: main form, false: child form
        //       oNode          :       Father Card's Node of the configurated TreeView
        //       iChildIndex    :       Child Index (-1 for all children)
        //       strParentName  :       The Group Box or the Tab Page in which the 
        //                              fiels of the card goup should be generated
        //       iXfather       :       Father's width
        //       bIsInPopupChildForm:   Indicates if the current form is a popup child form
        //                              
        //   Returns:
        //       The necessary height to design the Group fields in the form 
        //
        //**********************************************************************
        private int AddChildGroup(string    strProjectName,             
                                  string    strFormName, 
                                  TreeNode  oFatherNode, 
                                  int       iChildIndex, 
                                  string    strFatherName, 
                                  int       iStartHeight, 
                                  int       iFatherWidth, 
                                  bool      bIsInPopupChildForm, 
                                  bool      bUseSelectBuffer)
        {
	        int             iRetVal;
	        RepPP.CardGroup oCardGrp;
	        string          strChildName;
	        string          strTabName;
	        int             iIndex;
	        int             iChildHeight;
	        int             iMaxChildHeight;

	        iRetVal = 0;
	        if (oFatherNode.Nodes.Count > 0) {
		        if (oFatherNode.Nodes.Count == 1 || iChildIndex != ALL_CHILD) {
			        iChildIndex = ((iChildIndex == ALL_CHILD) ? 0 : iChildIndex);
			        // Add frame for the child group
			        oCardGrp = ((RepPP.CardGroup)((Object[])oFatherNode.Nodes[iChildIndex].Tag)[0]);
			        strChildName = GetUniqueCtlName(strProjectName, strFormName, "grp" + oCardGrp.Name);
			        AddControl(strProjectName, 
                               strFormName, 
                               strChildName, 
                               "GroupBox", 
                               new object[] {"FlatStyle", "Location", "Name", "Text", "Size"}, 
                               new object[] {"Integer", "Object", "String", "String", "Object"}, 
                               new object[] {"FlatStyle.System", "Point(12, " + iStartHeight + ")", strChildName, oCardGrp.Name, "Size(" + (iFatherWidth - 24) + ", 232)"}, strFatherName);
			        iRetVal = GenerateGroup(strProjectName, 
                                            strFormName, 
                                            oFatherNode.Nodes[iChildIndex], 
                                            strChildName, 
                                            bIsInPopupChildForm, 
                                            bUseSelectBuffer);
		        } else {
			        // Add tab control
			        strTabName = GetUniqueCtlName(strProjectName, 
                                                  strFormName, 
                                                  "tabControl1");
                    AddControl(strProjectName, 
                               strFormName, 
                               strTabName, 
                               "TabControl", 
                               new object[] {"Location", "Name", "SelectedIndex", "Size"}, 
                               new object[] {"Object", "String", "Integer", "Object"}, 
                               new object[] {"Point(12, " + iStartHeight + ")", strTabName, "0", "Size(" + (iFatherWidth - 24) + ", 232)"}, strFatherName);
			        iMaxChildHeight = 0;
			        for (iIndex = oFatherNode.Nodes.Count - 1; iIndex >=0; iIndex--) {
				        // Add tab page for the child group
				        oCardGrp = (RepPP.CardGroup)((object[])oFatherNode.Nodes[iIndex].Tag)[0];
				        strChildName = GetUniqueCtlName(strProjectName, strFormName, "pag" + oCardGrp.Name);
				        AddControl(strProjectName, 
                                   strFormName, 
                                   strChildName, 
                                   "TabPage", 
                                   new object[] {"Location", "Name", "Text", "Size"}, 
                                   new object[] {"Object", "String", "String", "Object"}, 
                                   new object[] {"Point(4, 22)", strChildName, oCardGrp.Name, "Size(" + (iFatherWidth - 24 - 8) + ", 206)"}, strTabName);
				        iChildHeight = GenerateGroup(strProjectName, 
                                                     strFormName, 
                                                     oFatherNode.Nodes[iIndex], 
                                                     strChildName, 
                                                     bIsInPopupChildForm, 
                                                     bUseSelectBuffer);
				        if (iChildHeight > iMaxChildHeight) {
					        iMaxChildHeight = iChildHeight;
				        }
			        }
			        // Update Tab control's height
			        SetProperty(strProjectName, 
                                strFormName, 
                                strTabName, 
                                "Size", 
                                "Object", 
                                "Size(" + (iFatherWidth - 24) + ", " + iMaxChildHeight + TAB_NAME_HEIGHT + ")");
			        iRetVal = iMaxChildHeight + TAB_NAME_HEIGHT;
		        }
	        }
	        return iRetVal;
        }

        //**********************************************************************
        //
        // Add rep++ fields for the specified group 
        //   In: 
        //       strProjectName :    The project name
        //       strFormName    :    The card name corresponding to the project
        //       strGrpName     :    The Rep++ group name
        //       strParentName  :    The Group Box or the Tab Page in which the 
        //                           fiels of the card should be generated
        //       iXFather       :    Father's width
        //       aConfig        :    array of configuration flags:
        //                               0: combox type (simple, dropdown drop down list)
        //                               1: alignement type (left, center, right)
        //                               2: use edit (true, false)
        //                               3: left text (true, false)
        //                               4: toobar size (small, medium, large, -1: form dosn't use a toolbar)
        //       bPKOnly        :    Add primary key fields only
        //   Returns:
        //       The necessary height to design the Group fields in the form 
        //
        //**********************************************************************
        private int AddRepPPFldGroup(string     strProjectName, 
                                     string     strFormName, 
                                     string     strGrpName, 
                                     string     strFatherName, 
                                     int        iXFather, 
                                     object[]   aConfig, 
                                     bool       bPkOnly)
        {
	        int         iRetVal         = 0;
	        RepPP.Group oGroup;
	        int         iMaxStatWidth   = 0;
	        int         iMaxFldWidth    = 0;
	        int         iXPos;
	        int         iYPos;
	        int         iHeight;
	        int         iWidth;
	        string      strCtlName;

	        oGroup = m_oRepPP.Groups.Find(strGrpName);
            if (oGroup == null) {
		        MessageBox.Show("Unable to find the group '" + strGrpName + "'");
	        } else {
		        GetMaxWidths(oGroup.Fields, ref iMaxStatWidth, ref iMaxFldWidth, iXFather);
		        if ((int)aConfig[4] == - 1) {
			        iYPos = VERT_MARGE_SPACE;
		        } else if ((int)aConfig[4] == 0) {
        	        iYPos = VERT_MARGE_SPACE * 4;
		        } else {
			        iYPos = VERT_MARGE_SPACE * 6;
		        }
		        foreach (RepPP.Field oField in oGroup.Fields) {
			        if (!bPkOnly || oField.IsPrimaryKey) {
				        // Add static Rep++ field
				        iHeight = DEFAULT_CTL_HEIGHT;
				        iWidth = iMaxStatWidth;
				        iXPos = HORIZ_MARGE_SPACE;
				        strCtlName = GetUniqueCtlName(strProjectName, 
                                                      strFormName, 
                                                      "sta" + oField.Name);
				        AddControl(strProjectName, 
                                   strFormName, 
                                   strCtlName, 
                                   "RepPP.RepPPStat", 
                                   new object[] {"FieldName", "GroupName", "Location", "Name", "Size", "TextAlign"}, 
                                   new object[] {"String", "String", "Object", "String", "Object", "Integer"}, 
                                   new object[] {oField.Name, strGrpName, "Point(" + iXPos + ", " + (iYPos + 4) + ")",
                                   strCtlName, 
                                   "Size(" + iWidth + ", " + iHeight + " )", "HorizontalAlignment." + aConfig[1].ToString()}, 
                                   strFatherName);
				        GetBestSizes(oField, iMaxFldWidth, ref iWidth, ref iHeight);
				        iXPos = 2 * HORIZ_MARGE_SPACE + iMaxStatWidth;
				        // Add Rep++ field
				        strCtlName = GetUniqueCtlName(strProjectName, strFormName, "fld" + oField.Name);
    			        AddControl(strProjectName, 
                                   strFormName, 
                                   strCtlName, 
                                   "RepPP.RepPPField", 
                                   new object[] {"FieldName", "GroupName", "Location", "Name", "Size", "TabStop", 
                                   "ComboBoxStyle", 
                                   "ControlType", 
                                   "RightToLeft", 
                                   "Multiline", 
                                   "ScrollBars"}, 
                                   new object[] {"String", "String", "Object", "String", "Object", "Integer", "Integer", "Integer", "Integer", "Integer", "Integer"}, 
                                   new object[] {oField.Name, strGrpName, "Point(" + iXPos + ", " + iYPos + ")", 
                                   strCtlName, 
                                   "Size(" + iWidth + ", " + iHeight + " )", 
                                   ((oField.IsSelectable) ? "true" : "false"), 
                                   "ComboBoxStyle." + aConfig[0].ToString(), 
                                   "RepPP.CtlType." + ((string)((bool)(aConfig[2]) ? "sdCtlEdit" : "sdCtlNone")), 
                                   "System.Windows.Forms.RightToLeft." + ((bool)(aConfig[3]) ? "Yes" : "No"), 
                                   ((oField.Type == RepPP.FieldType.sdFieldMemo) ? "true" : "false"), 
                                   ((oField.Type == RepPP.FieldType.sdFieldMemo) ? "System.Windows.Forms.ScrollBars.Vertical" : "System.Windows.Forms.ScrollBars.None")}, 
                                   strFatherName);
				        iYPos = iYPos + iHeight + VERT_MARGE_SPACE - 4;
			        }
		        }
		        iRetVal = iYPos + 4;
	        }
	        return iRetVal;
        }

        //**********************************************************************
        //
        // Add rep++ toolkit field controls for the specified group 
        //   In: 
        //       strProjectName :    The project name
        //       strFormName    :    The card name corresponding to the project
        //       strGrpName     :    The Rep++ group name
        //       strParentName  :    The Group Box or the Tab Page in which the 
        //                           fiels of the card should be generated
        //       iXFather       :    Father's width
        //       aConfig        :    array of configuration flags:
        //                               0: combox type (simple, dropdown drop down list)
        //                               1: alignement type (left, center, right)
        //                               2: use edit (true, false)
        //                               3: left text (true, false)
        //                               4: toobar size (small, medium, large)
        //   Returns:
        //       The necessary height to design the Group fields in the form 
        //
        //**********************************************************************
        private int AddRepPPTkFldGroup(string   strProjectName, 
                                       string   strFormName, 
                                       string   strGrpName, 
                                       string   strFatherName, 
                                       int      iXFather, 
                                       object[] aConfig)
        {
	        int         iRetVal         = 0;
	        RepPP.Group oGroup;
	        int         iMaxStatWidth   = 0;
	        int         iMaxFldWidth    = 0;
	        int         iXPos;
	        int         iYPos;
	        int         iHeight;
	        int         iWidth;
	        string      strCtlName;
	        string      strCtlClass;
            string      strFldFullName;

	        oGroup = m_oRepPP.Groups.Find(strGrpName);
	        if (oGroup == null) {
		        MessageBox.Show("Unable to find the group '" + strGrpName + "'");
	        } else {
		        GetMaxWidths(oGroup.Fields, ref iMaxStatWidth, ref iMaxFldWidth, iXFather);
		        if ((int)aConfig[4] == 0) {
			        iYPos = VERT_MARGE_SPACE * 4;
		        } else {
			        iYPos = VERT_MARGE_SPACE * 6;
		        }
		        foreach (RepPP.Field oField in oGroup.Fields) {
			        // Add a label rep++ field control
			        iHeight        = DEFAULT_CTL_HEIGHT;
			        iWidth         = iMaxStatWidth;
			        iXPos          = HORIZ_MARGE_SPACE;
                    strFldFullName = "RepPP.Toolkit.FldFullName(\"" + strGrpName  + "\", \"" + oField.Name + "\")";
			        strCtlName     = GetUniqueCtlName(strProjectName, 
                                                      strFormName, 
                                                      "lbl" + oField.Name);
			        AddControl(strProjectName, 
                               strFormName, 
                               strCtlName, 
                               "RepPP.Toolkit.Window.FldLabel", 
                               new object[] {"FieldFullName", "Location", "Name", "Size", "RightToLeft"}, 
                               new object[] {"Object", "Object", "String", "Object", "Integer"}, 
                               new object[] {strFldFullName, "Point(" + iXPos + ", " + (iYPos + 4) + ")", strCtlName, "Size(" + iWidth + ", " + iHeight + " )", "System.Windows.Forms.RightToLeft." + ((bool)(aConfig[3]) ? "Yes" : "No")}, strFatherName);
			        GetBestSizes(oField, iMaxFldWidth, ref iWidth, ref iHeight);
			        iXPos = 2 * HORIZ_MARGE_SPACE + iMaxStatWidth;
			        // Add rep++ field control
			        strCtlClass = GetFldCtlClass(oField.ControlType);
			        strCtlName  = GetUniqueCtlName(strProjectName, strFormName, "fld" + oField.Name);
			        switch (strCtlClass) {
				        case "RepPP.Toolkit.Window.FldTextBox":
					        AddControl(strProjectName, 
                                       strFormName, 
                                       strCtlName, 
                                       strCtlClass, 
                                       new object[] {"FieldFullName", "Location", "Name", "Size", "TabStop", "RightToLeft", "TextAlign", "Multiline"}, 
                                       new object[] {"Object", "Object", "String", "Object", "Integer", "Integer", "Integer", "Integer"}, 
                                       new object[] {strFldFullName, "Point(" + iXPos + ", " + iYPos + ")", strCtlName, "Size(" + iWidth + ", " + iHeight + " )", ((oField.IsSelectable) ? "true" : "false"), "System.Windows.Forms.RightToLeft." + ((bool)(aConfig[3]) ? "Yes" : "No"), "HorizontalAlignment." + aConfig[1].ToString(), ((oField.Type == RepPP.FieldType.sdFieldMemo) ? "true" : "false")}, strFatherName);
					        break;
				        case "RepPP.Toolkit.Window.FldComboBox":
					        AddControl(strProjectName, 
                                       strFormName, 
                                       strCtlName, 
                                       strCtlClass, 
                                       new object[] {"FieldFullName", "Location", "Name", "Size", "TabStop", "RightToLeft", "DropDownStyle"}, 
                                       new object[] {"Object", "Object", "String", "Object", "Integer", "Integer", "Integer"}, 
                                       new object[] {strFldFullName, "Point(" + iXPos + ", " + iYPos + ")", strCtlName, "Size(" + iWidth + ", " + iHeight + " )", ((oField.IsSelectable) ? "true" : "false"), "System.Windows.Forms.RightToLeft." + ((bool)(aConfig[3]) ? "Yes" : "No"), "ComboBoxStyle." + aConfig[0].ToString()}, strFatherName);
					        break;
				        case "RepPP.Toolkit.Window.FldListBox":
					        AddControl(strProjectName, 
                                       strFormName, 
                                       strCtlName, 
                                       strCtlClass, 
                                       new object[] {"FieldFullName", "Location", "Name", "Size", "TabStop", "RightToLeft"}, 
                                       new object[] {"Object", "Object", "String", "Object", "Integer", "Integer"}, 
                                       new object[] {strFldFullName, "Point(" + iXPos + ", " + iYPos + ")", strCtlName, "Size(" + iWidth + ", " + iHeight + " )", ((oField.IsSelectable) ? "true" : "false"), "System.Windows.Forms.RightToLeft." + ((bool)(aConfig[3]) ? "Yes" : "No")}, strFatherName);
					        break;
				        case "RepPP.Toolkit.Window.FldDateTimePicker":
					        AddControl(strProjectName, 
                                       strFormName, 
                                       strCtlName, 
                                       strCtlClass, 
                                       new object[] {"FieldFullName", "Location", "Name", "Size", "TabStop", "RightToLeft"}, 
                                       new object[] {"Object", "Object", "String", "Object", "Integer", "Integer"},
                                       new object[] {strFldFullName, "Point(" + iXPos + ", " + iYPos + ")", 
                                       strCtlName, 
                                       "Size(" + iWidth + ", " + iHeight + " )", 
                                       ((oField.IsSelectable) ? "true" : "false"), 
                                       "System.Windows.Forms.RightToLeft." + ((bool)(aConfig[3]) ? "Yes" : "No")}, 
                                       strFatherName);
					        break;
				        case "RepPP.Toolkit.Window.FldCheckBox":
				        case "RepPP.Toolkit.Window.FldRadioButton":
					        iHeight = oField.ChoiceList.Count * (DEFAULT_CTL_HEIGHT + VERT_MARGE_SPACE / 2) + VERT_MARGE_SPACE / 2;
					        AddSetOfTKFldControls(strProjectName, 
                                                  strFormName, 
                                                  strFatherName, 
                                                  oField, 
                                                  iXPos, 
                                                  iYPos, 
                                                  iHeight, 
                                                  iWidth + HORIZ_MARGE_SPACE, 
                                                  strCtlClass);
                            break;
                        default:
                            break;
			        }
			        iYPos = iYPos + iHeight + VERT_MARGE_SPACE - 4;
		        }
		        iRetVal = iYPos + 4;
	        }
	        return iRetVal;
        }

        //**********************************************************************
        //
        // Add a set of toolkit rep++ field controls. Case of checkbox or radiobuttons 
        //   In: 
        //       strProjectName:     The project name
        //       strFormName:        The card name corresponding to the project
        //       strParentName:      The Group Box or the Tab Page in which the 
        //                           fiels of the card should be generated
        //       fld:                Rep++ Field 
        //       iXPos:              X position of the set of controls
        //       iYPos:              Y position of the set of controls
        //       iHeight:            Height of the set of controls
        //       iWidth:             Width of the set of controls
        //       strClassName:       Controls class name
        //
        //**********************************************************************
        public void AddSetOfTKFldControls(string        strProjectName, 
                                          string        strFormName, 
                                          string        strFatherName, 
                                          RepPP.Field   fld, 
                                          int           iXPos, 
                                          int           iYPos, 
                                          int           iHeight, 
                                          int           iWidth, 
                                          string        strClassName)
        {
	        string  strPanelName;
	        int     iIndex;
	        string  strCtlName;
            string strFldFullName;

	        // Add a panel control
	        strPanelName = GetUniqueCtlName(strProjectName, 
                                            strFormName, 
                                            "pnl" + fld.Name);
	        AddControl(strProjectName, 
                       strFormName, 
                       strPanelName, 
                       "Panel", 
                       new object[] {"Name", "Size", "Location"}, 
                       new object[] {"String", "Object", "Object"}, 
                       new object[] {strPanelName, "Size(" + iWidth + ", " + iHeight + " )", 
                       "Point(" + iXPos + ", " + iYPos + ")"}, 
                       strFatherName);
	        iHeight = DEFAULT_CTL_HEIGHT;
	        iWidth = iWidth - HORIZ_MARGE_SPACE * 2;
	        iXPos = HORIZ_MARGE_SPACE;
	        iYPos = VERT_MARGE_SPACE / 2;
	        for (iIndex = 0; iIndex < fld.ChoiceList.Count - 1; iIndex++) {
		        strCtlName     = GetUniqueCtlName(strProjectName, 
                                                  strFormName, 
                                                  "fld" + fld.Name + iIndex);
                strFldFullName = "RepPP.Toolkit.FldFullName(\"" + fld.Group.Name + "\", \"" + fld.Name + "\")";
		        AddControl(strProjectName, 
                           strFormName, 
                           strCtlName, 
                           strClassName, 
                           new object[] {"FieldFullName", "ChoiceIndex", "Location", "Name", "Size", "TabStop"}, 
                           new object[] {"Object", "Integer", "Object", "String", "Object", "Integer"}, 
                           new object[] {strFldFullName, iIndex, "Point(" + iXPos + ", " + iYPos + ")", 
                           strCtlName, 
                           "Size(" + iWidth + ", " + iHeight + " )", 
                           ((fld.IsSelectable) ? "true" : "false")}, 
                           strPanelName);
		        iYPos = iYPos + VERT_MARGE_SPACE / 2 + DEFAULT_CTL_HEIGHT;
	        }
        }

        //**********************************************************************
        //
        // Determine the rep++ toolkit control class for the field 
        //   In: 
        //       eCtlType :    The control type of the field
        //   Returns:
        //       The control class name
        //
        //**********************************************************************
        private string GetFldCtlClass(RepPP.CtlType eCtlType)
        {
	        string strRetVal;

	        switch (eCtlType)
	        {
		        case RepPP.CtlType.sdCtlEdit:
		        case RepPP.CtlType.sdCtlFmt:
		        case RepPP.CtlType.sdCtlMLine:
		        case RepPP.CtlType.sdCtlNone:
			        strRetVal = "RepPP.Toolkit.Window.FldTextBox";
			        break;
		        case RepPP.CtlType.sdCtlCombo:
			        strRetVal = "RepPP.Toolkit.Window.FldComboBox";
			        break;
		        case RepPP.CtlType.sdCtlList:
			        strRetVal = "RepPP.Toolkit.Window.FldListBox";
			        break;
		        case RepPP.CtlType.sdCtlCheck:
			        strRetVal = "RepPP.Toolkit.Window.FldCheckBox";
			        break;
		        case RepPP.CtlType.sdCtlRadio:
			        strRetVal = "RepPP.Toolkit.Window.FldRadioButton";
			        break;
		        case RepPP.CtlType.sdCtlFmtDate:
			        strRetVal = "RepPP.Toolkit.Window.FldDateTimePicker";
			        break;
		        default:
			        throw new System.ApplicationException("Unknown type " + eCtlType);
	        };
	        return strRetVal;
        }

        //**********************************************************************
        //
        // Add a Grid control  for the specified group 
        //   In: 
        //       strProjectName :    The project name
        //       strFormName    :    The form name
        //       strCardName    :    The transaction card name
        //       strGrpName     :    The Rep++ group name
        //       strParentName  :    The Group Box or the Tab Page in which the 
        //                           fiels of the card should be generated
        //       iXFather       :    Father's width
        //       iToolbarSize   :    Toolbar button size
        //                               0: small
        //                               2: big
        //       strGridName:        The datagrid control name
        //   Returns:
        //       The necessary height to design the Group fields in the form 
        //
        //**********************************************************************
        private int AddGridGroup(string     strProjectName, 
                                 string     strFormName, 
                                 string     strCardName,
                                 string     strGrpName, 
                                 string     strFatherName, 
                                 int        iXFather, 
                                 int        iToolbarSize,
                                 ref string strGridName) {
	        RepPP.Group oGroup;
	        int         iXPos;
	        int         iYPos   = 0;
	        int         iHeight = 0;
	        int         iWidth;

	        oGroup = m_oRepPP.Groups.Find(strGrpName);
	        if (oGroup == null) {
		        MessageBox.Show("Unable to find the group '" + strGrpName + "'");
	        } else {
		        // Add Grid control
		        iHeight = DEFAULT_GRID_HEIGHT;
		        iWidth  = iXFather - 2 * HORIZ_MARGE_SPACE;
		        iXPos   = HORIZ_MARGE_SPACE;
		        if (iToolbarSize == 0) {
			        iYPos = VERT_MARGE_SPACE * 4;
		        } else {
			        iYPos = VERT_MARGE_SPACE * 6;
		        }
		        strGridName = GetUniqueCtlName(strProjectName, 
                                               strFormName, 
                                               "dataGrid" + oGroup.Name);
		        AddControl(strProjectName, 
                           strFormName, 
                           strGridName, 
                           "RepPP.Toolkit.Window.DataGridViewGInst", 
                           new object[] {"CardGroupFullName", "Location", "Name", "Size", "ShowDescription", "AllowUserToAddRows", "MultiSelect"}, 
                           new object[] {"Object", "Object", "String", "Object", "Integer", "Integer", "Integer"}, 
                           new object[] {"RepPP.Toolkit.CrdGrpFullName(\"" + strCardName + "\", \"" + strGrpName + "\")", "Point(" + iXPos + ", " + iYPos + ")", strGridName, "Size(" + iWidth + ", " + iHeight + " )", "true", "false", "false"}, 
                           strFatherName);
	        }
	        return iYPos + iHeight + VERT_MARGE_SPACE;
        }

        //**********************************************************************
        //
        // Add a control to the form
        //   In: 
        //       strProjectName :    The project name
        //       strFormName    :    The form in witch the control have to be added
        //       strCtlName     :    The control name
        //       strCtlType     :    The control type
        //       aPropNames     :    Array of property names
        //       aPropTypes     :    Array of property types
        //       aPropValues    :    Array of property values
        //       strPanelName   :    The Panel in witch the control have to be added
        //       strCollName    :    The collection name in witch the control have to 
        //                           to be added (default value: Controls)
        //       strCollType    :    The collection Type (default value: Control)
        //   Returns:
        //
        //**********************************************************************
        public virtual void AddControl(string   strProjectName, 
                                       string   strFormName, 
                                       string   strCtlName, 
                                       string   strCtlType, 
                                       object[] aProperties, 
                                       object[] aPropTypes, 
                                       object[] aPropValues, 
                                       string   strPanelName, 
                                       string   strCollName, 
                                       string   strCollType, 
                                       bool     bDeclareIt)
        {
        }

        //**********************************************************************
        //
        // Add a control to the form
        //   In: 
        //       strProjectName :    The project name
        //       strFormName    :    The form in witch the control have to be added
        //       strCtlName     :    The control name
        //       strCtlType     :    The control type
        //       aPropNames     :    Array of property names
        //       aPropTypes     :    Array of property types
        //       aPropValues    :    Array of property values
        //   Returns:
        //
        //**********************************************************************
        public virtual void AddControl(string   strProjectName, 
                                       string   strFormName, 
                                       string   strCtlName, 
                                       string   strCtlType, 
                                       object[] aProperties, 
                                       object[] aPropTypes, 
                                       object[] aPropValues)
        {
	        AddControl(strProjectName, 
                       strFormName, 
                       strCtlName, 
                       strCtlType, 
                       aProperties, 
                       aPropTypes, 
                       aPropValues, 
                       null, 
                       "Controls", 
                       "Control", 
                       true);
        }

        //**********************************************************************
        //
        // Add a control to the form
        //   In: 
        //       strProjectName :    The project name
        //       strFormName    :    The form in witch the control have to be added
        //       strCtlName     :    The control name
        //       strCtlType     :    The control type
        //       aProperties    :    Array of property names
        //       aPropTypes     :    Array of property types
        //       aPropValues    :    Array of property values
        //       strPanelName   :    The Panel in witch the control have to be added
        //   Returns:
        //
        //**********************************************************************
        public virtual void AddControl(string   strProjectName, 
                                       string   strFormName, 
                                       string   strCtlName, 
                                       string   strCtlType, 
                                       object[] aProperties, 
                                       object[] aPropTypes, 
                                       object[] aPropValues, 
                                       string   strPanelName)
        {
	        AddControl(strProjectName, 
                       strFormName, 
                       strCtlName, 
                       strCtlType, 
                       aProperties, 
                       aPropTypes, 
                       aPropValues, 
                       strPanelName, 
                       "Controls", 
                       "Control", 
                       true);
        }

        //**********************************************************************
        //
        // Add a control to the form
        //   In: 
        //       strProjectName :    The project name
        //       strFormName    :    The form in witch the control have to be added
        //       strCtlName     :    The control name
        //       strCtlType     :    The control type
        //       aProperties    :    Array of property names
        //       aPropTypes     :    Array of property types
        //       aPropValues    :    Array of property values
        //       strPanelName   :    The Panel in witch the control have to be added
        //       strCollName    :    The collection name in witch the control have to 
        //                           to be added (default value: Controls)
        //   Returns:
        //
        //**********************************************************************
        public virtual void AddControl(string   strProjectName, 
                                       string   strFormName, 
                                       string   strCtlName, 
                                       string   strCtlType, 
                                       object[] aProperties, 
                                       object[] aPropTypes, 
                                       object[] aPropValues, 
                                       string   strPanelName, 
                                       string   strCollName)
        {
	        AddControl(strProjectName, 
                       strFormName, 
                       strCtlName, 
                       strCtlType, 
                       aProperties, 
                       aPropTypes, 
                       aPropValues, 
                       strPanelName, 
                       strCollName, 
                       "Control", 
                       true);
        }

        //**********************************************************************
        //
        // Add a control to the form
        //   In: 
        //       strProjectName :    The project name
        //       strFormName    :    The form in witch the control have to be added
        //       strCtlName     :    The control name
        //       strCtlType     :    The control type
        //       aProperties    :    Array of property names
        //       aPropTypes     :    Array of property types
        //       aPropValues    :    Array of property values
        //       strPanelName   :    The Panel in witch the control have to be added
        //       strCollName    :    The collection name in witch the control have to 
        //                           to be added (default value: Controls)
        //       strCollType    :    The collection Type (default value: Control)
        //   Returns:
        //
        //**********************************************************************
        public virtual void AddControl(string   strProjectName, 
                                       string   strFormName, 
                                       string   strCtlName, 
                                       string   strCtlType, 
                                       object[] aProperties, 
                                       object[] aPropTypes, 
                                       object[] aPropValues, 
                                       string   strPanelName, 
                                       string   strCollName, 
                                       string   strCollType)
        {
	        AddControl(strProjectName, 
                       strFormName, 
                       strCtlName, 
                       strCtlType, 
                       aProperties, 
                       aPropTypes, 
                       aPropValues, 
                       strPanelName, 
                       strCollName, 
                       strCollType, 
                       true);
        }

        //**********************************************************************
        //
        // Add a form to the project
        //   In: 
        //       strProjectName :    The project name
        //       strFormName    :    The form name
        //       strBaseformName:    The base form name
        //       aProperties    :    Array of property names
        //       aPropTypes     :    Array of property types
        //       aPropValues    :    Array of property values
        //   Returns:
        //
        //**********************************************************************
        public virtual void AddForm(string      strProjectName, 
                                    string      strFormName, 
                                    string      strBaseFormName, 
                                    object[]    aProperties, 
                                    object[]    aPropTypes, 
                                    object[]    aPropValues)
        {
            m_arrFormName.Add(strFormName);
        }

        //**********************************************************************
        //
        // Get a property value
        //   In: 
        //       strProjectName:    The project name
        //       strFormName   :    The form in witch the control have to be added
        //       strCtlName    :    The control name
        //       strPropName   :    The property name
        //   Returns:
        //       The property value as a string
        //
        //**********************************************************************
        public virtual string GetProperty(string strProjectName, 
                                          string strFormName, 
                                          string strCtlName, 
                                          string strPropName)
        {
            return "";
        }

        //**********************************************************************
        //
        // Set a property value
        //   In: 
        //       strProjectName:    The project name
        //       strFormName   :    The form in witch the control have to be added
        //       strCtlName    :    The control name
        //       strPropName   :    The property name
        //       strPropType   :    The property type
        //       strPropValue  :    The property value
        //   Returns:
        //       
        //**********************************************************************
        public virtual void SetProperty(string strProjectName, 
                                        string strFormName, 
                                        string strCtlName, 
                                        string strPropName, 
                                        string strPropType, 
                                        string strPropValue)
        {
        }

        //**********************************************************************
        //
        // Add a function to a form
        //   In: 
        //       strProjectName:    The project name
        //       strFormName   :    The form in witch the control have to be added
        //       strName       :    The function name
        //       ekind         :    kind of the function(function, sub, ...)
        //       strRetType    :    Type of the return value
        //       aParamNames   :    Array of parameter names
        //       aParamTypes   :    Array of parameter types
        //       strFuncComment:    Function comment
        //       strReturnComment:  Return comment
        //       aParamComment:     Params comments
        //       strBody       :    The body of the function(optional)
        //       strEvent      :    The event handled by this function(optional)
        //       strEventType  :    The event handler type
        //   Returns:
        //       
        //**********************************************************************
        public virtual void AddFunction(string       strProjectName, 
                                        string       strFormName, 
                                        string       strName, 
                                        vsCMFunction eKind, 
                                        string       strRetType, 
                                        object[]     aParamNames, 
                                        object[]     aParamTypes, 
                                        string       strFuncComment, 
                                        string       strReturnComment, 
                                        object[]     aParamComment, 
                                        vsCMAccess   eAccess, 
                                        string       strBody, 
                                        string       strCtlEvent, 
                                        string       strEvent, 
                                        string       strEventType, 
                                        bool         bAddDelegate)
        {
        }

        //**********************************************************************
        //
        // Add a function to a form
        //   In: 
        //       strProjectName:    The project name
        //       strFormName   :    The form in witch the control have to be added
        //       strName       :    The function name
        //       ekind         :    kind of the function(function, sub, ...)
        //       strRetType    :    Type of the return value
        //       aParamNames   :    Array of parameter names
        //       aParamTypes   :    Array of parameter types
        //       strFuncComment:    Function comment
        //       strReturnComment:  Return comment
        //       aParamComment:     Params comments
        //   Returns:
        //       
        //**********************************************************************
        public virtual void AddFunction(string       strProjectName, 
                                        string       strFormName, 
                                        string       strName, 
                                        vsCMFunction eKind, 
                                        string       strRetType, 
                                        object[]     aParamNames, 
                                        object[]     aParamTypes, 
                                        string       strFuncComment, 
                                        string       strReturnComment, 
                                        object[]     aParamComment)
        {
	        AddFunction(strProjectName, 
                        strFormName, 
                        strName, 
                        eKind, 
                        strRetType, 
                        aParamNames, 
                        aParamTypes, 
                        strFuncComment, 
                        strReturnComment, 
                        aParamComment, 
                        vsCMAccess.vsCMAccessDefault, 
                        "", 
                        "", 
                        "", 
                        "System.EventHandler", 
                        false);
        }

        //**********************************************************************
        //
        // Add a function to a form
        //   In: 
        //       strProjectName:    The project name
        //       strFormName   :    The form in witch the control have to be added
        //       strName       :    The function name
        //       ekind         :    kind of the function(function, sub, ...)
        //       strRetType    :    Type of the return value
        //       aParamNames   :    Array of parameter names
        //       aParamTypes   :    Array of parameter types
        //       strFuncComment:    Function comment
        //       strReturnComment:  Return comment
        //       aParamComment:     Params comments
        //   Returns:
        //       
        //**********************************************************************
        public virtual void AddFunction(string       strProjectName, 
                                        string       strFormName, 
                                        string       strName, 
                                        vsCMFunction eKind, 
                                        string       strRetType, 
                                        object[]     aParamNames, 
                                        object[]     aParamTypes, 
                                        string       strFuncComment, 
                                        string       strReturnComment, 
                                        object[]     aParamComment, 
                                        vsCMAccess   eAccess)
        {
	        AddFunction(strProjectName, 
                        strFormName, 
                        strName, 
                        eKind, 
                        strRetType, 
                        aParamNames, 
                        aParamTypes, 
                        strFuncComment, 
                        strReturnComment, 
                        aParamComment, 
                        eAccess, 
                        "", 
                        "", 
                        "", 
                        "System.EventHandler", 
                        false);
        }

        //**********************************************************************
        //
        // Add a function to a form
        //   In: 
        //       strProjectName  :  The project name
        //       strFormName     :  The form in witch the control have to be added
        //       strName         :  The function name
        //       ekind           :  kind of the function(function, sub, ...)
        //       strRetType      :  Type of the return value
        //       aParamNames     :  Array of parameter names
        //       aParamTypes     :  Array of parameter types
        //       strFuncComment  :  Function comment
        //       strReturnComment:  Return comment
        //       aParamComment   :  Params comments
        //       eAccess         : 
        //       strBody         :
        //   Returns:
        //       
        //**********************************************************************
        public virtual void AddFunction(string          strProjectName, 
                                        string          strFormName, 
                                        string          strName, 
                                        vsCMFunction    eKind, 
                                        string          strRetType, 
                                        object[]        aParamNames, 
                                        object[]        aParamTypes, 
                                        string          strFuncComment, 
                                        string          strReturnComment, 
                                        object[]        aParamComment, 
                                        vsCMAccess      eAccess, 
                                        string          strBody)
        {
	        AddFunction(strProjectName, 
                        strFormName, 
                        strName, 
                        eKind, 
                        strRetType, 
                        aParamNames, 
                        aParamTypes, 
                        strFuncComment, 
                        strReturnComment, 
                        aParamComment, 
                        eAccess, 
                        strBody, 
                        "", 
                        "", 
                        "System.EventHandler", 
                        false);
        }

        //**********************************************************************
        //
        // Add a function to a form
        //   In: 
        //       strProjectName  :  The project name
        //       strFormName     :  The form in witch the control have to be added
        //       strName         :  The function name
        //       ekind           :  kind of the function(function, sub, ...)
        //       strRetType      :  Type of the return value
        //       aParamNames     :  Array of parameter names
        //       aParamTypes     :  Array of parameter types
        //       strFuncComment  :  Function comment
        //       strReturnComment:  Return comment
        //       aParamComment   :  Params comments
        //       eAccess         : 
        //       strBody         :
        //       strCtlEvent     :
        //   Returns:
        //       
        //**********************************************************************
        public virtual void AddFunction(string          strProjectName, 
                                        string          strFormName, 
                                        string          strName, 
                                        vsCMFunction    eKind, 
                                        string          strRetType, 
                                        object[]        aParamNames, 
                                        object[]        aParamTypes, 
                                        string          strFuncComment, 
                                        string          strReturnComment, 
                                        object[]        aParamComment, 
                                        vsCMAccess      eAccess, 
                                        string          strBody, 
                                        string          strCtlEvent)
        {
	        AddFunction(strProjectName, 
                        strFormName, 
                        strName, 
                        eKind, 
                        strRetType, 
                        aParamNames, 
                        aParamTypes, 
                        strFuncComment, 
                        strReturnComment, 
                        aParamComment, 
                        eAccess, 
                        strBody, 
                        strCtlEvent, 
                        "", 
                        "System.EventHandler", 
                        false);
        }

        //**********************************************************************
        //
        // Add a function to a form
        //   In: 
        //       strProjectName  :  The project name
        //       strFormName     :  The form in witch the control have to be added
        //       strName         :  The function name
        //       ekind           :  kind of the function(function, sub, ...)
        //       strRetType      :  Type of the return value
        //       aParamNames     :  Array of parameter names
        //       aParamTypes     :  Array of parameter types
        //       strFuncComment  :  Function comment
        //       strReturnComment:  Return comment
        //       aParamComment   :  Params comments
        //       eAccess         : 
        //       strBody         :
        //       strCtlEvent     : 
        //       strEvent        :
        //   Returns:
        //       
        //**********************************************************************
        public virtual void AddFunction(string          strProjectName, 
                                        string          strFormName, 
                                        string          strName, 
                                        vsCMFunction    eKind, 
                                        string          strRetType, 
                                        object[]        aParamNames, 
                                        object[]        aParamTypes, 
                                        string          strFuncComment, 
                                        string          strReturnComment, 
                                        object[]        aParamComment, 
                                        vsCMAccess      eAccess, 
                                        string          strBody, 
                                        string          strCtlEvent, 
                                        string          strEvent)
        {
	        AddFunction(strProjectName, 
                        strFormName, 
                        strName, 
                        eKind, 
                        strRetType, 
                        aParamNames, 
                        aParamTypes, 
                        strFuncComment, 
                        strReturnComment, 
                        aParamComment, 
                        eAccess, 
                        strBody, 
                        strCtlEvent, 
                        strEvent, 
                        "System.EventHandler", 
                        false);
        }

        //**********************************************************************
        //
        // Add a function to a form
        //   In: 
        //       strProjectName  :  The project name
        //       strFormName     :  The form in witch the control have to be added
        //       strName         :  The function name
        //       ekind           :  kind of the function(function, sub, ...)
        //       strRetType      :  Type of the return value
        //       aParamNames     :  Array of parameter names
        //       aParamTypes     :  Array of parameter types
        //       strFuncComment  :  Function comment
        //       strReturnComment:  Return comment
        //       aParamComment   :  Params comments
        //       eAccess         : 
        //       strBody         :
        //       strCtlEvent     : 
        //       strEvent        :
        //       strEventType    :
        //   Returns:
        //       
        //**********************************************************************
        public virtual void AddFunction(string          strProjectName, 
                                        string          strFormName, 
                                        string          strName, 
                                        vsCMFunction    eKind, 
                                        string          strRetType, 
                                        object[]        aParamNames, 
                                        object[]        aParamTypes, 
                                        string          strFuncComment, 
                                        string          strReturnComment, 
                                        object[]        aParamComment, 
                                        vsCMAccess      eAccess, 
                                        string          strBody, 
                                        string          strCtlEvent, 
                                        string          strEvent, 
                                        string          strEventType)
        {
	        AddFunction(strProjectName, 
                        strFormName, 
                        strName, 
                        eKind, 
                        strRetType, 
                        aParamNames, 
                        aParamTypes, 
                        strFuncComment, 
                        strReturnComment, 
                        aParamComment, 
                        eAccess, 
                        strBody, 
                        strCtlEvent, 
                        strEvent, 
                        strEventType, 
                        false);
        }

        //**********************************************************************
        //
        // Add a constructor to a form
        //   In: 
        //       strProjectName :    The project name
        //       strFormName    :    The form in witch the control have to be added
        //       aParamNames    :    Array of parameter names
        //       aParamTypes    :    Array of parameter types
        //       aBaseParamNames:    Array of parameter names
        //       strBody        :    The body of the function
        //       strFuncComment :    Function comment
        //       aParamComment  :    Params comments
        //   Returns:
        //       
        //**********************************************************************
        public virtual void AddConstructor(string   strProjectName, 
                                           string   strFormName, 
                                           object[] aParamNames, 
                                           object[] aParamTypes, 
                                           object[] aBaseParamNames, 
                                           string   strBody, 
                                           string   strFuncComment, 
                                           object[] aParamComment)
        {
        }

        //**********************************************************************
        //
        // Add a line to the function
        //   In: 
        //       strProjectName:    The project name
        //       strFormName   :    The form in witch the control have to be added
        //       strFuncName   :    The function name
        //       strLine       :    The line to add
        //       iPos          :    insertion postion (-1 at the end)
        //   Returns:
        //       
        //**********************************************************************
        public virtual void AddLineToFunction(string strProjectName, 
                                              string strFormName, 
                                              string strFuncName, 
                                              string strLine, 
                                              int    iPos)
        {
        }

        //**********************************************************************
        //
        // Add a line to the dispose
        //   In: 
        //       strProjectName  :    The project name
        //       strFormName     :    The form in witch the control have to be added
        //       strBody         :    Dispose code
        //   Returns:
        //       
        //**********************************************************************
        public virtual void AddToDispose(string strProjectName, 
                                         string strFormName, 
                                         string strBody)
        {
        }

        //**********************************************************************
        //
        // Add Begin form code
        //   In: 
        //       strProjectName  :    The project name
        //       strFormName     :    The form in witch the control have to be added
        //       strBaseForm     :    The base form name
        //       strCardName     :    The card name
        //       bUseSelectBuffer:    True to indicates that a selection buffer is used
        //       strClassWrapName:    Class wrapper name for the card instance
        //   Returns:
        //       
        //**********************************************************************
        public virtual void AddBeginFormCode(string strProjectName, 
                                             string strFormName, 
                                             string strBaseForm, 
                                             string strCardName, 
                                             bool   bUseSelectBuffer, 
                                             string strClassWrapName)
        {
        }

        //**********************************************************************
        //
        // Add a card group control clean up
        //   In: 
        //       strProjectName:    The project name
        //       strFormName   :    The form in witch the control have to be added
        //       strGrpCtlName :    The card group control name
        //       strGrpName    :    The group name
        //   Returns:
        //       
        //**********************************************************************
        public virtual void AddCardGroupCleanCode(string strProjectName, 
                                                  string strFormName, 
                                                  string strGrpCtlName, 
                                                  string strGrpName)
        {
        }

        //**********************************************************************
        //
        // Add a card group control initialization
        //   In: 
        //       strProjectName     :    The project name
        //       strFormName        :    The form in witch the control have to be added
        //       strGrpCtlName      :    The card group control name
        //       strGrpName         :    The group name
        //       strFatherCrdGrpCtl :    The father card group control name
        //       strGridName        :    The grid name
        //   Returns:
        //       
        //**********************************************************************
        public virtual void AddCardGroupInitCode(string strProjectName, 
                                                 string strFormName, 
                                                 string strGrpCtlName, 
                                                 string strGrpName, 
                                                 string strFatherCrdGrpCtl, 
                                                 string strGridName, 
                                                 bool   bChildRoolGroup, 
                                                 int    iChildIndex,
                                                 bool   bUseSelectBuffer)
        {
        }

        //**********************************************************************
        //
        // Add begin child form code
        //   In: 
        //       strProjectName  :    The project name
        //       strFormName     :    The form in witch the control have to be added
        //       strBaseFormName :    The base form name
        //       arrCardName     :    Array of childs card name
        //       bUseSelectBuffer:    True to use a selection buffer
        //   Returns:
        //       
        //**********************************************************************
        public virtual void AddBeginChildCode(string    strProjectName, 
                                              string    strFormName, 
                                              string    strBaseFormName, 
                                              string[]  arrCardName, 
                                              bool      bUseSelectBuffer)
        {
        }

        //**********************************************************************
        //
        // Add end child form code
        //   In: 
        //       strProjectName:    The project name
        //       strFormName   :    The form in witch the control have to be added
        //       bUseSelectBuffer:  True to generate application with a selection buffer
        //   Returns:
        //       
        //**********************************************************************
        public virtual void AddEndChildCode(string  strProjectName, 
                                            string  strFormName, 
                                            bool    bUseSelectBuffer)
        {
        }

        //**********************************************************************
        //
        // Adjuste the component name by removing bad characters
        //   In: 
        //       strName   :    The control name
        //       strDefault:    The defalult name witch will be returned if all 
        //                      characters in the component name are bad
        //
        //   Returns:
        //
        //**********************************************************************
        public string AdjustComponentName(string strName, 
                                          string strDefault)
        {
	        string strRetVal;
	        int    iLen;
	        int    iIndex;
	        char   cChr;

	        strRetVal = strDefault;
	        strName   = strName.Trim();
	        iLen      = strName.Length;
	        if (iLen == 0) {
		        strRetVal = strDefault;
	        } else if (strName.Substring(0, 1).CompareTo("0") >= 0 && strName.Substring(0, 1).CompareTo("9") <= 0) {
		        strRetVal = strDefault;
	        } else {
		        strRetVal = "";
		        for (iIndex = 0; iIndex < iLen; iIndex++) {
			        cChr = Char.Parse(strName.Substring(iIndex, 1));
			        if (Char.IsLetterOrDigit(cChr) || cChr == '_') {
				        strRetVal = strRetVal + cChr;
			        }
		        }
		        if (strRetVal.Length == 0) {
			        strRetVal = strDefault;
		        }
	        }
	        return strRetVal;
        }

        //**********************************************************************
        //
        // Find Text
        //   In: 
        //       epStart :    Start Edit point
        //       epEnd   :    End Edit point
        //       strText :    String to find 
        //   Returns:
        //       true if the string is found
        //
        //**********************************************************************
        public bool FindText(ref EditPoint  epStart, 
                             EditPoint      epEnd, 
                             string         strText)
        {
	        int     iLinePos;
	        int     iPos;
	        string  strTmp;
	        bool    bRetVal;

	        bRetVal  = false;
	        iLinePos = epStart.Line;
	        while (iLinePos < epEnd.Line && !bRetVal) {
		        strTmp = epStart.GetLines(iLinePos, iLinePos + 1);
		        iPos = strTmp.IndexOf(strText);
		        if (iPos > 0) {
			        epStart.MoveToLineAndOffset(iLinePos, iPos + 1);
			        bRetVal = true;
		        }
		        iLinePos = iLinePos + 1;
	        }
	        return bRetVal;
        }

        //**********************************************************************
        //
        // Replace Text in the specified function 
        //   In: 
        //       funcCode :    function code object
        //       strText  :    String to find 
        //   Returns:
        //       true if the string is found
        //
        //**********************************************************************
        public bool ReplaceFuncText(CodeFunction funcCode, 
                                    string       strText1, 
                                    string       strText2)
        {
	        bool      bRetVal;
	        EditPoint epStart;
	        EditPoint epEnd;

	        epStart = funcCode.StartPoint.CreateEditPoint();
	        epEnd = funcCode.EndPoint.CreateEditPoint();
	        bRetVal = ReplaceText(epStart, epEnd, strText1, strText2);
	        return bRetVal;
        }

        //**********************************************************************
        //
        // Replace all instances of the text
        //   In: 
        //       epStart :    Start Edit point
        //       epEnd   :    End Edit point
        //       strText :    String to find 
        //   Returns:
        //       true if the string is found
        //
        //**********************************************************************
        public bool ReplaceAllText(EditPoint epStart, 
                                   EditPoint epEnd, 
                                   string    strText1, 
                                   string    strText2)
        {
	        bool bRetVal;

	        bRetVal = false;
	        while(FindText(ref epStart, epEnd, strText1)) {
		        bRetVal = true;
		        if (bRetVal) {
			        epStart.Delete(strText1.Length);
			        epStart.Insert(strText2);
		        }
	        }
	        return bRetVal;
        }

        //**********************************************************************
        //
        // Replace the first instance of the text
        //   In: 
        //       epStart :    Start Edit point
        //       epEnd   :    End Edit point
        //       strText :    String to find 
        //   Returns:
        //       true if the string is found
        //
        //**********************************************************************
        public bool ReplaceText(EditPoint epStart, 
                                EditPoint epEnd, 
                                string    strText1, 
                                string    strText2)
        {
	        bool bRetVal;

	        bRetVal = FindText(ref epStart, epEnd, strText1);
	        if (bRetVal) {
		        epStart.Delete(strText1.Length);
		        epStart.Insert(strText2);
	        }
	        return bRetVal;
        }

        //**********************************************************************
        //
        // Get the project object
        //   In: 
        //       strProjectName :    The project name
        //   Returns:
        //       The project object
        //
        //**********************************************************************
        public Project GetProject(string strProjectName)
        {
	        Project oRetVal;

	        oRetVal = null;
   	        foreach (Project oItem in m_vsApp.Solution.Projects) {
		        if (oItem.Name == strProjectName) {
			        oRetVal = oItem;
			        break;
		        }
	        }
	        return oRetVal;
        }

        //**********************************************************************
        //
        // Get Field size
        //   In: 
        //       oField :    The field
        //   Returns:
        //       The field size
        //
        //**********************************************************************
        public int GetFldWidth(RepPP.Field oField)
        {
	        int iSize;
	        int iIndex;

	        iSize = 0;
	        if (oField.IsChoiceAvailable) {
		        for (iIndex = 0; iIndex < oField.ChoiceList.Count - 1; iIndex++) {
			        if (oField.ChoiceList.GetCode(iIndex).Length + oField.ChoiceList.GetDesc(iIndex).Length > iSize) {
				        iSize = oField.ChoiceList.GetCode(iIndex).Length + oField.ChoiceList.GetDesc(iIndex).Length;
			        }
		        }
		        // 9 char between code and description
		        iSize = iSize + 9;
	        } else {
		        iSize = oField.MaxSize + 1;
	        }
	        return iSize * (int) POINTS_PER_CHAR;
        }

        //**********************************************************************
        //
        // Get Max width of static and field Rep++ control
        //   In: 
        //       oFields         :    The fields
        //       iMaxSizeStatCtrl:    Max width of static fields (to be returned)
        //       iMaxSizeFldCtrl :    Max width of rep++ fields (to be returned)
        //       iFrameWidth     :    The frame width
        //   Returns:
        //
        //**********************************************************************
        private void GetMaxWidths(RepPP.Fields oFields, 
                                  ref int      iMaxSizeStatCtrl, 
                                  ref int      iMaxSizeFldCtrl, 
                                  int          iFrameWidth)
        {
	        int         iStatSize;
	        int         iFldSize;

	        iMaxSizeStatCtrl = 0;
	        iMaxSizeFldCtrl  = 0;
	        foreach (RepPP.Field oFld in oFields)
	        {
		        iStatSize = (int)(oFld.Prompt.Length * POINTS_PER_CHAR);
		        iFldSize = GetFldWidth(oFld);
		        if (iStatSize > iMaxSizeStatCtrl) {
			        iMaxSizeStatCtrl = iStatSize;
		        }
                if (iFldSize > iMaxSizeFldCtrl) {
			        iMaxSizeFldCtrl = iFldSize;
		        }
	        }
	        if (iMaxSizeStatCtrl > MAX_STAT_WIDTH) {
		        iMaxSizeStatCtrl = MAX_STAT_WIDTH;
	        }
	        if (iMaxSizeFldCtrl + iMaxSizeStatCtrl + 3 * HORIZ_MARGE_SPACE > iFrameWidth) {
		        iMaxSizeFldCtrl = iFrameWidth - ( iMaxSizeStatCtrl + 3 * HORIZ_MARGE_SPACE );
	        }
        }

        //**********************************************************************
        //
        // Get best rep++ field size
        //   In: 
        //       oField            :    The fields
        //       iMaxFldCtlWidth   :    the Maximum width rep ++ field can take
        //       iBestFldCtlWidth  :    The best rep++ field width
        //       iBestFldCtlHeight :    The best rep++ field height
        //   Returns:
        //
        //**********************************************************************
        private void GetBestSizes(RepPP.Field oField, 
                                  int         iMaxFldCtlWidth, 
                                  ref int     iBestFldCtlWidth, 
                                  ref int     iBestFldCtlHeight)
        {
	        int iFldWidth;

	        iFldWidth = GetFldWidth(oField);
	        switch (oField.ControlType) {
		        case RepPP.CtlType.sdCtlCheck:
		        case RepPP.CtlType.sdCtlRadio:
			        iBestFldCtlWidth = ((iFldWidth > iMaxFldCtlWidth) ? iMaxFldCtlWidth : iFldWidth);
			        iBestFldCtlHeight = DEFAULT_RADIO_HEIGHT * oField.ChoiceList.Count;
			        break;
		        case RepPP.CtlType.sdCtlList:
			        iBestFldCtlWidth = ((iFldWidth > iMaxFldCtlWidth) ? iMaxFldCtlWidth : iFldWidth);
			        iBestFldCtlHeight = DEFAULT_LIST_HEIGHT;
			        break;
		        case RepPP.CtlType.sdCtlCombo:
			        iBestFldCtlWidth = ((iFldWidth > iMaxFldCtlWidth) ? iMaxFldCtlWidth : iFldWidth);
			        iBestFldCtlHeight = DEFAULT_CTL_HEIGHT;
			        break;
		        default:
			        iBestFldCtlWidth = ((iFldWidth > iMaxFldCtlWidth) ? iMaxFldCtlWidth : iFldWidth);
			        if (oField.Type == RepPP.FieldType.sdFieldMemo) {
				        iBestFldCtlHeight = 3 * DEFAULT_CTL_HEIGHT;
			        } else {
				        iBestFldCtlHeight = DEFAULT_CTL_HEIGHT;
			        }
                    break;
	        }
        }

        //**********************************************************************
        //
        // Break up a string defining a size to X and Y position
        // Size(123, 200) ---> X = 123 and Y = 200
        //   In: 
        //       strSize :   String defining a size
        //       iXPos   :   X position
        //       iYPos   :   Y position
        //   Returns:
        //
        //**********************************************************************
        private void BreakUpSize(string  strSize, 
                                 ref int iXPos, 
                                 ref int iYPos)
        {
	        int    iIndex1;
	        int    iIndex2;
	        int    iIndex3;
	        string strTmp;

	        iIndex1 = strSize.IndexOf("(");
	        iIndex2 = strSize.IndexOf(",");
	        iIndex3 = strSize.IndexOf(")");
	        if (iIndex1 != - 1 && iIndex2 != 0 && iIndex3 != 0) {
		        strTmp = strSize.Substring(iIndex1 + 1, strSize.Length - 7);
		        iXPos = int.Parse(strTmp.Substring(0, iIndex2 - iIndex1 - 1).Trim());
	            iIndex2 = strTmp.IndexOf(",");
		        iYPos = int.Parse(strTmp.Substring(iIndex2 + 1).Trim());
	        }
        }

        //**********************************************************************
        //
        // Get unique name for the control by adding an index
        //   In: 
        //       strProjectName:    The project name
        //       strFormName   :    The form in witch the control have to be added
        //       strFormExt    :    Form extention (.vb, cs, ...)
        //       strCtlName    :    The control name
        //   Returns:
        //       The new control name
        //
        //**********************************************************************
        protected virtual string GetUniqueCtlName(string strProjectName, 
                                                  string strFormName, 
                                                  string strCtlName) {
	        return strCtlName;
        }

        //**********************************************************************
        //
        // Get unique name for the control by adding an index
        //   In: 
        //       strProjectName:    The project name
        //       strFormName   :    The form in witch the control have to be added
        //       strCtlName    :    The control name
        //   Returns:
        //       The new control name
        //
        //**********************************************************************
        protected virtual string GetUniqueFormName(string strProjectName, 
                                                   string strFormName) {
	        return strFormName;
        }

        //**********************************************************************
        //
        // Add a variable to a form
        //   In: 
        //       strProjectName:    The project name
        //       strFormName   :    The form in witch the variable have to be added
        //       strVarName    :    The variable name
        //       strVarType    :    The variable type
        //       eAccess       :    The variable access type
        //       bIsConstant   :    If the variable is constant
        //       strInitValue  :    Initialization value
        //   Returns:
        //
        //**********************************************************************
        protected virtual void AddVariable(string      strProjectName, 
                                           string      strFormName, 
                                           string      strVarName, 
                                           string      strVarType, 
                                           vsCMAccess  eAccess, 
                                           string      strComment,
                                           bool        bIsConstant,
                                           string      strInitValue) {
        }

        //**********************************************************************
        //
        // Buid a fprmatted string from array
        //   In: 
        //       arrString:    Array list
        //
        //**********************************************************************    
        protected string BuildStringFromArray(string[] arrString)
        {
	        string strListParam;

	        strListParam = "";
	        foreach(string str in arrString) {
		        if (strListParam != "") {
			        strListParam = strListParam + ", ";
		        }
		        strListParam = strListParam + "\"" + str + "\"";
	        }
	        return(strListParam);
        }

        //**********************************************************************
        //
        // Get the program language code (0: VB, 1: CS)
        //
        //**********************************************************************    
        protected virtual int GetLanguage() {
	        return(0);
        }

        //**********************************************************************
        //
        // Add the DotNetBar XML File from rep++ extended framework
        // IN:
        //   strProjectName:     Project name
        //
        //**********************************************************************        
        protected void AddDNetBarXMLFile(string strProjectName)
        {
	        Project                     oProject;
	        ProjectItem                 projItem;
	        Microsoft.Win32.RegistryKey key;
	        string                      strFileName;

	        oProject = GetProject(strProjectName);
	        if (oProject != null) {
		        try {
			        projItem = oProject.ProjectItems.Item("frmBaseSBEditor.dotNetBarManagerMain.xml");
		        } catch {
			        projItem = null;
		        }
		        if (projItem == null) {
			        key = Microsoft.Win32.Registry.LocalMachine.OpenSubKey(Global.REGKEY_INSTALLDIR);
			        if (key != null) {
				        strFileName = key.GetValue("", "").ToString().Trim();
				        key.Close();
				        strFileName = Path.Combine(strFileName, @"source\sdtkdock\frmBaseSBEditor.dotNetBarManagerMain.xml");
				        if (System.IO.File.Exists(strFileName)) {
					        oProject.ProjectItems.AddFromFileCopy(strFileName);
				        }
			        }
		        }
	        }
        }

        //*********************************************************     
        //
        /// <summary>
        /// GenCardTypedInstance:           Genearte card typed instance 
        /// </summary>
        /// <param name="strPrjName">       Project name</param>
        /// <param name="strCardName">      Card name</param>
        //
        //*********************************************************     
        protected virtual void GenCardTypedInstance(string strPrjName, string strCardName) {
        }

        //*********************************************************     
        //
        /// <summary>
        /// GenGroupTypedInstanceV:         Genearte group typed instance 
        /// </summary>
        /// <param name="strPrjName">       Project name</param>
        /// <param name="strGroupName">     Group name</param>
        //
        //*********************************************************     
        protected virtual void GenGroupTypedInstance(string strPrjName, string strGroupName) {
        }
#if VC8

        //**********************************************************************
        //
        /// <summary>
        /// ReplaceLineInProjItem:          Replace line in the project item
        /// </summary>
        /// <param name="strProjectName">   Project name</param>
        /// <param name="strProjItemName">  Project item name</param>
        /// <param name="strOldLineStart">  Line to replace</param>
        /// <param name="strNewLine">       New line text</param>
        //
        //**********************************************************************
        protected void ReplaceLineInProjItem(string strProjectName, 
                                             string strProjItemName,
                                             string strOldLineStart, 
                                             string strNewLine) {
            string          strText;
            string          strFileName;
            Project         project;
            ProjectItem     projectItem;
            StreamReader    reader;
            StreamWriter    writer;
            int             iIndex1;
            int             iIndex2;

            project     = Utility.GetProject(m_vsApp, strProjectName);
            projectItem = Utility.FindProjectItem(project, strProjItemName);
            if (projectItem != null) {
                strFileName = projectItem.get_FileNames(1);
                using (reader = File.OpenText(strFileName)) {
                    strText = reader.ReadToEnd();
                }
                iIndex1 = strText.IndexOf(strOldLineStart);
                iIndex2 = strText.IndexOf("\r\n", iIndex1);
                strText = strText.Substring(0, iIndex1) +
                          strNewLine +
                          strText.Substring(iIndex2 + 2);
                using (writer = new StreamWriter(strFileName)) {
                    writer.Write(strText);
                }
            }
        }
#endif

        //**********************************************************************
        //
        /// <summary>
        /// ReplaceFormTags:                Replace the tags in a form file after generating
        ///                                 it using a template
        /// </summary>
        /// <param name="strFormFileName">  Form file full path</param>
        /// <param name="strClassName">     Class name</param>
        /// <param name="strNameSpace">     Namespace</param>
        //
        //**********************************************************************
        protected void ReplaceFormTags(string strFormFileName, string strClassName, string strNameSpace) {
	        StreamReader    streamRd;
	        StreamWriter    streamWr;
	        string          strTxtRead = "";
	        string          strTxtWrite;
            int             iStrTxtRead;
            int             iIndex;
            
	        streamRd = File.OpenText(strFormFileName);
	        if (streamRd != null) {
		        strTxtRead = streamRd.ReadToEnd();
		        streamRd.Close();
	        }
            iStrTxtRead  = strTxtRead.Length;
            strTxtRead   = strTxtRead.Replace("[!output SAFE_CLASS_NAME]", strClassName);
            strTxtWrite  = strTxtRead;
	        strTxtWrite  = strTxtWrite.Replace("[!output SAFE_NAMESPACE_NAME]", strNameSpace);
	        if ((iStrTxtRead) > (strTxtWrite.Length)) {
		        for (iIndex = 1; iIndex <= strTxtRead.Length - strTxtWrite.Length; iIndex++) {
			        strTxtWrite = strTxtWrite + " ";
		        }
	        }
            using (streamWr = Utility.CreateTextFile(strFormFileName, Utility.ReplaceFileModeE.sdReplaceWithoutAsk)) {
                streamWr.Write(strTxtWrite);
            }
        }
	}
}
