//*********************************************************
//
// frmMainBase:     Base main form in which the step forms will be attached
//
// Author:		    Maher Najah
//
// (c) 2003 by Consyst SQL Inc.
//
//
//*********************************************************
using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;
using System.Xml;
using System.IO;
using sdfwwebcsnet;
using System.Web;
using Microsoft.Win32;

namespace RepPP.VSNetWizard
{
    /// <summary>
    /// Generation Mode
    /// </summary>
    internal enum GenerationModeE {
        sdApplication   = 1,  // Application generation
        sdItemGroup     = 2,  // Item group generation
        sdItemCard      = 4,  // Item card without selection buffer
        sdItem          = 6   // Item generation
    }

    /// <summary>
    /// Language
    /// </summary>
    internal enum ProgramLanguageE {
        sdCSharp        = 1,  // C# language
        sdVisualBasic   = 2   // VB language
    }

	/// <summary>
	/// frmMainBase:    Base class for main wizard form.
	/// </summary>
	internal class frmMainBase : System.Windows.Forms.Form
	{
        protected int                               m_iCurStep;             // Current step
        protected RepPP.Application                 m_app;                  // Rep++ application object
        protected EnvDTE.DTE                        m_vsApp;                // Visual studio instance object
        protected string                            m_strPrjName;           // Project name
        protected string                            m_strPrjFullName;       // Project full name
        protected GenerationModeE                   m_eWizardMode;          // Generation type (application ,item)
        protected ProgramLanguageE                  m_eLang;                // Language (CS, VB)
                   
        protected System.Windows.Forms.Panel        pnlMain;
        protected System.Windows.Forms.Button       butCancelFinish;
        protected System.Windows.Forms.Button       butNext;
        protected System.Windows.Forms.Button       butBack;
        protected System.Windows.Forms.PictureBox   pictureBox1;
        protected System.Windows.Forms.GroupBox     grpBar;
		private System.ComponentModel.Container     components = null;

        //******************************************************************
        //
        /// <summary>
        /// ctor:                       Class constructor
        /// </summary>
        //
        //******************************************************************
		public frmMainBase() {
			InitializeComponent();
		}

        //******************************************************************
        //
        /// <summary>
        /// ctor:                           Class constructor
        /// </summary>
        /// <param name="vsApp">            Visual studio application</param>
        /// <param name="strPrjName">       Project name</param>
        /// <param name="strPrjFullName">   Project full name</param>
        /// <param name="eGenType">         Generation type</param>
        /// <param name="eLang">            Language</param>
        //
        //******************************************************************
		public frmMainBase(EnvDTE.DTE       vsApp,
                           string           strPrjName,
                           string           strPrjFullName,
                           ProgramLanguageE eLang,
                           GenerationModeE  eMode) {
			InitializeComponent();
            m_vsApp                   = vsApp;
            m_strPrjName              = strPrjName;
            m_strPrjFullName          = strPrjFullName;
            m_eWizardMode             = eMode;
            m_eLang                   = eLang;
            m_iCurStep                = 0;
            m_app                     = null;
            butNext.Click            += new System.EventHandler(OnButNextClick);
            butBack.Click            += new System.EventHandler(OnButBackClick);
            butCancelFinish.Click    += new System.EventHandler(OnButCancelFinishClick);
		}

        //******************************************************************
        //
        /// <summary>
        /// Dispose:                    Dispose the form
        /// </summary>
        /// <param name="bDisposing">   true if disposing, false if finalizing</param>
        //
        //******************************************************************
        protected override void Dispose(bool bDisposing) {
            if (bDisposing) {
                if (components != null) {
                    components.Dispose();
                }
            }
            base.Dispose(bDisposing);
        }

        //******************************************************************
        //
        /// <summary>
        /// ProjectName:             Project name
        /// </summary>
        //
        //******************************************************************
        public string ProjectName {
            get {
                return(m_strPrjName);
            }
            set {
                m_strPrjName = value;
            }
        }

        //******************************************************************
        //
        /// <summary>
        /// ProjectFullName:        Project full name
        /// </summary>
        //
        //******************************************************************
        public string ProjectFullName {
            get {
                return(m_strPrjFullName);
            }
            set {
                m_strPrjFullName = value;
            }
        }

        //******************************************************************
        //
        /// <summary>
        /// NextButton:             Next button
        /// </summary>
        //
        //******************************************************************
        public Button NextButton {
            get {
                return(butNext);
            }
        }

        //******************************************************************
        //
        /// <summary>
        /// BackButton:             Back button
        /// </summary>
        //
        //******************************************************************
        public Button BackButton {
            get {
                return(butBack);
            }
        }

        //******************************************************************
        //
        /// <summary>
        /// PanelMain:             Main panel
        /// </summary>
        //
        //******************************************************************
        public Panel MainPanel {
            get {
                return(pnlMain);
            }
        }

        //******************************************************************
        //
        /// <summary>
        /// CancelFinishButton:             Cancel/Finish button
        /// </summary>
        //
        //******************************************************************
        public Button CancelFinishButton {
            get {
                return(butCancelFinish);
            }
        }

        //******************************************************************
        //
        /// <summary>
        /// GenerationMode:     Wizard mode(Application mode or item mode)
        /// </summary>
        //
        //******************************************************************
        public GenerationModeE WizardMode {
            get {
                return(m_eWizardMode);
            }
        }

        //******************************************************************
        //
        /// <summary>
        /// Application:             Rep++ Application object
        /// </summary>
        //
        //******************************************************************
        public RepPP.Application Application {
            get {
                return(m_app);
            }
            set {
                m_app = value;
            }
        }

        //******************************************************************
        //
        /// <summary>
        /// ProgramLanguage:             Get the programming language
        /// </summary>
        //
        //******************************************************************
        public ProgramLanguageE ProgramLanguage {
            get {
                return(m_eLang);
            }
        }

        //******************************************************************
        //
        /// <summary>
        /// CurrentProject:       Get the current project if it's already created
        ///                       (case of Add Item), otherwise it returns null
        /// </summary>
        //
        //******************************************************************
        public EnvDTE.Project CurrentProject {
            get {
                EnvDTE.Project prjRetVal = null;

                if (m_strPrjName != String.Empty && m_eWizardMode == GenerationModeE.sdItem) {
                    prjRetVal = Utility.GetProject(m_vsApp, m_strPrjName);
                }
                return(prjRetVal);
            }
        }

        //******************************************************************
        //
        /// <summary>
        /// InitializeRepPP:            Initialize rep++ application. If Rep++ is already
        ///                             initialized we reset it otherwize we create a new one.
        /// </summary>
        /// <param name="strSysName">   System name</param>
        /// <param name="strProgName">  Program name</param>
        /// <param name="strConnName">  Connection name</param>
        /// <param name="strUserName">  User name</param>
        /// <param name="strPwd">       Password</param>
        /// <param name="eLang">        Language</param>
        /// <returns>
        /// True:                       Rep++ is initialized with success
        /// Flase:                      Rep++ is not initialized
        /// </returns>
        //  
        //******************************************************************
        protected virtual bool InitializeRepPP(string             strSysName,
                                               string             strProgName,
                                               string             strConnName,
                                               string             strUserName,
                                               string             strPwd,
                                               RepPP.LanguageCode eLang) {
            bool bRetVal;

            m_app = RepPP.Application.GetApplication();
            if (m_app != null) {
                //if (!m_app.IsThisInstance(strSysName, strProgName, strConnName, strUserName, strPwd, eLang, 4096)) {
                    RepPP.Application.Reset(null);
                //}
            } else {
                m_app = RepPP.Application.Create();
            }
            if (!m_app.IsProgramStarted()) {
                if (m_app.Init(strSysName,
                               strProgName,
                               strConnName,
                               strUserName,
                               strPwd,
                               eLang,
                               4096) != 0) {    // 4096-> Rep++ in design mode
                    MessageBox.Show("Unable to initialize Rep++.", 
                                    "Rep++ Wizard",
                                    MessageBoxButtons.OK, 
                                    MessageBoxIcon.Error);
                    RepPP.Application.Reset(null);
                    m_app   = null;
                    bRetVal = false;
                } else {
                    bRetVal = true;
                }
            } else {
                bRetVal = true;
            }
            return(bRetVal);
        }

        //*********************************************************     
        //
        /// <summary>
        /// SetStepPanelv:          Set the step panel by the panel defined in the form
        /// </summary>
        /// <param name="frmStep">  The form defining the step panel</param>
        /// <param name="bNext">    True to indicates that this step is the next of the current step</param>
        //  
        //*********************************************************     
        protected void SetStepPanelV(frmStepBase frmStep, bool bNext) {
            frmStep.AttachToMainPanelV();
            if (bNext) {
                frmStep.InitV();
                butBack.Enabled = true;
                butNext.Enabled = frmStep.ValidateB();
            } else {
                butBack.Enabled = true;
                butNext.Enabled = true;
            }
        }

        //*********************************************************     
        //
        /// <summary>
        /// OnButNextClick:         Handle next button click event
        /// </summary>
        /// <param name="sender">   Sender object   </param>
        /// <param name="e">        Event Arguments </param>
        //  
        //*********************************************************     
        protected virtual void OnButNextClick(object sender, System.EventArgs e) {
        }

        //*********************************************************     
        //
        /// <summary>
        /// OnButBackClick:         Handle back button click event
        /// </summary>
        /// <param name="sender">   Sender object   </param>
        /// <param name="e">        Event Arguments </param>
        //  
        //*********************************************************     
        protected virtual void OnButBackClick(object sender, System.EventArgs e) {
        }

        //*********************************************************     
        //
        /// <summary>
        /// OnButCancelFinishClick:     Handle cancel/finish button click event
        /// </summary>
        /// <param name="sender">       Sender object   </param>
        /// <param name="e">            Event Arguments </param>
        //  
        //*********************************************************     
        protected virtual void OnButCancelFinishClick(object sender, System.EventArgs e) {
        }

        //*********************************************************     
        //
        /// <summary>
        /// Generate:                   Generate items
        /// </summary>
        //  
        //*********************************************************     
        public virtual void Generate() {
        }
		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
            this.pnlMain = new System.Windows.Forms.Panel();
            this.butCancelFinish = new System.Windows.Forms.Button();
            this.butNext = new System.Windows.Forms.Button();
            this.butBack = new System.Windows.Forms.Button();
            this.pictureBox1 = new System.Windows.Forms.PictureBox();
            this.grpBar = new System.Windows.Forms.GroupBox();
            this.SuspendLayout();
            // 
            // pnlMain
            // 
            this.pnlMain.Location = new System.Drawing.Point(138, 0);
            this.pnlMain.Name = "pnlMain";
            this.pnlMain.Size = new System.Drawing.Size(416, 280);
            this.pnlMain.TabIndex = 0;
            // 
            // butCancelFinish
            // 
            this.butCancelFinish.BackColor = System.Drawing.SystemColors.Control;
            this.butCancelFinish.Cursor = System.Windows.Forms.Cursors.Default;
            this.butCancelFinish.Font = new System.Drawing.Font("Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
            this.butCancelFinish.ForeColor = System.Drawing.SystemColors.ControlText;
            this.butCancelFinish.Location = new System.Drawing.Point(470, 292);
            this.butCancelFinish.Name = "butCancelFinish";
            this.butCancelFinish.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.butCancelFinish.Size = new System.Drawing.Size(73, 23);
            this.butCancelFinish.TabIndex = 7;
            this.butCancelFinish.Tag = "104";
            this.butCancelFinish.Text = "&Cancel";
            // 
            // butNext
            // 
            this.butNext.BackColor = System.Drawing.SystemColors.Control;
            this.butNext.Cursor = System.Windows.Forms.Cursors.Default;
            this.butNext.Font = new System.Drawing.Font("Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
            this.butNext.ForeColor = System.Drawing.SystemColors.ControlText;
            this.butNext.Location = new System.Drawing.Point(382, 292);
            this.butNext.Name = "butNext";
            this.butNext.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.butNext.Size = new System.Drawing.Size(73, 23);
            this.butNext.TabIndex = 6;
            this.butNext.Tag = "103";
            this.butNext.Text = "&Next >";
            // 
            // butBack
            // 
            this.butBack.BackColor = System.Drawing.SystemColors.Control;
            this.butBack.Cursor = System.Windows.Forms.Cursors.Default;
            this.butBack.Font = new System.Drawing.Font("Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
            this.butBack.ForeColor = System.Drawing.SystemColors.ControlText;
            this.butBack.Location = new System.Drawing.Point(304, 292);
            this.butBack.Name = "butBack";
            this.butBack.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.butBack.Size = new System.Drawing.Size(73, 23);
            this.butBack.TabIndex = 5;
            this.butBack.Tag = "102";
            this.butBack.Text = "< &Back";
            // 
            // pictureBox1
            // 
            this.pictureBox1.Location = new System.Drawing.Point(0, 0);
            this.pictureBox1.Name = "pictureBox1";
            this.pictureBox1.Size = new System.Drawing.Size(144, 280);
            this.pictureBox1.TabIndex = 8;
            this.pictureBox1.TabStop = false;
            // 
            // grpBar
            // 
            this.grpBar.Location = new System.Drawing.Point(0, 280);
            this.grpBar.Name = "grpBar";
            this.grpBar.Size = new System.Drawing.Size(560, 4);
            this.grpBar.TabIndex = 9;
            this.grpBar.TabStop = false;
            // 
            // frmMainBase
            // 
            this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
            this.ClientSize = new System.Drawing.Size(554, 326);
            this.Controls.Add(this.grpBar);
            this.Controls.Add(this.pictureBox1);
            this.Controls.Add(this.butCancelFinish);
            this.Controls.Add(this.butNext);
            this.Controls.Add(this.butBack);
            this.Controls.Add(this.pnlMain);
            this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedSingle;
            this.MaximizeBox = false;
            this.MinimizeBox = false;
            this.Name = "frmMainBase";
            this.StartPosition = System.Windows.Forms.FormStartPosition.CenterScreen;
            this.Text = "Rep++ Wizard";
            this.ResumeLayout(false);

        }
		#endregion
	} // class frmMainBase
} // namespace
