using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using RepPP.VSNetWizard;

namespace RepPP.VSNetWizard.TypedInst
{
	/// <summary>
	/// Step 2 form: select cards and groups
	/// </summary>
	internal class frmStep2 : frmStepBase
	{
        internal System.Windows.Forms.Button            butNoneCards;
        internal System.Windows.Forms.Button            butAllCards;
        internal System.Windows.Forms.CheckedListBox    chkLstCards;
        internal System.Windows.Forms.Label             lblCards;
        internal System.Windows.Forms.Button            butNoneGroups;
        internal System.Windows.Forms.Button            butAllGroups;
        internal System.Windows.Forms.CheckedListBox    chkLstGroups;
        internal System.Windows.Forms.Label             lblGroups;
		private System.ComponentModel.Container         components = null;

        /// <summary>Hash table to save the auto-checked group</summary>
        private Hashtable                               m_hashAutocheckGroup;

        //******************************************************************
        //
        /// <summary>
        /// ctor:                       Class constructor
        /// </summary>
        //
        //******************************************************************
		public frmStep2() {
			InitializeComponent();
		}

        //******************************************************************
        //
        /// <summary>
        /// ctor:                       Class constructor
        /// </summary>
        /// <param name="frmMain">      Main form</param>
        //
        //******************************************************************
		public frmStep2(frmMain frmMain) : base(frmMain) {
			InitializeComponent();
            m_hashAutocheckGroup = new Hashtable();
        }

        //******************************************************************
        //
        /// <summary>
        /// Dispose:                    Dispose the form
        /// </summary>
        /// <param name="bDisposing">   true if disposing, false if finalizing</param>
        //
        //******************************************************************
        protected override void Dispose(bool bDisposing) {
            if (bDisposing) {
                if (components != null) {
                    components.Dispose();
                }
            }
            base.Dispose(bDisposing);
        }

        //******************************************************************
        //
        /// <summary>
        /// ValidateB:                    Validate the step
        /// </summary>
        /// <returns>
        /// True:   Valid
        /// False:  Not Valid
        /// </returns>
        //
        //******************************************************************
        public override bool ValidateB() {
            return(chkLstCards.CheckedIndices.Count > 0 ||
                   chkLstGroups.CheckedIndices.Count > 0);   
        }

        //******************************************************************
        //
        /// <summary>
        /// InitV:                    Initialize the step
        /// </summary>
        //
        //******************************************************************
        public override void InitV() {
            RepPP.IApplication  app;

            app = m_frmMain.Application;
            chkLstCards.Items.Clear();
            foreach (RepPP.Card crd in app.Cards) {
                chkLstCards.Items.Add(crd.Name);
            }
            butAllCards.Enabled  = (chkLstCards.Items.Count > 0);
            butNoneCards.Enabled = butAllCards.Enabled;
            chkLstGroups.Items.Clear();
            foreach (RepPP.Group grp in app.Groups) {
                chkLstGroups.Items.Add(grp.Name);
            }
            butAllGroups.Enabled  = (chkLstGroups.Items.Count > 0);
            butNoneGroups.Enabled = butAllGroups.Enabled;
        }

        //******************************************************************
        //
        /// <summary>
        /// SelectedCards:             Selected cards list
        /// </summary>
        //
        //******************************************************************
        public ArrayList SelectedCards {
            get {
                return(new ArrayList(chkLstCards.CheckedItems));
            }
        }

        //******************************************************************
        //
        /// <summary>
        /// SelectedGroups:             Selected groups list
        /// </summary>
        //
        //******************************************************************
        public ArrayList SelectedGroups {
            get {
                return(new ArrayList(chkLstGroups.CheckedItems));
            }
        }

        //******************************************************************
        //
        /// <summary>
        /// CheckAllListItemsv:     Check or not all the check listbox items
        /// </summary>
        /// <param name="chkLst">   Checked listbox</param>
        /// <param name="bCheck">   True to check items</param>
        //
        //******************************************************************
        private void CheckAllListItemsv(CheckedListBox chkLst, bool bCheck) {
            int iIndex;

            for (iIndex = 0; iIndex < chkLst.Items.Count; iIndex++) {
                chkLst.SetItemChecked(iIndex, bCheck);
            }
            m_frmMain.NextButton.Enabled = ValidateB();
        }

        //******************************************************************
        //
        /// <summary>
        /// OnButAllCardsClick:         Handle click event on all cards button
        /// </summary>
        /// <param name="sender">       Sender</param>
        /// <param name="e">            Event arguments</param>
        //
        //******************************************************************
        private void OnButAllCardsClick(object sender, EventArgs e) {
            CheckAllListItemsv(chkLstCards, true);
        }

        //******************************************************************
        //
        /// <summary>
        /// OnButNoneCardsClick:         Handle click event on none cards button
        /// </summary>
        /// <param name="sender">       Sender</param>
        /// <param name="e">            Event arguments</param>
        //
        //******************************************************************
        private void OnButNoneCardsClick(object sender, System.EventArgs e) {
            CheckAllListItemsv(chkLstCards, false);
        }

        //******************************************************************
        //
        /// <summary>
        /// OnButAllGroupsClick:        Handle click event on all groups button
        /// </summary>
        /// <param name="sender">       Sender</param>
        /// <param name="e">            Event arguments</param>
        //
        //******************************************************************
        private void OnButAllGroupsClick(object sender, System.EventArgs e) {
            CheckAllListItemsv(chkLstGroups, true);
        }

        //******************************************************************
        //
        /// <summary>
        /// OnButNoneGroupsClick:      Handle click event on none groups button
        /// </summary>
        /// <param name="sender">       Sender</param>
        /// <param name="e">            Event arguments</param>
        //
        //******************************************************************
        private void OnButNoneGroupsClick(object sender, System.EventArgs e) {
            CheckAllListItemsv(chkLstGroups, false);
        }

        //******************************************************************
        //
        /// <summary>
        /// OnListSelectedIndexChanged:     Handle selected index changed event on cards list
        ///                                 and groups list
        /// </summary>
        /// <param name="sender">           Sender</param>
        /// <param name="e">                Event arguments</param>
        //
        //******************************************************************
        private void OnListSelectedIndexChanged(object sender, System.EventArgs e) {
            m_frmMain.NextButton.Enabled = ValidateB();
        }

        //******************************************************************
        //
        /// <summary>
        /// OnCardItemCheck:            Handle item check event for the card list
        /// </summary>
        /// <param name="sender">       Sender</param>
        /// <param name="e">            Event arguments</param>
        //
        //******************************************************************
        private void OnCardItemCheck(object sender, ItemCheckEventArgs e) {
            string[]    arrGroupName;
            bool        bChecked;
            int         iIndex;
            string      strCardName;
            int         iCount;

            bChecked     = (e.NewValue == CheckState.Checked);
            strCardName  = chkLstCards.Items[e.Index].ToString();
            arrGroupName = Utility.GetGroupNameList(m_frmMain.Application.Cards[strCardName]);
            foreach (string strGroupName in arrGroupName) {
                iIndex = chkLstGroups.Items.IndexOf(strGroupName);
                if (bChecked) {
                    if (m_hashAutocheckGroup[strGroupName] != null) {
                        iCount = int.Parse(m_hashAutocheckGroup[strGroupName].ToString()) + 1;
                        m_hashAutocheckGroup[strGroupName] = iCount;
                    } else {
                        m_hashAutocheckGroup.Add(strGroupName, "1");
                        chkLstGroups.SetItemCheckState(iIndex, CheckState.Indeterminate);
                    }
                } else {
                    iCount = int.Parse(m_hashAutocheckGroup[strGroupName].ToString()) -1;
                    if (iCount == 0) {
                        m_hashAutocheckGroup.Remove(strGroupName);
                        chkLstGroups.SetItemChecked(iIndex, false);
                    }
                }
            }
        }

        //******************************************************************
        //
        /// <summary>
        /// OnGroupItemCheck:           Handle item check event for the card list
        /// </summary>
        /// <param name="sender">       Sender</param>
        /// <param name="e">            Event arguments</param>
        //
        //******************************************************************
        private void OnGroupItemCheck(object sender, ItemCheckEventArgs e) {
            string strGroupName;

            strGroupName = chkLstGroups.Items[e.Index].ToString();
            if (m_hashAutocheckGroup[strGroupName] != null) {
                e.NewValue = CheckState.Indeterminate;
            }
        }
		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
            this.butNoneCards = new System.Windows.Forms.Button();
            this.butAllCards = new System.Windows.Forms.Button();
            this.chkLstCards = new System.Windows.Forms.CheckedListBox();
            this.lblCards = new System.Windows.Forms.Label();
            this.butNoneGroups = new System.Windows.Forms.Button();
            this.butAllGroups = new System.Windows.Forms.Button();
            this.chkLstGroups = new System.Windows.Forms.CheckedListBox();
            this.lblGroups = new System.Windows.Forms.Label();
            this.pnlStep.SuspendLayout();
            this.SuspendLayout();
            // 
            // pnlStep
            // 
            this.pnlStep.BackColor = System.Drawing.SystemColors.Control;
            this.pnlStep.Controls.Add(this.butNoneGroups);
            this.pnlStep.Controls.Add(this.butAllGroups);
            this.pnlStep.Controls.Add(this.chkLstGroups);
            this.pnlStep.Controls.Add(this.lblGroups);
            this.pnlStep.Controls.Add(this.butNoneCards);
            this.pnlStep.Controls.Add(this.butAllCards);
            this.pnlStep.Controls.Add(this.chkLstCards);
            this.pnlStep.Controls.Add(this.lblCards);
            this.pnlStep.Location = new System.Drawing.Point(16, 8);
            this.pnlStep.Size = new System.Drawing.Size(416, 280);
            // 
            // butNoneCards
            // 
            this.butNoneCards.Location = new System.Drawing.Point(152, 16);
            this.butNoneCards.Name = "butNoneCards";
            this.butNoneCards.Size = new System.Drawing.Size(48, 24);
            this.butNoneCards.TabIndex = 29;
            this.butNoneCards.Text = "None";
            this.butNoneCards.Click += new System.EventHandler(this.OnButNoneCardsClick);
            // 
            // butAllCards
            // 
            this.butAllCards.Location = new System.Drawing.Point(96, 16);
            this.butAllCards.Name = "butAllCards";
            this.butAllCards.Size = new System.Drawing.Size(48, 24);
            this.butAllCards.TabIndex = 28;
            this.butAllCards.Text = "All";
            this.butAllCards.Click += new System.EventHandler(this.OnButAllCardsClick);
            // 
            // chkLstCards
            // 
            this.chkLstCards.CheckOnClick = true;
            this.chkLstCards.Location = new System.Drawing.Point(16, 48);
            this.chkLstCards.Name = "chkLstCards";
            this.chkLstCards.Size = new System.Drawing.Size(182, 214);
            this.chkLstCards.Sorted = true;
            this.chkLstCards.TabIndex = 27;
            this.chkLstCards.SelectedIndexChanged += new System.EventHandler(this.OnListSelectedIndexChanged);
            this.chkLstCards.ItemCheck += new System.Windows.Forms.ItemCheckEventHandler(this.OnCardItemCheck);
            // 
            // lblCards
            // 
            this.lblCards.Location = new System.Drawing.Point(16, 24);
            this.lblCards.Name = "lblCards";
            this.lblCards.Size = new System.Drawing.Size(40, 16);
            this.lblCards.TabIndex = 26;
            this.lblCards.Text = "Cards:";
            // 
            // butNoneGroups
            // 
            this.butNoneGroups.Location = new System.Drawing.Point(352, 16);
            this.butNoneGroups.Name = "butNoneGroups";
            this.butNoneGroups.Size = new System.Drawing.Size(48, 24);
            this.butNoneGroups.TabIndex = 33;
            this.butNoneGroups.Text = "None";
            this.butNoneGroups.Click += new System.EventHandler(this.OnButNoneGroupsClick);
            // 
            // butAllGroups
            // 
            this.butAllGroups.Location = new System.Drawing.Point(296, 16);
            this.butAllGroups.Name = "butAllGroups";
            this.butAllGroups.Size = new System.Drawing.Size(48, 24);
            this.butAllGroups.TabIndex = 32;
            this.butAllGroups.Text = "All";
            this.butAllGroups.Click += new System.EventHandler(this.OnButAllGroupsClick);
            // 
            // chkLstGroups
            // 
            this.chkLstGroups.CheckOnClick = true;
            this.chkLstGroups.Location = new System.Drawing.Point(214, 48);
            this.chkLstGroups.Name = "chkLstGroups";
            this.chkLstGroups.Size = new System.Drawing.Size(182, 214);
            this.chkLstGroups.Sorted = true;
            this.chkLstGroups.TabIndex = 31;
            this.chkLstGroups.SelectedIndexChanged += new System.EventHandler(this.OnListSelectedIndexChanged);
            this.chkLstGroups.ItemCheck += new System.Windows.Forms.ItemCheckEventHandler(this.OnGroupItemCheck);
            // 
            // lblGroups
            // 
            this.lblGroups.Location = new System.Drawing.Point(214, 24);
            this.lblGroups.Name = "lblGroups";
            this.lblGroups.Size = new System.Drawing.Size(48, 16);
            this.lblGroups.TabIndex = 30;
            this.lblGroups.Text = "Groups:";
            // 
            // frmStep2
            // 
            this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
            this.ClientSize = new System.Drawing.Size(448, 318);
            this.Name = "frmStep2";
            this.Text = "frmStep2";
            this.pnlStep.ResumeLayout(false);
            this.ResumeLayout(false);

        }
		#endregion
	}
}
