using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using VSLangProj;
using System.IO;
using System.Resources;
using EnvDTE;
using Microsoft.Win32;
using RepPP.VSNetWizard;

namespace RepPP.VSNetWizard.Windows {
    //**********************************************************************
    //
    //    Module:             frmMain.vb.
    //
    //    Author:             Marie-Jose Lanciault
    //    Version:            1.00.00
    //    Creation:           2004-12-03
    //    Modification:       2004-12-03
    //
    //    Description:        Implementing Rep++ Wizard Main Form
    //
    //   The Tag in a TreeNode contains an array, this array is composed of:
    //        0: card group object
    //        1: form name
    //        2: form type generated 0, 1 or 2: 0 for rep++ control 1 for datagrid and 2 for rep++ toolkit controls
    //        3: child layout 0, 1 or 2: 0: child in same form, 1: in a new form, 2: each in new form
    //        4: base form name
    //        5: card group control name
    //        6: combox style, simple, Dropdown, DropdownList
    //        7: alignment: left, center, right
    //        8: use edit control or default controls: true, false
    //        9: left text for radiobutton and checkbox: true, false
    //       10: toobar button size: 0 small, 1 medium, 2 large
    //       11: selection buffer card name
    //
    //**********************************************************************
    internal class frmMain : System.Windows.Forms.Form {
        // Constants
        const string FRM_TITLE      =   "Rep++ Windows Application Wizard";
        internal enum StepOptionE {
            sdStepIntro             =   0,              // Introduction step
            sdStepInitRep           =   1,              // Introduction step
            sdStepSelect            =   2,              // Selection step
            sdStepCard              =   3,              // Configuratiom card step
            sdStepGroup             =   4,              // Configuration group step
            sdStepTypedInst         =   5,              // Typed instances generation
            sdStepFinish            =   6,              // Generation step
            sdStepAll               = - 1               // All steps
        }
        internal enum DirectionOptionE {
            sdDirNone               =   0,              // Non direction
            sdDirBack               =   1,              // Back direction
            sdDirNext               =   2               // Next direction
        }
        internal enum FormOptionE {
            sdSameForm              =   0,              // All child in same form option
            sdNewFormAll            =   1,              // All child in new form option
            sdNewFormEach           =   2               // New form for each child option
        }
        public   System.Windows.Forms.Label                 LabelFrmName;
        public   System.Windows.Forms.Label                 lblFormName;
        public   System.Windows.Forms.Panel                 Picture1;
        public   System.Windows.Forms.Label                 lblCardGroup;
        public   System.Windows.Forms.RadioButton           optGenerate3T;
        public   System.Windows.Forms.RadioButton           optGenerate2T;
        internal System.Windows.Forms.TreeView              TreeView1;
        public   System.Windows.Forms.GroupBox              fraFrmLayout;
        public   System.Windows.Forms.GroupBox              fraChildLocation;
        public   System.Windows.Forms.RadioButton           optGridCtl;
        public   System.Windows.Forms.RadioButton           optRepCtl;
        public   System.Windows.Forms.RadioButton           optNewFrmEach;
        public   System.Windows.Forms.RadioButton           optNewFrm;
        public   System.Windows.Forms.RadioButton           optSameFrm;
        public   System.Windows.Forms.TextBox               txtFormName;
        public   System.Windows.Forms.GroupBox              fraFmtFormLayout;
        public   System.Windows.Forms.GroupBox              fraGenerate;
        public   System.Windows.Forms.TextBox               txtConnection;
        public   System.Windows.Forms.Label                 lblConnection;
        public   System.Windows.Forms.TextBox               txtUser;
        public   System.Windows.Forms.Label                 lblUser;
        public   System.Windows.Forms.TextBox               txtPassword;
        public   System.Windows.Forms.Label                 lblPassword;
        public   System.Windows.Forms.TextBox               txtSystem;
        public   System.Windows.Forms.Label                 lblSystem;
        public   System.Windows.Forms.TextBox               txtProgram;
        public   System.Windows.Forms.Label                 lblProgram;
        public   System.Windows.Forms.Label                 lblLanguage;
        internal System.Windows.Forms.ComboBox              cmbLanguage;
        internal System.Windows.Forms.Button                cmdConnWizard;
        public   System.Windows.Forms.TextBox               txtFrmFormName;
        internal System.Windows.Forms.Label                 lblHeader0;
        public   System.Windows.Forms.Label                 Label1;
        public   System.Windows.Forms.Panel                 pnlStep4;
        public   System.Windows.Forms.Panel                 pnlStep3;
        public   System.Windows.Forms.Panel                 pnlStep1;
        public   System.Windows.Forms.Panel                 pnlConnection;
        public   System.Windows.Forms.Panel                 pnlStep0;
        public   System.Windows.Forms.Panel                 pnlStep2;
        public   System.Windows.Forms.Panel                 pnlStep5;
        internal System.Windows.Forms.Panel                 pnlHeader1;
        public   System.Windows.Forms.Panel                 pnlHeader2;
        internal System.Windows.Forms.Label                 Label2;
        public   System.Windows.Forms.Label                 Label3;
        internal System.Windows.Forms.Panel                 pnlHeader3;
        internal System.Windows.Forms.Label                 Label4;
        public   System.Windows.Forms.Label                 Label5;
        internal System.Windows.Forms.Panel                 Panel2;
        internal System.Windows.Forms.Label                 lblHeader4;
        public   System.Windows.Forms.Label                 lblStep4;
        internal System.Windows.Forms.Label                 lblHeader5;
        public   System.Windows.Forms.Label                 lblStep5;
        internal System.Windows.Forms.Panel                 pnlHeader5;
        internal System.Windows.Forms.Label                 lblStatus;
        public   System.Windows.Forms.RadioButton           optCardForm;
        public   System.Windows.Forms.RadioButton           optGroupForm;
        public   System.Windows.Forms.Button                cmdFldConfig4;
        public   System.Windows.Forms.Button                cmdFldConfig3;
        internal System.Windows.Forms.Label                 lblBaseForm;
        internal System.Windows.Forms.ComboBox              cmbBaseForm;
        internal System.Windows.Forms.TextBox               txtSummary;
        public   System.Windows.Forms.RadioButton           optFrmGridCtl;
        public   System.Windows.Forms.RadioButton           optFrmRepCtl;
        internal System.Windows.Forms.GroupBox              grpToolbarSize;
        internal System.Windows.Forms.RadioButton           optSmall;
        internal System.Windows.Forms.RadioButton           optLarge;
        internal System.Windows.Forms.RadioButton           optRepTkCtl;
        public   System.Windows.Forms.RadioButton           optFrmRepTkCtl;
        public   System.Windows.Forms.ComboBox              cboCards;
        internal System.Windows.Forms.GroupBox              grpUseSB;
        internal System.Windows.Forms.CheckBox              chkUseSB;
        internal System.Windows.Forms.CheckBox              chkUseDNetBar;
        public   System.Windows.Forms.Label                 lblSBCardName;
        public   System.Windows.Forms.ComboBox              cboSBCards;
        public System.Windows.Forms.Panel                   pnlStepTypedInst;
        public System.Windows.Forms.Panel                   panel4;
        internal System.Windows.Forms.Label                 label7;
        public System.Windows.Forms.Label                   label8;
        public System.Windows.Forms.PictureBox              imgStep0;
        private System.Windows.Forms.Panel                  pnlTypedInst;
        public System.Windows.Forms.Button                  cmdFinish;
        public System.Windows.Forms.Button                  cmdNext;
        public System.Windows.Forms.Button                  cmdBack;
        public System.Windows.Forms.Label                   _Line1_1;
        public System.Windows.Forms.Label                   _Line1_0;
        public System.Windows.Forms.Panel                   picNav;
        private  System.ComponentModel.Container            components = null;

        // Module level vars
        private int                                         m_nCurStep;         // The current step
        public DTE                                          m_vsApp;            // DTE object
        private bool                                        m_bFinishOK;        // True if the step is the last one
        private RepPP.Application                           m_app;              // rep++ application object
        private string                                      m_strProjectName;   // The project name
        private string                                      m_strProjectDir;    // the project directory
        private string                                      m_strLang;          // Language used for the generated item
        private string                                      m_strType;          // Application or item       
        private bool                                        m_bIsBarInstalled;  // Indicates if the .Net Bar components are installed
        private frmTypedInstParam                           m_frmTypedInst;     // Typed instances parameters form

        //**********************************************************************
        //
        // Constructor
        //   In: 
        //   Returns:
        //
        //**********************************************************************
        public frmMain() {
        }

        //**********************************************************************
        //
        // Constructor
        //   In: 
        //       dte              : DTE object
        //       strPrjName       : Project name
        //       strPrjFullName   : Project full name
        //       strLang          : Language
        //       strType          : Type 
        //   Returns:
        //
        //**********************************************************************
        public frmMain(object   dte,
                       string   strPrjName,
                       string   strPrjFullName, 
                       string   strLang, 
                       string   strType) {
            InitializeComponent();
            m_vsApp           = (DTE)dte;
            m_strProjectName  = strPrjName;
            m_strProjectDir   = strPrjFullName;
            m_strLang         = strLang;
            m_strType         = strType;
            m_nCurStep        = 0;
            m_app             = null;
            if (m_strType == "APP") {
                optGenerate2T.Enabled = true;
                optGenerate2T.Checked = true;
                optCardForm.Enabled   = false;
                optGroupForm.Enabled  = false;
            } else {
                optGenerate2T.Enabled = false;
                optCardForm.Enabled   = true;
                optGroupForm.Enabled  = true;
                optCardForm.Checked   = true;
            }
            optSmall.Checked = true;
            chkUseSB.Checked = true;
            m_frmTypedInst   = new frmTypedInstParam(this);
            pnlTypedInst.Controls.Add(m_frmTypedInst.StepPanel);
            m_frmTypedInst.StepPanel.Dock = DockStyle.Fill;
            if (strLang == "CS") {
                if (strType == "APP") {
                    m_frmTypedInst.Namespace = strPrjName;
                } else {
                    m_frmTypedInst.Namespace = Utility.GetProjectRootNamespace(m_vsApp, strPrjName);
                }
            }
            //TODO Delete this initialization whene the functionnailities become supported
            // by the window framework V2
            optNewFrm.Visible       = false;
            chkUseSB.Visible        = false;
            chkUseDNetBar.Visible   = false;
        }

        //******************************************************************
        //
        /// <summary>
        /// Dispose:                    Dispose the form
        /// </summary>
        /// <param name="bDisposing">   true if disposing, false if finalizing</param>
        //
        //******************************************************************
        protected override void Dispose(bool bDisposing) {
            if (bDisposing) {
                if(components != null) {
                    components.Dispose();
                }
                if (m_frmTypedInst != null) {
                    m_frmTypedInst.Dispose();
                    m_frmTypedInst = null;
                }
            }
            base.Dispose(bDisposing);
        }

        //******************************************************************
        //
        /// <summary>
        /// NextButton:             Next button
        /// </summary>
        //
        //******************************************************************
        public Button NextButton {
            get {
                return(cmdNext);
            }
        }

        //******************************************************************
        //
        /// <summary>
        /// NextButton:             Next button
        /// </summary>
        //
        //******************************************************************
        public RepPP.Application Application {
            get {
                return(m_app);
            }
        }

        //******************************************************************
        //
        /// <summary>
        /// CurrentProject:       Get the current project if it's already created
        ///                       (case of Add Item), otherwise it returns null
        /// </summary>
        //
        //******************************************************************
        public EnvDTE.Project CurrentProject {
            get {
                EnvDTE.Project prjRetVal = null;

                if (m_strProjectName != String.Empty) {
                    prjRetVal = Utility.GetProject(m_vsApp, m_strProjectName);
                }
                return(prjRetVal);
            }
        }

        //**********************************************************************
        //
        /// <summary>
        /// InitConnParamStep           Initialize the connection parameters from 
        ///                             the RepPPInfo.resx file
        /// </summary>
        //
        //**********************************************************************
        private void InitConnParamStep() {
            EnvDTE.Project      prjCurrent;
            EnvDTE.ProjectItem  prjItem;
            string              strFileName;
            ResXResourceSet     resxSet;
            string              strLang;

            prjCurrent = CurrentProject;
            if (prjCurrent != null) {
                prjItem = Utility.FindProjectItem(prjCurrent, "RepPPInfo.resx");
                if (prjItem != null) {
                    strFileName                 = prjItem.get_FileNames(0);
                    resxSet                     = new ResXResourceSet(strFileName);
                    txtProgram.Text             = resxSet.GetString("PrgName",  true);
                    txtSystem.Text              = resxSet.GetString("SysName",  true);
                    txtConnection.Text          = resxSet.GetString("ConnName", true);
                    txtUser.Text                = resxSet.GetString("UserName", true);
                    txtPassword.Text            = resxSet.GetString("Pwd",      true);
                    strLang                     = resxSet.GetString("Language", true);
                    if (strLang != String.Empty) {
                        cmbLanguage.SelectedIndex = int.Parse(strLang);
                    }
                }
            }
        }

        //**********************************************************************
        //
        // frmWizard_Load
        //   In: 
        //       eventSender:     The event sender
        //       eventArgs  :     The event arguments
        //   Returns:
        //
        //**********************************************************************
        private void frmWizard_Load(System.Object eventSender, System.EventArgs eventArgs) {
            m_bFinishOK = false;
            ShowFrameStep(false, (int)StepOptionE.sdStepAll);
            FillLanguageCombo();
            FillBaseFormCombo();
            SetStep((int)StepOptionE.sdStepIntro, (int)DirectionOptionE.sdDirNone);
            m_bIsBarInstalled      = IsDNetBarInstalled();
            chkUseDNetBar.Enabled  = m_bIsBarInstalled;
            InitConnParamStep();
        }

        //**********************************************************************
        //
        // Show or hide a step frame
        //   In: 
        //       bVisible :    True to show the frame, False to hide it
        //       nStep    :    Frame step number
        //   Returns:
        //
        //**********************************************************************
        private void ShowFrameStep(bool bVisible, int nStep) {
            pnlStep0.Visible            = false;
            pnlStep1.Visible            = false;
            pnlStep2.Visible            = false;
            pnlStep3.Visible            = false;
            pnlStep4.Visible            = false;
            pnlStepTypedInst.Visible    = false;
            pnlStep5.Visible            = false;

            switch ((StepOptionE)(nStep)) {
            case StepOptionE.sdStepIntro:
                pnlStep0.Visible = bVisible;
                break;
            case StepOptionE.sdStepInitRep:
                pnlStep1.Visible = bVisible;
                break;
            case StepOptionE.sdStepSelect:
                pnlStep2.Visible = bVisible;
                break;
            case StepOptionE.sdStepCard:
                pnlStep3.Visible = bVisible;
                break;
            case StepOptionE.sdStepGroup:
                pnlStep4.Visible = bVisible;
                break;
            case StepOptionE.sdStepTypedInst:
                pnlStepTypedInst.Visible = bVisible;
                break;
            case StepOptionE.sdStepFinish:
                pnlStep5.Visible = bVisible;
                break;
            default:
                break;
            }
            System.Windows.Forms.Application.DoEvents();
        }

        //**********************************************************************
        //
        // Fill the combo box with the card or group lists
        //   In: 
        //       bGetCard:     True to load card names
        //                     false to load group names
        //   Returns:
        //
        //**********************************************************************
        private void FillCardOrGroupComboBox(bool bGetCard) {
            if (m_app != null) {
                if (m_app.IsProgramStarted()) {
                    cboCards.Items.Clear();
                    cboSBCards.Items.Clear();
                    if (bGetCard) {
                        // Cards
                        lblCardGroup.Text = "Card Name";
                        foreach (RepPP.Card oCard in m_app.Cards) {
                            cboCards.Items.Add(oCard.Name);
                            cboSBCards.Items.Add(oCard.Name);
                        }
                    } else {
                        // Groups
                        lblCardGroup.Text = "Group Name";
                        foreach (RepPP.Group oGrp in m_app.Groups) {
                            cboCards.Items.Add(oGrp.Name);
                        }
                    }
                }
            }
        }

        //**********************************************************************
        //
        // Set the step as the current
        //   In: 
        //       nStep     :     The step number
        //       nDirection:     The direction
        //   Returns:
        //
        //**********************************************************************
        private void SetStep(int nStep, int nDirection) {
            switch ((StepOptionE)(nStep)) {
            case StepOptionE.sdStepIntro:
                break;
            case StepOptionE.sdStepSelect:
                if ((nDirection == (int)DirectionOptionE.sdDirNext)) {
                    FillCardOrGroupComboBox(!optGroupForm.Checked);
                }
                break;
            case StepOptionE.sdStepCard:
                if (nDirection == (int)DirectionOptionE.sdDirNext) {
                    PopulateTree(cboCards.Text);
                }
                m_bFinishOK = false;
                break;
            case StepOptionE.sdStepGroup:
                txtFrmFormName.Text = "frm" + cboCards.Text;
                if (nDirection == (int)DirectionOptionE.sdDirNext) {
                    PopulateTree(cboCards.Text);
                }
                m_bFinishOK = false;
                break;
            case StepOptionE.sdStepTypedInst:
                m_bFinishOK = false;
                break;
            case StepOptionE.sdStepFinish:
                //If cboCards.Text <> "" Then
                m_bFinishOK = true;
                break;
                //End If
            default:
                break;
            }
            ShowFrameStep(true, nStep);
            SetCaption(ref nStep);
            SetNavBtns(nStep);
        }

        //**********************************************************************
        //
        // Set the navigator buttons for the step
        //   In: 
        //       nStep     :     The step number
        //   Returns:
        //**********************************************************************
        private void SetNavBtns(int nStep) {
            m_nCurStep = nStep;

            switch ((StepOptionE)(nStep)) {
            case StepOptionE.sdStepIntro:
                cmdBack.Enabled = false;
                cmdNext.Enabled = true;
                break;
            case StepOptionE.sdStepInitRep:
                cmdBack.Enabled = true;
                cmdNext.Enabled = ValidateRepPPInit();
                break;
            case StepOptionE.sdStepCard:
                cmdBack.Enabled = true;
                cmdNext.Enabled = txtFormName.Text.Trim() != "" && cmbBaseForm.Text.Trim() != "";
                break;
            case StepOptionE.sdStepGroup:
                cmdBack.Enabled = true;
                cmdNext.Enabled = txtFrmFormName.Text.Trim() != "";
                break;
            case StepOptionE.sdStepTypedInst:
                cmdBack.Enabled = true;
                cmdNext.Enabled = m_frmTypedInst.ValidateB();
                break;
            case StepOptionE.sdStepFinish:
                cmdNext.Enabled = false;
                cmdBack.Enabled = true;
                break;
            case StepOptionE.sdStepSelect:
                cmdNext.Enabled = ((cboCards.Text.Trim().Length) > 0 ) && (optGroupForm.Checked || ( !chkUseSB.Checked || cboSBCards.Text != "" ) );
                cmdBack.Enabled = true;
                break;
            default:
                cmdBack.Enabled = true;
                cmdNext.Enabled = true;
                break;
            }

            if (m_bFinishOK == true) {
                if (m_strType == "APP") {
                    SetSummary(m_strProjectName, true, TreeView1.Nodes[0]);
                } else {
                    SetSummary(m_strProjectName, false, TreeView1.Nodes[0]);
                }
                cmdFinish.Text = "&Finish";
            } else {
                cmdFinish.Text = "&Cancel";
            }
        }

        //**********************************************************************
        //
        // Button Back clicked
        //   In: 
        //       eventSender:     The event sender
        //       eventArgs  :     The event arguments
        //   Returns:
        //
        //**********************************************************************
        private void cmdBack_Click(System.Object    eventSender, 
                                   System.EventArgs eventArgs) {
            int nAltStep;
        
            nAltStep = m_nCurStep;
            switch ((StepOptionE)(m_nCurStep)) {
            case StepOptionE.sdStepIntro:
                break;
            case StepOptionE.sdStepInitRep:
                nAltStep = (int)StepOptionE.sdStepIntro;
                break;
            case StepOptionE.sdStepSelect:
                nAltStep = (int)StepOptionE.sdStepInitRep;
                break;
            case StepOptionE.sdStepCard:
            case StepOptionE.sdStepGroup:
                nAltStep = (int)StepOptionE.sdStepSelect;
                break;
            case StepOptionE.sdStepTypedInst:
                if (optGroupForm.Checked) {
                    nAltStep = (int)StepOptionE.sdStepGroup;
                } else {
                    nAltStep = (int)StepOptionE.sdStepCard;
                }
                break;
            case StepOptionE.sdStepFinish:
                nAltStep = (int)StepOptionE.sdStepTypedInst;
                break;
            default:
                break;
            }
            SetStep(nAltStep, (int)DirectionOptionE.sdDirBack);
        }

        //**********************************************************************
        //
        // Button Next clicked
        //   In: 
        //       eventSender:     The event sender
        //       eventArgs  :     The event arguments
        //   Returns:
        //
        //**********************************************************************
        private void cmdNext_Click(System.Object    eventSender, 
                                   System.EventArgs eventArgs) {
            int         nAltStep;
            bool        bRetVal;
            ArrayList   arrCardNames;
            ArrayList   arrGroupNames;
            string[]    arrNames;
            bool        bError = false;


            nAltStep = m_nCurStep;
            switch ((StepOptionE)(m_nCurStep)) {
            case StepOptionE.sdStepIntro:
                nAltStep = (int)StepOptionE.sdStepInitRep;
                break;
            case StepOptionE.sdStepInitRep:
                m_app = RepPP.Application.GetApplication();
                if (m_app != null) {
                    //if (!m_app.IsThisInstance(txtSystem.Text,
                    //                          txtProgram.Text,
                    //                          txtConnection.Text,
                    //                          txtUser.Text,
                    //                          txtPassword.Text,
                    //                          (RepPP.LanguageCode)cmbLanguage.SelectedIndex,
                    //                          4096)) {
                    RepPP.Application.Reset(null);
                    //}
                } else {
                    m_app = RepPP.Application.Create();
                }
                if (!m_app.IsProgramStarted()) {
                    if (m_app.Init(txtSystem.Text,
                                   txtProgram.Text,
                                   txtConnection.Text,
                                   txtUser.Text,
                                   txtPassword.Text,
                                   (RepPP.LanguageCode)cmbLanguage.SelectedIndex,
                                   4096) != 0) {    // 4096-> Rep++ in design mode
                        MessageBox.Show("Unable to initialize the Rep++ Application.", 
                                        "Rep++ Windows Wizard",
                                        MessageBoxButtons.OK, 
                                        MessageBoxIcon.Error);
                        txtConnection.Focus();
                        cmdNext.Enabled = false;
                        RepPP.Application.Reset(null);
                        m_app   = null;
                        bRetVal = false;
                    } else {
                        bRetVal = true;
                    }
                } else {
                    bRetVal = true;
                }
                if (bRetVal) {
                    nAltStep = (int)StepOptionE.sdStepSelect;
                }
                break;
            case StepOptionE.sdStepSelect:
                if(optGroupForm.Checked) {
                    nAltStep = (int)StepOptionE.sdStepGroup;
                }
                else {
                    nAltStep = (int)StepOptionE.sdStepCard;
                }
                break;
            case StepOptionE.sdStepCard:
            case StepOptionE.sdStepGroup:
                nAltStep = (int)StepOptionE.sdStepTypedInst;
                break;
            case StepOptionE.sdStepTypedInst:
                if (m_frmTypedInst.GenTypedInstance != Utility.GenTypedInstTypeE.None) {
                    arrCardNames = new ArrayList(2);
                    arrCardNames.Add(cboCards.Text);
                    arrCardNames.Add(cboSBCards.Text);
                    arrGroupNames = new ArrayList();
                    arrNames = Utility.GetGroupNameList(m_app.Cards[cboCards.Text]);
                    arrGroupNames.AddRange(arrNames);
                    arrNames = Utility.GetGroupNameList(m_app.Cards[cboSBCards.Text]);
                    foreach (string strName in arrNames) {
                        if (!arrGroupNames.Contains(strName)) {
                            arrGroupNames.Add(strName);
                        }
                    }
                    if (!Utility.CheckForTypedInstNameClash(m_app,
                                                            arrCardNames,
                                                            arrGroupNames,
                                                            m_frmTypedInst.CardInstanceBaseClass,
                                                            m_frmTypedInst.GroupInstanceBaseClass,
                                                            m_frmTypedInst.CardInstanceClassPrefix,
                                                            m_frmTypedInst.GroupInstanceClassPrefix,
                                                            m_frmTypedInst.GroupInstancePropertyPrefix,
                                                            m_frmTypedInst.FieldPropertyPrefix,
                                                            m_frmTypedInst.GenTypedInstance == Utility.GenTypedInstTypeE.TypedInstAndWSAdapter)) {
                        bError = true;
                    }
                }
                if (!bError) {
                    if (m_strType == "APP"                                                         ||
                        Utility.GetProjectRootNamespace(m_vsApp, m_strProjectName) != String.Empty ||
                        m_frmTypedInst.Namespace != String.Empty) {
                        nAltStep = (int)StepOptionE.sdStepFinish;
                    } else {
                        MessageBox.Show("The project does not have a root or a default namespace and no namespace is specified for the typed instances. \r\nPlease specify a namespace for the typed instances.",
                                        "Rep++ Windows Wizard",
                                        System.Windows.Forms.MessageBoxButtons.OK,
                                        System.Windows.Forms.MessageBoxIcon.Error);
                    }
                }
                break;
            default:
                break;
            }
            if (nAltStep != m_nCurStep) {
                SetStep (nAltStep, (int)DirectionOptionE.sdDirNext);
            }
        }

        //**********************************************************************
        //
        // Validate inputs used to initialize rep++
        //   In: 
        //   Returns:
        //       true :  valid
        //       false:  not valid
        //
        //**********************************************************************
        private bool ValidateRepPPInit() {
            bool bValidateRepPPInit = true;

            if (txtConnection.Text.Trim() == "" || txtUser.Text.Trim() == "" || txtSystem.Text.Trim() == "" || txtProgram.Text.Trim() == "") {
                bValidateRepPPInit = false;
            }
            else {
                bValidateRepPPInit = true;
            }
            return bValidateRepPPInit;
        }

        //**********************************************************************
        //
        // Connection Edit Text changed
        //   In: 
        //       eventSender:     The event sender
        //       eventArgs  :     The event arguments
        //   Returns:
        //
        //**********************************************************************
        private void txtConnection_TextChanged(System.Object eventSender, 
            System.EventArgs eventArgs) {
            SetNavBtns(m_nCurStep);
        }

        //**********************************************************************
        //
        // User Edit Text changed
        //   In: 
        //       eventSender:     The event sender
        //       eventArgs  :     The event arguments
        //   Returns:
        //
        //**********************************************************
        private void txtUser_TextChanged(System.Object    eventSender, 
            System.EventArgs eventArgs) {
            SetNavBtns(m_nCurStep);
        }

        //**********************************************************************
        //
        // System Edit Text changed
        //   In: 
        //       eventSender:     The event sender
        //       eventArgs  :     The event arguments
        //   Returns:
        //
        //**********************************************************************
        private void txtSystem_TextChanged(System.Object    eventSender, 
                                           System.EventArgs eventArgs) {
            SetNavBtns(m_nCurStep);
        }

        //**********************************************************************
        //
        // Program Edit Text changed
        //   In: 
        //       eventSender:     The event sender
        //       eventArgs  :     The event arguments
        //   Returns:
        //
        //**********************************************************************
        private void txtProgram_TextChanged(System.Object    eventSender, 
                                            System.EventArgs eventArgs) {
            SetNavBtns(m_nCurStep);
        }

        //**********************************************************************
        //
        // Card Form name changed
        //   In: 
        //       eventSender:     The event sender
        //       eventArgs  :     The event arguments
        //   Returns:
        //
        //**********************************************************************
        private void txtFormName_TextChanged(System.Object    eventSender, 
                                             System.EventArgs eventArgs) {
            SetNavBtns(m_nCurStep);
        }

        //**********************************************************************
        //
        // Combo base form name changed
        //   In: 
        //       eventSender:     The event sender
        //       eventArgs  :     The event arguments
        //   Returns:
        //
        //**********************************************************************
        private void cmbBaseForm_TextChanged(System.Object    eventSender, 
                                             System.EventArgs eventArgs) {
            SetNavBtns(m_nCurStep);
        }

        //**********************************************************************
        //
        // Group form name changed
        //   In: 
        //       eventSender:     The event sender
        //       eventArgs  :     The event arguments
        //   Returns:
        //
        //**********************************************************************
        private void txtfrmFormName_TextChanged(System.Object    eventSender, 
                                                System.EventArgs eventArgs) {
            SetNavBtns(m_nCurStep);
        }

        //**********************************************************************
        //
        // Handle the ckecked changeed event of the use SB checkbox
        //   In: 
        //       eventSender:     The event sender
        //       eventArgs  :     The event arguments
        //   Returns:
        //
        //**********************************************************************
        private void chkUseSB_CheckedChanged(System.Object eventSender, System.EventArgs eventArgs) {
            cboSBCards.Enabled    = chkUseSB.Checked;
            chkUseDNetBar.Enabled = m_bIsBarInstalled && chkUseSB.Checked;
            SetNavBtns(m_nCurStep);
        }

        //**********************************************************************
        //
        // When form name edit text control leaved
        //   In: 
        //       eventSender:     The event sender
        //       eventArgs  :     The event arguments
        //   Returns:
        //
        //**********************************************************************
        private void txtfrmFormName_Leave(System.Object     eventSender, 
                                          System.EventArgs  eventArgs) {
            if(TreeView1.Nodes.Count > 0) {
                ((Object[])TreeView1.Nodes[0].Tag)[1] = txtFrmFormName.Text;
            }
        }

        //*********************************************************     
        //
        /// <summary>
        /// Generate:                       Generate the requested forms
        /// </summary>
        //  
        //*********************************************************     
        public void Generate() {
            bool                        bSuccess;
            WinGeneratorBase            oGen;
            bool                        bUseBar;
            Utility.GenTypedInstParam   genTypedInstParam;

            bUseBar             = (chkUseDNetBar.Checked && chkUseDNetBar.Enabled);
            genTypedInstParam   = new Utility.GenTypedInstParam(m_frmTypedInst.GenTypedInstance,
                                                                m_frmTypedInst.Namespace,
                                                                "",
                                                                m_frmTypedInst.CardInstanceBaseClass,
                                                                m_frmTypedInst.GroupInstanceBaseClass,
                                                                m_frmTypedInst.CardInstanceClassPrefix,
                                                                m_frmTypedInst.GroupInstanceClassPrefix,
                                                                m_frmTypedInst.GroupInstancePropertyPrefix,
                                                                m_frmTypedInst.FieldPropertyPrefix);
            if (m_strLang == "VB") {
                oGen = new WinGeneratorForVB((EnvDTE.DTE)m_vsApp, m_app, null, bUseBar, genTypedInstParam);
            } else {
                oGen = new WinGeneratorForCS((EnvDTE.DTE)m_vsApp, m_app, null, bUseBar, genTypedInstParam);
            }
            if (oGen != null) {
                if (m_strType == "APP") {
                    bSuccess = oGen.CreateApplication(m_strProjectDir, m_strProjectName, TreeView1.Nodes[0]);
                } else if (optCardForm.Checked) {
                    bSuccess = oGen.AddCardForm(m_strProjectName, TreeView1.Nodes[0]);
                } else {
                    bSuccess = oGen.AddGroupForm(m_strProjectName, TreeView1.Nodes[0]);
                }
                if (bSuccess && m_frmTypedInst.GenTypedInstance != Utility.GenTypedInstTypeE.None) {
                    Utility.GenTypedInstanceConfigFile(Utility.GetProject(m_vsApp, m_strProjectName),
                                                       m_app.SystemName,
                                                       m_app.ProgramName,
                                                       m_app.ConnectionName,
                                                       m_app.UserName,
                                                       m_app.LanguageCode,
                                                       genTypedInstParam.m_strCardInstClassPrefix,
                                                       genTypedInstParam.m_strGroupInstClassPrefix,
                                                       genTypedInstParam.m_strGroupInstPropPrefix,
                                                       genTypedInstParam.m_strFieldPropPrefix,
                                                       genTypedInstParam.m_strNamespace,
                                                       genTypedInstParam.m_strRootNamespace,
                                                       m_frmTypedInst.CardInstanceBaseClass,
                                                       m_frmTypedInst.GroupInstanceBaseClass,
                                                       m_frmTypedInst.GenTypedInstance == Utility.GenTypedInstTypeE.TypedInstAndWSAdapter);
                    m_frmTypedInst.SaveTypedInstParam();
                }
            }
        }

        //**********************************************************************
        //
        // Button Finish clicked
        //   In: 
        //       eventSender :   The event sender
        //       eventArgs   :   The event arguments
        //   Returns:
        //
        //**********************************************************************
        private void cmdFinish_Click(System.Object eventSender, System.EventArgs eventArgs) {
            try {
                if (cmdFinish.Text == "&Finish") {
#if !VC8
                    cmdFinish.Enabled   = false;
                    cmdBack.Enabled     = false;
                    cmdNext.Enabled     = false;
                    Generate();
#endif
                    this.DialogResult = System.Windows.Forms.DialogResult.OK;
                } else {
                    this.DialogResult = System.Windows.Forms.DialogResult.Cancel;
                }
            } finally {
                Close();
            }
        }

        //**********************************************************************
        //
        // Set the wizard generation summary
        //   In: 
        //       strProjName:   The project name
        //       bNewProj:      Indicates if the project is a new one
        //       oNode:         The root treeView node
        //   Returns:
        //
        //**********************************************************************
        private void SetSummary(string   strProjName, 
                                bool     bNewProj, 
                                TreeNode oNode) {
            string strTxt;

            txtSummary.Text = "";
            if(bNewProj) {
                strTxt = "-Add the project " + strProjName + "." + "\r\n";
            }
            else {
                strTxt = "Add to " + strProjName + " project:" + "\r\n";
            }
            strTxt = strTxt + FormSummary(oNode);
            txtSummary.Text = strTxt;
        }

        //**********************************************************************
        //
        // Set the wizard generation summary for a form and its child
        //   In: 
        //       oNode:     TreeView node
        //   Returns:
        //
        //**********************************************************************
        private string FormSummary(TreeNode oNode) {
            string      strTxt = "";
            bool        bDisplay;

            if (oNode != null) {
                bDisplay = false;
                if (oNode.Parent == null) {
                    bDisplay = true;
                } else if ((int)((object[])oNode.Parent.Tag)[3] == 2 || ((int)((object[]) oNode.Parent.Tag)[3] == 1 && oNode.Index == 0)) {
                    bDisplay = true;
                }
                if (bDisplay) {
                    strTxt = "    -Add the form " + ((Object[])oNode.Tag)[1] + " with the following options:" + "\r\n";
                    strTxt = strTxt + "        -Base form: " + ((Object[])oNode.Tag)[4] + "." + "\r\n";
                    if ((int)((object[])oNode.Tag)[2] == 0) {
                        strTxt = strTxt + "        -Use Rep++ controls." + "\r\n";
                    } else if ((int)((object[])oNode.Tag)[2] == 1) {
                        strTxt = strTxt + "        -Use DataGrid control." + "\r\n";
                    } else {
                        strTxt = strTxt + "        -Use Rep++ toolkit controls." + "\r\n";
                    }
                    if( oNode.Nodes.Count > 0) {
                        switch ((int)((object[])oNode.Tag)[3]) {
                        case 0:
                            strTxt = strTxt + "        -Children in a same form." + "\r\n";
                            break;
                        case 1:
                            strTxt = strTxt + "        -Children in a new form." + "\r\n";
                            break;
                        case 2:
                            strTxt = strTxt + "        -Each child in a new form." + "\r\n";
                            break;
                        default:
                            break;
                        }
                    }
                }
                foreach (TreeNode oChild in oNode.Nodes) {
                    strTxt = strTxt + FormSummary(oChild);
                }
            }
            return strTxt;
        }

        //**********************************************************************
        //
        // Set Form caption
        //   In: 
        //       nStep:     The step
        //   Returns:
        //
        //**********************************************************************
        private void SetCaption(ref int nStep) {
            Text = FRM_TITLE + " - Step " + ((nStep >= 4) ? nStep - 1 : nStep);
        }

        //**********************************************************************
        //
        // The Cards combo index changed
        //   In: 
        //       eventSender:     The event sender
        //       eventArgs  :     The event arguments
        //   Returns:
        //
        //**********************************************************************
        private void cboCards_SelectedIndexChanged(System.Object    eventSender, 
                                                   System.EventArgs eventArgs) {
            SetNavBtns(m_nCurStep);
        }

        //**********************************************************************
        //
        // The base form combo index changed
        //   In: 
        //       eventSender:     The event sender
        //       eventArgs  :     The event arguments
        //   Returns:
        //
        //**********************************************************************
        private void cmbBaseForm_SelectedIndexChanged(System.Object    eventSender, 
                                                      System.EventArgs eventArgs) {
            if (TreeView1.SelectedNode != null) {
                ((object[])TreeView1.SelectedNode.Tag)[4] = cmbBaseForm.Text.Trim();
            }
        }

        //**********************************************************************
        //
        // When base form combobox leaved
        //   In: 
        //       eventSender:     The event sender
        //       eventArgs  :     The event arguments
        //   Returns:
        //
        //**********************************************************************
        private void cmbBaseForm_Leave(System.Object    eventSender, 
                                       System.EventArgs eventArgs) {
            if (TreeView1.SelectedNode != null) {
                ((object[])TreeView1.SelectedNode.Tag)[4] = cmbBaseForm.Text.Trim();
            }
        }

        //**********************************************************************
        //
        // The selection buffer cards combo index changed
        //   In: 
        //       eventSender:     The event sender
        //       eventArgs  :     The event arguments
        //   Returns:
        //
        //**********************************************************************
        private void cboSBCards_SelectedIndexChanged(System.Object    eventSender, 
                                                     System.EventArgs eventArgs) {
            SetNavBtns(m_nCurStep);
        }

        //**********************************************************************
        //
        // When generate 2tiers Radiobutton checked changed
        //   In: 
        //       eventSender:     The event sender
        //       eventArgs  :     The event arguments
        //   Returns:
        //
        //**********************************************************************
        private void optGenerate2T_CheckedChanged(System.Object    eventSender, 
                                                  System.EventArgs eventArgs) {
            if(((RadioButton)eventSender).Checked) {
                SetNavBtns(m_nCurStep);
                FillCardOrGroupComboBox(true);
            }
        }

        //**********************************************************************
        //
        // When generate 3tiers RadioButton checked changed
        //   In: 
        //       eventSender:     The event sender
        //       eventArgs  :     The event arguments
        //   Returns:
        //
        //**********************************************************************
        private void optGenerate3T_CheckedChanged(System.Object     eventSender, 
                                                  System.EventArgs  eventArgs) {
            if (((RadioButton)eventSender).Checked) {
                SetNavBtns(m_nCurStep);
                FillCardOrGroupComboBox(true);
            }
        }

        //**********************************************************************
        //
        // When generate form RadioButton checked changed
        //   In: 
        //       eventSender:     The event sender
        //       eventArgs  :     The event arguments
        //   Returns:
        //
        //**********************************************************************
        private void optCardForm_CheckedChanged(System.Object    eventSender, 
                                                System.EventArgs eventArgs) {
            if (((RadioButton)eventSender).Checked) {
                cboCards.Items.Clear();
                cboSBCards.Items.Clear();
                grpUseSB.Visible = true;
                SetNavBtns(m_nCurStep);
                FillCardOrGroupComboBox(true);
            }
        }

        //**********************************************************************
        //
        // When generate form RadioButton checked changed
        //   In: 
        //       eventSender:     The event sender
        //       eventArgs  :     The event arguments
        //   Returns:
        //
        //**********************************************************************
        private void optGroupForm_CheckedChanged(System.Object    eventSender, 
                                                 System.EventArgs eventArgs) {
            if (((RadioButton)eventSender).Checked) {
                cboCards.Items.Clear();
                cboSBCards.Items.Clear();
                grpUseSB.Visible = false;
                SetNavBtns(m_nCurStep);
                FillCardOrGroupComboBox(false);
            }
        }

        //**********************************************************************
        //
        // Initialize the TreeView  
        //   In: 
        //       sCardName:     The card name
        //   Returns:
        //
        //**********************************************************************
        private void PopulateTree(string sCardName) {
            RepPP.Card  oCard;
            RepPP.Group oGroup;
            TreeNode    oNode;

            try {
                if (m_app != null) {
                    if (!optGroupForm.Checked) {
                        TreeView1.Nodes.Clear();
                        oCard = m_app.Cards.Find(sCardName);
                        if (oCard != null) {
                            foreach (RepPP.CardGroup oCardGroup in oCard.ChildCardGroups) {
                                FillTreeView(oCardGroup, null);
                            }
                        }
                    } else {
                        TreeView1.Nodes.Clear();
                        oGroup = m_app.Groups.Find(cboCards.Text);
                        if (oGroup != null) {
                            oNode = new System.Windows.Forms.TreeNode(oGroup.Name);
                            if(oNode != null) {
                                //        0: card group object
                                //        1: form name
                                //        2: form type generated 0, 1 or 2: 0 for rep++ control 1 for datagrid and 2 for rep++ toolkit controls
                                //        3: child layout 0, 1 or 2: 0: child in same form, 1: in a new form, 2: each in new form
                                //        4: base form name
                                //        5: card group control name
                                //        6: combox style, simple, Dropdown, DropdownList
                                //        7: alignment: left, center, right
                                //        8: use edit control or default controls: true, false
                                //        9: left text for radiobutton and checkbox: true, false
                                //       10: toobar button size: 0 small, 1 medium, 2 large
                                //       11: selection buffer card name
                                oNode.Tag = new object[] {oGroup, "frm" + oGroup.Name, 0, 0, "RepPP.Framework.Window.frmPopupChildEditorUI", "", ComboBoxStyle.DropDownList, HorizontalAlignment.Left, false, false, ((optSmall.Checked) ? 0 : 2), cboSBCards.Text};
                                TreeView1.Nodes.Add(oNode);
                            }
                        }
                    }
                    TreeView1.ExpandAll();
                }
            }
            catch(System.Exception ex) {
                MessageBox.Show(ex.ToString(), "Rep++ Wizard");
            }
        }

        //**********************************************************************
        //
        // Fill the card groups TreeView
        //   In: 
        //       oCardGrp   :     The card group
        //       oParentNode:     The parent node
        //   Returns:
        //
        //**********************************************************************
        private void FillTreeView(RepPP.CardGroup               oCardGrp, 
            System.Windows.Forms.TreeNode oParentNode) {

            System.Windows.Forms.TreeNode oNode;
            string                        strBaseFormName;

            oNode = new System.Windows.Forms.TreeNode(oCardGrp.Name);
            if(oNode != null) {
                if(oParentNode == null) {
                    strBaseFormName = ((chkUseSB.Checked) ? "RepPP.Framework.Window.frmSBChildEditor" : "RepPP.Framework.Window.frmTopBaseEditor");
                } else {
                    strBaseFormName = "RepPP.Framework.Window.frmPopupChildEditorUI";
                }
                //        0: card group object
                //        1: form name
                //        2: form type generated 0, 1 or 2: 0 for rep++ control 1 for datagrid and 2 for rep++ toolkit controls
                //        3: child layout 0, 1 or 2: 0: child in same form, 1: in a new form, 2: each in new form
                //        4: base form name
                //        5: card group control name
                //        6: combox style, simple, Dropdown, DropdownList
                //        7: alignment: left, center, right
                //        8: use edit control or default controls: true, false
                //        9: left text for radiobutton and checkbox: true, false
                //       10: toobar button size: 0 small, 1 medium, 2 large
                //       11: selection buffer card name
                oNode.Tag = new object[] {oCardGrp, 
                                             "frm" + oCardGrp.Name, 
                                             0, 
                                             0, 
                                             strBaseFormName, 
                                             "", 
                                             ComboBoxStyle.DropDownList, 
                                             HorizontalAlignment.Left, 
                                             false, 
                                             false, 
                                             ((optSmall.Checked) ? 0 : 2), 
                                             ((chkUseSB.Checked) ? cboSBCards.Text : "")};
                if (oParentNode == null) {
                    TreeView1.Nodes.Add(oNode);
                } else {
                    oParentNode.Nodes.Add(oNode);
                }
                foreach (RepPP.CardGroup oChild in oCardGrp.ChildCardGroups) {
                    FillTreeView(oChild, oNode);
                }
                if(oParentNode == null) {
                    TreeView1.SelectedNode = oNode;
                }
            }
        }

        //**********************************************************************
        //
        // Fill the combo box with the card or group lists
        //   In: 
        //       bGetCard:     True to load card names
        //                     false to load group names
        //   Returns:
        //
        //**********************************************************************
        private void FillTreeView(RepPP.CardGroup oCardGrp) {
            FillTreeView(oCardGrp, null);
        }

        //**********************************************************************
        //
        // When a node is selected
        //   In: 
        //       eventSender:      The event sender
        //       eventArgs  :      The event arguments struct
        //   Returns:
        //
        //**********************************************************************
        private void TreeView1_AfterSelect(System.Object                          eventSender, 
                                           System.Windows.Forms.TreeViewEventArgs eventArgs) {
            System.Windows.Forms.TreeNode oNode;
            RepPP.CardGroup               CardGrp;
            bool                          bHaveChild;

            oNode   = eventArgs.Node;
            CardGrp = (RepPP.CardGroup)((object[])oNode.Tag)[0];
            txtFormName.Text = ((object[])oNode.Tag)[1].ToString();
            cmbBaseForm.Text = ((object[])oNode.Tag)[4].ToString();
            SetFormLayout((int)((object[])oNode.Tag)[2]);
            SetChildLocation((int)((object[])oNode.Tag)[3]);

            // Enable/disable form type
            if (CardGrp.GroupType == RepPP.GroupType.sdHorizontal) {
                optGridCtl.Enabled = true;
            } else {
                optGridCtl.Enabled = false;
            }
            // Enable/disable child layout
            bHaveChild               = (CardGrp.ChildCardGroups.Count != 0);
            fraChildLocation.Enabled = bHaveChild;
            optSameFrm.Enabled       = bHaveChild;
            optNewFrm.Enabled        = bHaveChild;
            optNewFrmEach.Enabled    = bHaveChild;
            // Enable/disable form name
            cmbBaseForm.Enabled = false;
            if (oNode.Parent == null) {
                txtFormName.Enabled = true;
            } else {
                if ((int)((object[])oNode.Parent.Tag)[3] == 0 || ((int)((object[])oNode.Parent.Tag)[3] == 1 && CardGrp.ChildId != 0 )) {
                    txtFormName.Enabled = false;
                } else {
                    txtFormName.Enabled = true;
                }
            }
        }

        //**********************************************************************
        //
        // Fill Language ComboBox
        //   In: 
        //       Void
        //   Returns:
        //
        //**********************************************************************
        private void FillLanguageCombo() {
            cmbLanguage.Items.AddRange(new object[] {"Default", "French", "English", "Spanish", "German", "Italian"});
            cmbLanguage.SelectedIndex = 0;
        }

        //**********************************************************************
        //
        // Fill Base form ComboBox
        //   In: 
        //       Void
        //   Returns:
        //
        //**********************************************************************
        private void FillBaseFormCombo() {
            cmbBaseForm.Items.AddRange(new object[] {"System.Windows.Forms.Form", "RepPP.Framework.Window.SCMenuForm"});
            cmbBaseForm.SelectedIndex = 0;
        }

        //**********************************************************************
        //
        // Set Children location OptionButton control
        //   In: 
        //       nIndex:      The option index
        //   Returns:
        //
        //**********************************************************************
        private void SetChildLocation(int nIndex) {
            switch((FormOptionE)nIndex) {
            case FormOptionE.sdSameForm:
                optSameFrm.Checked = true;
                break;
            case FormOptionE.sdNewFormAll:
                optNewFrm.Checked = true;
                break;
            case FormOptionE.sdNewFormEach:
                optNewFrmEach.Checked = true;
                break;
            default:
                break;
            }
        }

        //**********************************************************************
        //
        // Set Form layout OptionButton control
        //   In: 
        //       nIndex:      The option index
        //   Returns:
        //
        //**********************************************************************
        private void SetFormLayout(int nIndex) {
            if (nIndex == 1) {
                optGridCtl.Checked = true;
            } else if (nIndex== 0) {
                optRepCtl.Checked = true;
            } else {
                optRepTkCtl.Checked = true;
            }
        }

        //**********************************************************************
        //
        // When RepPP control OptionButton checked changed
        //   In: 
        //       eventSender:     The event sender
        //       eventArgs  :     The event arguments
        //   Returns:
        //
        //**********************************************************************
        private void optRepCtl_CheckedChanged(System.Object    eventSender, 
                                              System.EventArgs eventArgs) {
            if (((RadioButton)eventSender).Checked) {
                cmdFldConfig3.Enabled = true;
                if (TreeView1.SelectedNode != null) {
                    ((object[])TreeView1.SelectedNode.Tag)[2] = 0;
                }
            }
        }

        //**********************************************************************
        //
        // When RepPP toolkit control OptionButton checked changed
        //   In: 
        //       eventSender:     The event sender
        //       eventArgs  :     The event arguments
        //   Returns:
        //
        //**********************************************************************
        private void optRepTkCtl_CheckedChanged(System.Object    eventSender, 
                                                System.EventArgs eventArgs) {
            if(((RadioButton)eventSender).Checked) {
                cmdFldConfig3.Enabled = true;
                if(TreeView1.SelectedNode != null) {
                    ((object[])TreeView1.SelectedNode.Tag)[2] = 2;
                }
            }
        }

        //**********************************************************************
        //
        // When DataGrid control OptionButton checked changed
        //   In: 
        //       eventSender:     The event sender
        //       eventArgs  :     The event arguments
        //   Returns:
        //
        //**********************************************************************
        private void optGridCtl_CheckedChanged(System.Object    eventSender, 
                                               System.EventArgs eventArgs) {
            if (((RadioButton)eventSender).Checked) {
                cmdFldConfig3.Enabled = false;
                if(TreeView1.SelectedNode != null) {
                    ((Object[])TreeView1.SelectedNode.Tag)[2] = 1;
                }
            }
        }

        //**********************************************************************
        //
        // When same form OptionButton checked changed
        //   In: 
        //       eventSender:     The event sender
        //       eventArgs  :     The event arguments
        //   Returns:
        //
        //**********************************************************************
        private void optSameFrm_CheckedChanged(System.Object    eventSender, 
                                               System.EventArgs eventArgs) {
            if  (((RadioButton)eventSender).Checked && TreeView1.SelectedNode != null) {
                ((object[])TreeView1.SelectedNode.Tag)[3] = FormOptionE.sdSameForm;
            }
        }

        //**********************************************************
        //
        // When new form OptionButton checked changed
        //   In: 
        //       eventSender:     The event sender
        //       eventArgs  :     The event arguments
        //   Returns:
        //
        //**********************************************************
        private void optNewFrm_CheckedChanged(System.Object    eventSender, 
                                              System.EventArgs eventArgs) {
            if  (((RadioButton)eventSender).Checked && TreeView1.SelectedNode != null) {
                ((object[])TreeView1.SelectedNode.Tag)[3] = FormOptionE.sdNewFormAll;
            }
        }

        //**********************************************************
        //
        // When new form each OptionButton checked changed
        //   In: 
        //       eventSender:     The event sender
        //       eventArgs  :     The event arguments
        //   Returns:
        //
        //**********************************************************
        private void optNewFrmEach_CheckedChanged(System.Object    eventSender, 
                                                  System.EventArgs eventArgs) {
            if  (((RadioButton)eventSender).Checked && TreeView1.SelectedNode != null) {
                ((object[])TreeView1.SelectedNode.Tag)[3] = FormOptionE.sdNewFormEach;
            }
        }

        //**********************************************************************
        //
        // When form name edit text control leaved
        //   In: 
        //       eventSender:     The event sender
        //       eventArgs  :     The event arguments
        //   Returns:
        //
        //**********************************************************************
        private void txtFormName_Leave(System.Object eventSender, System.EventArgs eventArgs) {
            ((object[])TreeView1.SelectedNode.Tag)[1] = txtFormName.Text;
        }

        //**********************************************************
        //
        // Step 4 RepPP Control Option Button checked changed
        //   In: 
        //       eventSender:     The event sender
        //       eventArgs  :     The event arguments
        //   Returns:
        //
        //**********************************************************
        private void optFrmRepCtl_CheckedChanged(System.Object eventSender, System.EventArgs eventArgs) {
            if (((RadioButton)eventSender).Checked) {
                cmdFldConfig4.Enabled = true;
                if (TreeView1.Nodes.Count > 0) {
                    ((object[])TreeView1.Nodes[0].Tag)[2] = 0;
                }
            }
        }

        //**********************************************************
        //
        // Step 4 RepPP toolkit Control Option Button checked changed
        //   In: 
        //       eventSender:     The event sender
        //       eventArgs  :     The event arguments
        //   Returns:
        //
        //**********************************************************
        private void optFrmRepTkCtl_CheckedChanged(System.Object eventSender, System.EventArgs eventArgs) {
            if (((RadioButton)eventSender).Checked) {
                cmdFldConfig4.Enabled = true;
                if (TreeView1.Nodes.Count > 0) {
                    ((object[])TreeView1.Nodes[0].Tag)[2] = 2;
                }
            }
        }

        //**********************************************************
        //
        // Step 4 DateGrid Control Option Button checked changed
        //   In: 
        //       eventSender:     The event sender
        //       eventArgs  :     The event arguments
        //   Returns:
        //
        //**********************************************************
        private void optFrmGridCtl_CheckedChanged(System.Object    eventSender, 
                                                  System.EventArgs eventArgs) {
            if (((RadioButton)eventSender).Checked) {
                cmdFldConfig4.Enabled = false;
                if(TreeView1.Nodes.Count > 0) {
                    ((object[])TreeView1.Nodes[0].Tag)[2] = 1;
                }
            }
        }

        //**********************************************************
        //
        // Configure step 3 button clicked
        //   In: 
        //       eventSender:     The event sender
        //       eventArgs  :     The event arguments
        //   Returns:
        //
        //**********************************************************
        private void cmdFldConfig3_Click(System.Object    eventSender, 
                                         System.EventArgs eventArgs) {
            ConfigForm();
        }

        //**********************************************************
        //
        // Configure step 4 button clicked
        //   In: 
        //       eventSender:     The event sender
        //       eventArgs  :     The event arguments
        //   Returns:
        //
        //**********************************************************
        private void cmdFldConfig4_Click(System.Object    eventSender, 
                                         System.EventArgs eventArgs) {
            ConfigForm();
        }

        //**********************************************************
        //
        // Call frmFieldConfig form to set form generation options
        //   In: 
        //
        //   Returns:
        //
        //**********************************************************
        private void ConfigForm() {
            frmFieldConfig  frmConfig;
            object[]        tag;
            
            if (TreeView1.SelectedNode != null) {
                tag = (object[])TreeView1.SelectedNode.Tag;
            } else {
                tag = (object[])TreeView1.Nodes[0].Tag;
            }
            using (frmConfig = frmConfig = new frmFieldConfig(tag)) {
                if (frmConfig.ShowDialog(this) == DialogResult.OK) {
                    if (frmConfig.optLeft.Checked) {
                        tag[7] = HorizontalAlignment.Left;
                    } else if (frmConfig.optCenter.Checked) {
                        tag[7] = HorizontalAlignment.Center;
                    } else {
                        tag[7] = HorizontalAlignment.Right;
                    }
                    if (frmConfig.optSimple.Checked) {
                        tag[6] = ComboBoxStyle.Simple;
                    } else if (frmConfig.optDropDown.Checked) {
                        tag[6] = ComboBoxStyle.DropDown;
                    } else {
                        tag[6] = ComboBoxStyle.DropDownList;
                    }
                    tag[8] = frmConfig.optEdit.Checked;
                    tag[9] = frmConfig.optTextOnLeft.Checked;
                }
            }
        }

        //**********************************************************
        //
        // Connection wizard button clicked
        //   In: 
        //       eventSender:     The event sender
        //       eventArgs  :     The event arguments
        //   Returns:
        //
        //**********************************************************
        private void cmdConnWizard_Click(System.Object sender, System.EventArgs e) {
            string              strConnection = txtConnection.Text;
            string              strUser       = txtUser.Text;
            string              strPassword   = txtPassword.Text;
            string              strSystem     = txtSystem.Text;
            string              strProgram    = txtProgram.Text;
            RepPP.Application   app           = null;

            try {
                app = RepPP.Application.GetApplication();
                if (app == null) {
                    app = RepPP.Application.Create();
                }
                RepPP.ConnWizard.ShowDialog(ref strConnection, 
                                            ref strUser, 
                                            ref strPassword, 
                                            ref strSystem, 
                                            ref strProgram, 
                                            2, 
                                            Handle.ToInt32());
                txtConnection.Text  = strConnection;
                txtUser.Text        = strUser;
                txtPassword.Text    = strPassword;
                txtSystem.Text      = strSystem;
                txtProgram.Text     = strProgram;
            } catch(System.Exception ex) {
                MessageBox.Show(ex.ToString());
            }
        }

        //**********************************************************
        //
        // Check if the sdtkdock is installed
        //   In: 
        //
        //   Returns:
        //
        //**********************************************************
        private bool IsDNetBarInstalled() {
            bool        bRetVal;
            string      strDllPath;

            strDllPath = Path.Combine(Utility.GetRepPPBinDir(), "RepPP.Framework.Window.Ext.V1.dll");
            bRetVal    = File.Exists(strDllPath);
            // TODO: how tocheck id the .Net bar dll is installed?
            return (bRetVal);
        }

        #region Windows Form Designer generated code
        /// <summary>
        /// Required method for Designer support - do not modify
        /// the contents of this method with the code editor.
        /// </summary>
        #endregion

        private void InitializeComponent() {
            System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(frmMain));
            this.pnlStep4 = new System.Windows.Forms.Panel();
            this.Panel2 = new System.Windows.Forms.Panel();
            this.lblHeader4 = new System.Windows.Forms.Label();
            this.lblStep4 = new System.Windows.Forms.Label();
            this.txtFrmFormName = new System.Windows.Forms.TextBox();
            this.fraFmtFormLayout = new System.Windows.Forms.GroupBox();
            this.optFrmRepTkCtl = new System.Windows.Forms.RadioButton();
            this.cmdFldConfig4 = new System.Windows.Forms.Button();
            this.optFrmGridCtl = new System.Windows.Forms.RadioButton();
            this.optFrmRepCtl = new System.Windows.Forms.RadioButton();
            this.LabelFrmName = new System.Windows.Forms.Label();
            this.pnlStep3 = new System.Windows.Forms.Panel();
            this.pnlHeader3 = new System.Windows.Forms.Panel();
            this.Label5 = new System.Windows.Forms.Label();
            this.Label4 = new System.Windows.Forms.Label();
            this.TreeView1 = new System.Windows.Forms.TreeView();
            this.Picture1 = new System.Windows.Forms.Panel();
            this.cmbBaseForm = new System.Windows.Forms.ComboBox();
            this.lblBaseForm = new System.Windows.Forms.Label();
            this.txtFormName = new System.Windows.Forms.TextBox();
            this.fraFrmLayout = new System.Windows.Forms.GroupBox();
            this.optRepTkCtl = new System.Windows.Forms.RadioButton();
            this.cmdFldConfig3 = new System.Windows.Forms.Button();
            this.optGridCtl = new System.Windows.Forms.RadioButton();
            this.optRepCtl = new System.Windows.Forms.RadioButton();
            this.fraChildLocation = new System.Windows.Forms.GroupBox();
            this.optNewFrmEach = new System.Windows.Forms.RadioButton();
            this.optNewFrm = new System.Windows.Forms.RadioButton();
            this.optSameFrm = new System.Windows.Forms.RadioButton();
            this.lblFormName = new System.Windows.Forms.Label();
            this.pnlStep1 = new System.Windows.Forms.Panel();
            this.pnlHeader1 = new System.Windows.Forms.Panel();
            this.Label1 = new System.Windows.Forms.Label();
            this.pnlConnection = new System.Windows.Forms.Panel();
            this.cmdConnWizard = new System.Windows.Forms.Button();
            this.cmbLanguage = new System.Windows.Forms.ComboBox();
            this.lblLanguage = new System.Windows.Forms.Label();
            this.txtProgram = new System.Windows.Forms.TextBox();
            this.lblProgram = new System.Windows.Forms.Label();
            this.txtSystem = new System.Windows.Forms.TextBox();
            this.lblSystem = new System.Windows.Forms.Label();
            this.txtPassword = new System.Windows.Forms.TextBox();
            this.lblPassword = new System.Windows.Forms.Label();
            this.txtUser = new System.Windows.Forms.TextBox();
            this.lblUser = new System.Windows.Forms.Label();
            this.txtConnection = new System.Windows.Forms.TextBox();
            this.lblConnection = new System.Windows.Forms.Label();
            this.pnlStep0 = new System.Windows.Forms.Panel();
            this.imgStep0 = new System.Windows.Forms.PictureBox();
            this.lblHeader0 = new System.Windows.Forms.Label();
            this.pnlStep2 = new System.Windows.Forms.Panel();
            this.grpUseSB = new System.Windows.Forms.GroupBox();
            this.chkUseDNetBar = new System.Windows.Forms.CheckBox();
            this.chkUseSB = new System.Windows.Forms.CheckBox();
            this.cboSBCards = new System.Windows.Forms.ComboBox();
            this.lblSBCardName = new System.Windows.Forms.Label();
            this.grpToolbarSize = new System.Windows.Forms.GroupBox();
            this.optLarge = new System.Windows.Forms.RadioButton();
            this.optSmall = new System.Windows.Forms.RadioButton();
            this.pnlHeader2 = new System.Windows.Forms.Panel();
            this.Label2 = new System.Windows.Forms.Label();
            this.Label3 = new System.Windows.Forms.Label();
            this.fraGenerate = new System.Windows.Forms.GroupBox();
            this.optGroupForm = new System.Windows.Forms.RadioButton();
            this.optGenerate2T = new System.Windows.Forms.RadioButton();
            this.optGenerate3T = new System.Windows.Forms.RadioButton();
            this.optCardForm = new System.Windows.Forms.RadioButton();
            this.cboCards = new System.Windows.Forms.ComboBox();
            this.lblCardGroup = new System.Windows.Forms.Label();
            this.pnlStep5 = new System.Windows.Forms.Panel();
            this.txtSummary = new System.Windows.Forms.TextBox();
            this.lblStatus = new System.Windows.Forms.Label();
            this.pnlHeader5 = new System.Windows.Forms.Panel();
            this.lblHeader5 = new System.Windows.Forms.Label();
            this.lblStep5 = new System.Windows.Forms.Label();
            this.pnlStepTypedInst = new System.Windows.Forms.Panel();
            this.pnlTypedInst = new System.Windows.Forms.Panel();
            this.panel4 = new System.Windows.Forms.Panel();
            this.label7 = new System.Windows.Forms.Label();
            this.label8 = new System.Windows.Forms.Label();
            this.cmdFinish = new System.Windows.Forms.Button();
            this.cmdNext = new System.Windows.Forms.Button();
            this.cmdBack = new System.Windows.Forms.Button();
            this._Line1_1 = new System.Windows.Forms.Label();
            this._Line1_0 = new System.Windows.Forms.Label();
            this.picNav = new System.Windows.Forms.Panel();
            this.pnlStep4.SuspendLayout();
            this.Panel2.SuspendLayout();
            this.fraFmtFormLayout.SuspendLayout();
            this.pnlStep3.SuspendLayout();
            this.pnlHeader3.SuspendLayout();
            this.Picture1.SuspendLayout();
            this.fraFrmLayout.SuspendLayout();
            this.fraChildLocation.SuspendLayout();
            this.pnlStep1.SuspendLayout();
            this.pnlHeader1.SuspendLayout();
            this.pnlConnection.SuspendLayout();
            this.pnlStep0.SuspendLayout();
            this.pnlStep2.SuspendLayout();
            this.grpUseSB.SuspendLayout();
            this.grpToolbarSize.SuspendLayout();
            this.pnlHeader2.SuspendLayout();
            this.fraGenerate.SuspendLayout();
            this.pnlStep5.SuspendLayout();
            this.pnlHeader5.SuspendLayout();
            this.pnlStepTypedInst.SuspendLayout();
            this.panel4.SuspendLayout();
            this.picNav.SuspendLayout();
            this.SuspendLayout();
            // 
            // pnlStep4
            // 
            this.pnlStep4.BackColor = System.Drawing.SystemColors.Control;
            this.pnlStep4.Controls.Add(this.Panel2);
            this.pnlStep4.Controls.Add(this.txtFrmFormName);
            this.pnlStep4.Controls.Add(this.fraFmtFormLayout);
            this.pnlStep4.Controls.Add(this.LabelFrmName);
            this.pnlStep4.Cursor = System.Windows.Forms.Cursors.Default;
            this.pnlStep4.ForeColor = System.Drawing.SystemColors.ControlText;
            this.pnlStep4.Location = new System.Drawing.Point(0, 0);
            this.pnlStep4.Name = "pnlStep4";
            this.pnlStep4.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.pnlStep4.Size = new System.Drawing.Size(484, 334);
            this.pnlStep4.TabIndex = 32;
            this.pnlStep4.Tag = "2004";
            this.pnlStep4.Text = "Step 2 Group";
            // 
            // Panel2
            // 
            this.Panel2.BackColor = System.Drawing.SystemColors.Window;
            this.Panel2.Controls.Add(this.lblHeader4);
            this.Panel2.Controls.Add(this.lblStep4);
            this.Panel2.Location = new System.Drawing.Point(0, 0);
            this.Panel2.Name = "Panel2";
            this.Panel2.Size = new System.Drawing.Size(478, 56);
            this.Panel2.TabIndex = 41;
            // 
            // lblHeader4
            // 
            this.lblHeader4.Font = new System.Drawing.Font("Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
            this.lblHeader4.Location = new System.Drawing.Point(16, 4);
            this.lblHeader4.Name = "lblHeader4";
            this.lblHeader4.Size = new System.Drawing.Size(264, 16);
            this.lblHeader4.TabIndex = 42;
            this.lblHeader4.Text = "Set Form Layout";
            // 
            // lblStep4
            // 
            this.lblStep4.BackColor = System.Drawing.SystemColors.Window;
            this.lblStep4.Cursor = System.Windows.Forms.Cursors.Default;
            this.lblStep4.ForeColor = System.Drawing.SystemColors.ControlText;
            this.lblStep4.Location = new System.Drawing.Point(24, 22);
            this.lblStep4.Name = "lblStep4";
            this.lblStep4.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.lblStep4.Size = new System.Drawing.Size(376, 24);
            this.lblStep4.TabIndex = 41;
            this.lblStep4.Text = "Set form\'s name and select control\'s type.";
            // 
            // txtFrmFormName
            // 
            this.txtFrmFormName.AcceptsReturn = true;
            this.txtFrmFormName.AutoSize = false;
            this.txtFrmFormName.BackColor = System.Drawing.SystemColors.Window;
            this.txtFrmFormName.Cursor = System.Windows.Forms.Cursors.IBeam;
            this.txtFrmFormName.ForeColor = System.Drawing.SystemColors.WindowText;
            this.txtFrmFormName.Location = new System.Drawing.Point(104, 88);
            this.txtFrmFormName.MaxLength = 0;
            this.txtFrmFormName.Name = "txtFrmFormName";
            this.txtFrmFormName.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.txtFrmFormName.Size = new System.Drawing.Size(193, 19);
            this.txtFrmFormName.TabIndex = 0;
            this.txtFrmFormName.Text = "";
            this.txtFrmFormName.TextChanged += new System.EventHandler(this.txtfrmFormName_TextChanged);
            this.txtFrmFormName.Leave += new System.EventHandler(this.txtfrmFormName_Leave);
            // 
            // fraFmtFormLayout
            // 
            this.fraFmtFormLayout.BackColor = System.Drawing.SystemColors.Control;
            this.fraFmtFormLayout.Controls.Add(this.optFrmRepTkCtl);
            this.fraFmtFormLayout.Controls.Add(this.cmdFldConfig4);
            this.fraFmtFormLayout.Controls.Add(this.optFrmGridCtl);
            this.fraFmtFormLayout.Controls.Add(this.optFrmRepCtl);
            this.fraFmtFormLayout.ForeColor = System.Drawing.SystemColors.ControlText;
            this.fraFmtFormLayout.Location = new System.Drawing.Point(32, 128);
            this.fraFmtFormLayout.Name = "fraFmtFormLayout";
            this.fraFmtFormLayout.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.fraFmtFormLayout.Size = new System.Drawing.Size(264, 104);
            this.fraFmtFormLayout.TabIndex = 1;
            this.fraFmtFormLayout.TabStop = false;
            this.fraFmtFormLayout.Text = "Form Layout";
            // 
            // optFrmRepTkCtl
            // 
            this.optFrmRepTkCtl.BackColor = System.Drawing.SystemColors.Control;
            this.optFrmRepTkCtl.Cursor = System.Windows.Forms.Cursors.Default;
            this.optFrmRepTkCtl.ForeColor = System.Drawing.SystemColors.ControlText;
            this.optFrmRepTkCtl.Location = new System.Drawing.Point(18, 48);
            this.optFrmRepTkCtl.Name = "optFrmRepTkCtl";
            this.optFrmRepTkCtl.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.optFrmRepTkCtl.Size = new System.Drawing.Size(126, 17);
            this.optFrmRepTkCtl.TabIndex = 3;
            this.optFrmRepTkCtl.Text = "Rep++ toolkit controls";
            this.optFrmRepTkCtl.CheckedChanged += new System.EventHandler(this.optFrmRepTkCtl_CheckedChanged);
            // 
            // cmdFldConfig4
            // 
            this.cmdFldConfig4.BackColor = System.Drawing.SystemColors.Control;
            this.cmdFldConfig4.Cursor = System.Windows.Forms.Cursors.Default;
            this.cmdFldConfig4.ForeColor = System.Drawing.SystemColors.ControlText;
            this.cmdFldConfig4.Location = new System.Drawing.Point(160, 24);
            this.cmdFldConfig4.Name = "cmdFldConfig4";
            this.cmdFldConfig4.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.cmdFldConfig4.Size = new System.Drawing.Size(65, 21);
            this.cmdFldConfig4.TabIndex = 2;
            this.cmdFldConfig4.Text = "C&onfigure";
            this.cmdFldConfig4.Click += new System.EventHandler(this.cmdFldConfig4_Click);
            // 
            // optFrmGridCtl
            // 
            this.optFrmGridCtl.BackColor = System.Drawing.SystemColors.Control;
            this.optFrmGridCtl.Cursor = System.Windows.Forms.Cursors.Default;
            this.optFrmGridCtl.ForeColor = System.Drawing.SystemColors.ControlText;
            this.optFrmGridCtl.Location = new System.Drawing.Point(18, 72);
            this.optFrmGridCtl.Name = "optFrmGridCtl";
            this.optFrmGridCtl.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.optFrmGridCtl.Size = new System.Drawing.Size(126, 17);
            this.optFrmGridCtl.TabIndex = 1;
            this.optFrmGridCtl.Text = "DataGrid control";
            this.optFrmGridCtl.CheckedChanged += new System.EventHandler(this.optFrmGridCtl_CheckedChanged);
            // 
            // optFrmRepCtl
            // 
            this.optFrmRepCtl.BackColor = System.Drawing.SystemColors.Control;
            this.optFrmRepCtl.Checked = true;
            this.optFrmRepCtl.Cursor = System.Windows.Forms.Cursors.Default;
            this.optFrmRepCtl.ForeColor = System.Drawing.SystemColors.ControlText;
            this.optFrmRepCtl.Location = new System.Drawing.Point(18, 24);
            this.optFrmRepCtl.Name = "optFrmRepCtl";
            this.optFrmRepCtl.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.optFrmRepCtl.Size = new System.Drawing.Size(126, 17);
            this.optFrmRepCtl.TabIndex = 0;
            this.optFrmRepCtl.TabStop = true;
            this.optFrmRepCtl.Text = "Rep++ controls";
            this.optFrmRepCtl.CheckedChanged += new System.EventHandler(this.optFrmRepCtl_CheckedChanged);
            // 
            // LabelFrmName
            // 
            this.LabelFrmName.BackColor = System.Drawing.SystemColors.Control;
            this.LabelFrmName.Cursor = System.Windows.Forms.Cursors.Default;
            this.LabelFrmName.ForeColor = System.Drawing.SystemColors.ControlText;
            this.LabelFrmName.Location = new System.Drawing.Point(32, 92);
            this.LabelFrmName.Name = "LabelFrmName";
            this.LabelFrmName.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.LabelFrmName.Size = new System.Drawing.Size(64, 24);
            this.LabelFrmName.TabIndex = 38;
            this.LabelFrmName.Text = "Form Name";
            // 
            // pnlStep3
            // 
            this.pnlStep3.BackColor = System.Drawing.SystemColors.Control;
            this.pnlStep3.Controls.Add(this.pnlHeader3);
            this.pnlStep3.Controls.Add(this.TreeView1);
            this.pnlStep3.Controls.Add(this.Picture1);
            this.pnlStep3.Cursor = System.Windows.Forms.Cursors.Default;
            this.pnlStep3.ForeColor = System.Drawing.SystemColors.ControlText;
            this.pnlStep3.Location = new System.Drawing.Point(0, 0);
            this.pnlStep3.Name = "pnlStep3";
            this.pnlStep3.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.pnlStep3.Size = new System.Drawing.Size(484, 334);
            this.pnlStep3.TabIndex = 19;
            this.pnlStep3.Tag = "2002";
            this.pnlStep3.Text = "Step 2 Card";
            // 
            // pnlHeader3
            // 
            this.pnlHeader3.BackColor = System.Drawing.SystemColors.Window;
            this.pnlHeader3.Controls.Add(this.Label5);
            this.pnlHeader3.Controls.Add(this.Label4);
            this.pnlHeader3.Location = new System.Drawing.Point(0, 0);
            this.pnlHeader3.Name = "pnlHeader3";
            this.pnlHeader3.Size = new System.Drawing.Size(478, 56);
            this.pnlHeader3.TabIndex = 26;
            // 
            // Label5
            // 
            this.Label5.BackColor = System.Drawing.SystemColors.Window;
            this.Label5.Cursor = System.Windows.Forms.Cursors.Default;
            this.Label5.ForeColor = System.Drawing.SystemColors.ControlText;
            this.Label5.Location = new System.Drawing.Point(24, 22);
            this.Label5.Name = "Label5";
            this.Label5.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.Label5.Size = new System.Drawing.Size(216, 16);
            this.Label5.TabIndex = 27;
            this.Label5.Text = "Select main form and children layout.";
            // 
            // Label4
            // 
            this.Label4.Font = new System.Drawing.Font("Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
            this.Label4.Location = new System.Drawing.Point(16, 4);
            this.Label4.Name = "Label4";
            this.Label4.Size = new System.Drawing.Size(208, 16);
            this.Label4.TabIndex = 26;
            this.Label4.Text = "Set Form Layout";
            // 
            // TreeView1
            // 
            this.TreeView1.HideSelection = false;
            this.TreeView1.ImageIndex = -1;
            this.TreeView1.Location = new System.Drawing.Point(14, 72);
            this.TreeView1.Name = "TreeView1";
            this.TreeView1.SelectedImageIndex = -1;
            this.TreeView1.Size = new System.Drawing.Size(168, 258);
            this.TreeView1.TabIndex = 0;
            this.TreeView1.AfterSelect += new System.Windows.Forms.TreeViewEventHandler(this.TreeView1_AfterSelect);
            // 
            // Picture1
            // 
            this.Picture1.BackColor = System.Drawing.SystemColors.Control;
            this.Picture1.BorderStyle = System.Windows.Forms.BorderStyle.Fixed3D;
            this.Picture1.Controls.Add(this.cmbBaseForm);
            this.Picture1.Controls.Add(this.lblBaseForm);
            this.Picture1.Controls.Add(this.txtFormName);
            this.Picture1.Controls.Add(this.fraFrmLayout);
            this.Picture1.Controls.Add(this.fraChildLocation);
            this.Picture1.Controls.Add(this.lblFormName);
            this.Picture1.Cursor = System.Windows.Forms.Cursors.Default;
            this.Picture1.ForeColor = System.Drawing.SystemColors.ControlText;
            this.Picture1.Location = new System.Drawing.Point(192, 72);
            this.Picture1.Name = "Picture1";
            this.Picture1.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.Picture1.Size = new System.Drawing.Size(272, 258);
            this.Picture1.TabIndex = 1;
            this.Picture1.TabStop = true;
            // 
            // cmbBaseForm
            // 
            this.cmbBaseForm.Location = new System.Drawing.Point(80, 40);
            this.cmbBaseForm.Name = "cmbBaseForm";
            this.cmbBaseForm.Size = new System.Drawing.Size(176, 21);
            this.cmbBaseForm.TabIndex = 1;
            this.cmbBaseForm.TextChanged += new System.EventHandler(this.cmbBaseForm_TextChanged);
            this.cmbBaseForm.SelectedIndexChanged += new System.EventHandler(this.cmbBaseForm_SelectedIndexChanged);
            this.cmbBaseForm.Leave += new System.EventHandler(this.cmbBaseForm_Leave);
            // 
            // lblBaseForm
            // 
            this.lblBaseForm.Location = new System.Drawing.Point(14, 40);
            this.lblBaseForm.Name = "lblBaseForm";
            this.lblBaseForm.Size = new System.Drawing.Size(64, 14);
            this.lblBaseForm.TabIndex = 32;
            this.lblBaseForm.Text = "Base Form";
            // 
            // txtFormName
            // 
            this.txtFormName.AcceptsReturn = true;
            this.txtFormName.AutoSize = false;
            this.txtFormName.BackColor = System.Drawing.SystemColors.Window;
            this.txtFormName.Cursor = System.Windows.Forms.Cursors.IBeam;
            this.txtFormName.ForeColor = System.Drawing.SystemColors.WindowText;
            this.txtFormName.Location = new System.Drawing.Point(80, 10);
            this.txtFormName.MaxLength = 0;
            this.txtFormName.Name = "txtFormName";
            this.txtFormName.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.txtFormName.Size = new System.Drawing.Size(176, 19);
            this.txtFormName.TabIndex = 0;
            this.txtFormName.Text = "";
            this.txtFormName.TextChanged += new System.EventHandler(this.txtFormName_TextChanged);
            this.txtFormName.Leave += new System.EventHandler(this.txtFormName_Leave);
            // 
            // fraFrmLayout
            // 
            this.fraFrmLayout.BackColor = System.Drawing.SystemColors.Control;
            this.fraFrmLayout.Controls.Add(this.optRepTkCtl);
            this.fraFrmLayout.Controls.Add(this.cmdFldConfig3);
            this.fraFrmLayout.Controls.Add(this.optGridCtl);
            this.fraFrmLayout.Controls.Add(this.optRepCtl);
            this.fraFrmLayout.ForeColor = System.Drawing.SystemColors.ControlText;
            this.fraFrmLayout.Location = new System.Drawing.Point(8, 72);
            this.fraFrmLayout.Name = "fraFrmLayout";
            this.fraFrmLayout.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.fraFrmLayout.Size = new System.Drawing.Size(248, 96);
            this.fraFrmLayout.TabIndex = 2;
            this.fraFrmLayout.TabStop = false;
            this.fraFrmLayout.Text = "Form Layout";
            // 
            // optRepTkCtl
            // 
            this.optRepTkCtl.Location = new System.Drawing.Point(16, 40);
            this.optRepTkCtl.Name = "optRepTkCtl";
            this.optRepTkCtl.Size = new System.Drawing.Size(136, 16);
            this.optRepTkCtl.TabIndex = 3;
            this.optRepTkCtl.Text = "Rep++ toolkit controls";
            this.optRepTkCtl.CheckedChanged += new System.EventHandler(this.optRepTkCtl_CheckedChanged);
            // 
            // cmdFldConfig3
            // 
            this.cmdFldConfig3.BackColor = System.Drawing.SystemColors.Control;
            this.cmdFldConfig3.Cursor = System.Windows.Forms.Cursors.Default;
            this.cmdFldConfig3.ForeColor = System.Drawing.SystemColors.ControlText;
            this.cmdFldConfig3.Location = new System.Drawing.Point(168, 16);
            this.cmdFldConfig3.Name = "cmdFldConfig3";
            this.cmdFldConfig3.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.cmdFldConfig3.Size = new System.Drawing.Size(65, 21);
            this.cmdFldConfig3.TabIndex = 2;
            this.cmdFldConfig3.Text = "C&onfigure";
            this.cmdFldConfig3.Click += new System.EventHandler(this.cmdFldConfig3_Click);
            // 
            // optGridCtl
            // 
            this.optGridCtl.BackColor = System.Drawing.SystemColors.Control;
            this.optGridCtl.Cursor = System.Windows.Forms.Cursors.Default;
            this.optGridCtl.ForeColor = System.Drawing.SystemColors.ControlText;
            this.optGridCtl.Location = new System.Drawing.Point(16, 64);
            this.optGridCtl.Name = "optGridCtl";
            this.optGridCtl.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.optGridCtl.Size = new System.Drawing.Size(136, 17);
            this.optGridCtl.TabIndex = 1;
            this.optGridCtl.TabStop = true;
            this.optGridCtl.Text = "DataGrid control";
            this.optGridCtl.CheckedChanged += new System.EventHandler(this.optGridCtl_CheckedChanged);
            // 
            // optRepCtl
            // 
            this.optRepCtl.BackColor = System.Drawing.SystemColors.Control;
            this.optRepCtl.Checked = true;
            this.optRepCtl.Cursor = System.Windows.Forms.Cursors.Default;
            this.optRepCtl.ForeColor = System.Drawing.SystemColors.ControlText;
            this.optRepCtl.Location = new System.Drawing.Point(16, 16);
            this.optRepCtl.Name = "optRepCtl";
            this.optRepCtl.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.optRepCtl.Size = new System.Drawing.Size(136, 16);
            this.optRepCtl.TabIndex = 0;
            this.optRepCtl.TabStop = true;
            this.optRepCtl.Text = "Rep++ controls";
            this.optRepCtl.CheckedChanged += new System.EventHandler(this.optRepCtl_CheckedChanged);
            // 
            // fraChildLocation
            // 
            this.fraChildLocation.BackColor = System.Drawing.SystemColors.Control;
            this.fraChildLocation.Controls.Add(this.optNewFrmEach);
            this.fraChildLocation.Controls.Add(this.optNewFrm);
            this.fraChildLocation.Controls.Add(this.optSameFrm);
            this.fraChildLocation.ForeColor = System.Drawing.SystemColors.ControlText;
            this.fraChildLocation.Location = new System.Drawing.Point(8, 176);
            this.fraChildLocation.Name = "fraChildLocation";
            this.fraChildLocation.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.fraChildLocation.Size = new System.Drawing.Size(248, 74);
            this.fraChildLocation.TabIndex = 3;
            this.fraChildLocation.TabStop = false;
            this.fraChildLocation.Text = "Children Location";
            // 
            // optNewFrmEach
            // 
            this.optNewFrmEach.BackColor = System.Drawing.SystemColors.Control;
            this.optNewFrmEach.Cursor = System.Windows.Forms.Cursors.Default;
            this.optNewFrmEach.ForeColor = System.Drawing.SystemColors.ControlText;
            this.optNewFrmEach.Location = new System.Drawing.Point(112, 16);
            this.optNewFrmEach.Name = "optNewFrmEach";
            this.optNewFrmEach.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.optNewFrmEach.Size = new System.Drawing.Size(120, 24);
            this.optNewFrmEach.TabIndex = 2;
            this.optNewFrmEach.TabStop = true;
            this.optNewFrmEach.Text = "New form for each";
            this.optNewFrmEach.CheckedChanged += new System.EventHandler(this.optNewFrmEach_CheckedChanged);
            // 
            // optNewFrm
            // 
            this.optNewFrm.BackColor = System.Drawing.SystemColors.Control;
            this.optNewFrm.Cursor = System.Windows.Forms.Cursors.Default;
            this.optNewFrm.ForeColor = System.Drawing.SystemColors.ControlText;
            this.optNewFrm.Location = new System.Drawing.Point(16, 40);
            this.optNewFrm.Name = "optNewFrm";
            this.optNewFrm.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.optNewFrm.Size = new System.Drawing.Size(88, 17);
            this.optNewFrm.TabIndex = 1;
            this.optNewFrm.TabStop = true;
            this.optNewFrm.Text = "New form";
            this.optNewFrm.CheckedChanged += new System.EventHandler(this.optNewFrm_CheckedChanged);
            // 
            // optSameFrm
            // 
            this.optSameFrm.BackColor = System.Drawing.SystemColors.Control;
            this.optSameFrm.Checked = true;
            this.optSameFrm.Cursor = System.Windows.Forms.Cursors.Default;
            this.optSameFrm.ForeColor = System.Drawing.SystemColors.ControlText;
            this.optSameFrm.Location = new System.Drawing.Point(16, 16);
            this.optSameFrm.Name = "optSameFrm";
            this.optSameFrm.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.optSameFrm.Size = new System.Drawing.Size(88, 17);
            this.optSameFrm.TabIndex = 0;
            this.optSameFrm.TabStop = true;
            this.optSameFrm.Text = "Same form";
            this.optSameFrm.CheckedChanged += new System.EventHandler(this.optSameFrm_CheckedChanged);
            // 
            // lblFormName
            // 
            this.lblFormName.BackColor = System.Drawing.SystemColors.Control;
            this.lblFormName.Cursor = System.Windows.Forms.Cursors.Default;
            this.lblFormName.ForeColor = System.Drawing.SystemColors.ControlText;
            this.lblFormName.Location = new System.Drawing.Point(14, 10);
            this.lblFormName.Name = "lblFormName";
            this.lblFormName.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.lblFormName.Size = new System.Drawing.Size(64, 17);
            this.lblFormName.TabIndex = 30;
            this.lblFormName.Text = "Form Name";
            // 
            // pnlStep1
            // 
            this.pnlStep1.BackColor = System.Drawing.SystemColors.Control;
            this.pnlStep1.Controls.Add(this.pnlHeader1);
            this.pnlStep1.Controls.Add(this.pnlConnection);
            this.pnlStep1.Cursor = System.Windows.Forms.Cursors.Default;
            this.pnlStep1.ForeColor = System.Drawing.SystemColors.ControlText;
            this.pnlStep1.Location = new System.Drawing.Point(0, 0);
            this.pnlStep1.Name = "pnlStep1";
            this.pnlStep1.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.pnlStep1.Size = new System.Drawing.Size(484, 334);
            this.pnlStep1.TabIndex = 25;
            this.pnlStep1.Tag = "2002";
            this.pnlStep1.Text = "Step 1 Init. Rep";
            // 
            // pnlHeader1
            // 
            this.pnlHeader1.BackColor = System.Drawing.SystemColors.Window;
            this.pnlHeader1.Controls.Add(this.Label1);
            this.pnlHeader1.Location = new System.Drawing.Point(0, 0);
            this.pnlHeader1.Name = "pnlHeader1";
            this.pnlHeader1.Size = new System.Drawing.Size(478, 50);
            this.pnlHeader1.TabIndex = 23;
            // 
            // Label1
            // 
            this.Label1.BackColor = System.Drawing.SystemColors.Window;
            this.Label1.Cursor = System.Windows.Forms.Cursors.Default;
            this.Label1.Font = new System.Drawing.Font("Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
            this.Label1.ForeColor = System.Drawing.SystemColors.ControlText;
            this.Label1.Location = new System.Drawing.Point(16, 4);
            this.Label1.Name = "Label1";
            this.Label1.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.Label1.Size = new System.Drawing.Size(280, 15);
            this.Label1.TabIndex = 21;
            this.Label1.Text = "Initialize Rep++";
            // 
            // pnlConnection
            // 
            this.pnlConnection.BackColor = System.Drawing.SystemColors.Control;
            this.pnlConnection.Controls.Add(this.cmdConnWizard);
            this.pnlConnection.Controls.Add(this.cmbLanguage);
            this.pnlConnection.Controls.Add(this.lblLanguage);
            this.pnlConnection.Controls.Add(this.txtProgram);
            this.pnlConnection.Controls.Add(this.lblProgram);
            this.pnlConnection.Controls.Add(this.txtSystem);
            this.pnlConnection.Controls.Add(this.lblSystem);
            this.pnlConnection.Controls.Add(this.txtPassword);
            this.pnlConnection.Controls.Add(this.lblPassword);
            this.pnlConnection.Controls.Add(this.txtUser);
            this.pnlConnection.Controls.Add(this.lblUser);
            this.pnlConnection.Controls.Add(this.txtConnection);
            this.pnlConnection.Controls.Add(this.lblConnection);
            this.pnlConnection.Cursor = System.Windows.Forms.Cursors.Default;
            this.pnlConnection.ForeColor = System.Drawing.SystemColors.ControlText;
            this.pnlConnection.Location = new System.Drawing.Point(24, 64);
            this.pnlConnection.Name = "pnlConnection";
            this.pnlConnection.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.pnlConnection.Size = new System.Drawing.Size(432, 216);
            this.pnlConnection.TabIndex = 22;
            this.pnlConnection.TabStop = true;
            // 
            // cmdConnWizard
            // 
            this.cmdConnWizard.Location = new System.Drawing.Point(336, 14);
            this.cmdConnWizard.Name = "cmdConnWizard";
            this.cmdConnWizard.Size = new System.Drawing.Size(72, 24);
            this.cmdConnWizard.TabIndex = 1;
            this.cmdConnWizard.Text = "Wizard...";
            this.cmdConnWizard.Click += new System.EventHandler(this.cmdConnWizard_Click);
            // 
            // cmbLanguage
            // 
            this.cmbLanguage.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
            this.cmbLanguage.Location = new System.Drawing.Point(80, 176);
            this.cmbLanguage.Name = "cmbLanguage";
            this.cmbLanguage.Size = new System.Drawing.Size(248, 21);
            this.cmbLanguage.TabIndex = 6;
            // 
            // lblLanguage
            // 
            this.lblLanguage.BackColor = System.Drawing.SystemColors.Control;
            this.lblLanguage.Cursor = System.Windows.Forms.Cursors.Default;
            this.lblLanguage.ForeColor = System.Drawing.SystemColors.ControlText;
            this.lblLanguage.Location = new System.Drawing.Point(8, 180);
            this.lblLanguage.Name = "lblLanguage";
            this.lblLanguage.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.lblLanguage.Size = new System.Drawing.Size(56, 17);
            this.lblLanguage.TabIndex = 40;
            this.lblLanguage.Text = "Language";
            // 
            // txtProgram
            // 
            this.txtProgram.AcceptsReturn = true;
            this.txtProgram.AutoSize = false;
            this.txtProgram.BackColor = System.Drawing.SystemColors.Window;
            this.txtProgram.Cursor = System.Windows.Forms.Cursors.IBeam;
            this.txtProgram.ForeColor = System.Drawing.SystemColors.WindowText;
            this.txtProgram.Location = new System.Drawing.Point(80, 144);
            this.txtProgram.MaxLength = 16;
            this.txtProgram.Name = "txtProgram";
            this.txtProgram.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.txtProgram.Size = new System.Drawing.Size(248, 19);
            this.txtProgram.TabIndex = 5;
            this.txtProgram.Text = "";
            this.txtProgram.TextChanged += new System.EventHandler(this.txtProgram_TextChanged);
            // 
            // lblProgram
            // 
            this.lblProgram.BackColor = System.Drawing.SystemColors.Control;
            this.lblProgram.Cursor = System.Windows.Forms.Cursors.Default;
            this.lblProgram.ForeColor = System.Drawing.SystemColors.ControlText;
            this.lblProgram.Location = new System.Drawing.Point(8, 148);
            this.lblProgram.Name = "lblProgram";
            this.lblProgram.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.lblProgram.Size = new System.Drawing.Size(56, 17);
            this.lblProgram.TabIndex = 38;
            this.lblProgram.Text = "Program";
            // 
            // txtSystem
            // 
            this.txtSystem.AcceptsReturn = true;
            this.txtSystem.AutoSize = false;
            this.txtSystem.BackColor = System.Drawing.SystemColors.Window;
            this.txtSystem.Cursor = System.Windows.Forms.Cursors.IBeam;
            this.txtSystem.ForeColor = System.Drawing.SystemColors.WindowText;
            this.txtSystem.Location = new System.Drawing.Point(80, 112);
            this.txtSystem.MaxLength = 16;
            this.txtSystem.Name = "txtSystem";
            this.txtSystem.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.txtSystem.Size = new System.Drawing.Size(248, 19);
            this.txtSystem.TabIndex = 4;
            this.txtSystem.Text = "";
            this.txtSystem.TextChanged += new System.EventHandler(this.txtSystem_TextChanged);
            // 
            // lblSystem
            // 
            this.lblSystem.BackColor = System.Drawing.SystemColors.Control;
            this.lblSystem.Cursor = System.Windows.Forms.Cursors.Default;
            this.lblSystem.ForeColor = System.Drawing.SystemColors.ControlText;
            this.lblSystem.Location = new System.Drawing.Point(8, 116);
            this.lblSystem.Name = "lblSystem";
            this.lblSystem.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.lblSystem.Size = new System.Drawing.Size(56, 17);
            this.lblSystem.TabIndex = 36;
            this.lblSystem.Text = "System";
            // 
            // txtPassword
            // 
            this.txtPassword.AcceptsReturn = true;
            this.txtPassword.AutoSize = false;
            this.txtPassword.BackColor = System.Drawing.SystemColors.Window;
            this.txtPassword.Cursor = System.Windows.Forms.Cursors.IBeam;
            this.txtPassword.ForeColor = System.Drawing.SystemColors.WindowText;
            this.txtPassword.Location = new System.Drawing.Point(80, 80);
            this.txtPassword.MaxLength = 40;
            this.txtPassword.Name = "txtPassword";
            this.txtPassword.PasswordChar = '*';
            this.txtPassword.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.txtPassword.Size = new System.Drawing.Size(248, 19);
            this.txtPassword.TabIndex = 3;
            this.txtPassword.Text = "";
            // 
            // lblPassword
            // 
            this.lblPassword.BackColor = System.Drawing.SystemColors.Control;
            this.lblPassword.Cursor = System.Windows.Forms.Cursors.Default;
            this.lblPassword.ForeColor = System.Drawing.SystemColors.ControlText;
            this.lblPassword.Location = new System.Drawing.Point(8, 84);
            this.lblPassword.Name = "lblPassword";
            this.lblPassword.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.lblPassword.Size = new System.Drawing.Size(56, 17);
            this.lblPassword.TabIndex = 34;
            this.lblPassword.Text = "Password";
            // 
            // txtUser
            // 
            this.txtUser.AcceptsReturn = true;
            this.txtUser.AutoSize = false;
            this.txtUser.BackColor = System.Drawing.SystemColors.Window;
            this.txtUser.Cursor = System.Windows.Forms.Cursors.IBeam;
            this.txtUser.ForeColor = System.Drawing.SystemColors.WindowText;
            this.txtUser.Location = new System.Drawing.Point(80, 48);
            this.txtUser.MaxLength = 16;
            this.txtUser.Name = "txtUser";
            this.txtUser.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.txtUser.Size = new System.Drawing.Size(248, 19);
            this.txtUser.TabIndex = 2;
            this.txtUser.Text = "";
            this.txtUser.TextChanged += new System.EventHandler(this.txtUser_TextChanged);
            // 
            // lblUser
            // 
            this.lblUser.BackColor = System.Drawing.SystemColors.Control;
            this.lblUser.Cursor = System.Windows.Forms.Cursors.Default;
            this.lblUser.ForeColor = System.Drawing.SystemColors.ControlText;
            this.lblUser.Location = new System.Drawing.Point(8, 52);
            this.lblUser.Name = "lblUser";
            this.lblUser.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.lblUser.Size = new System.Drawing.Size(56, 17);
            this.lblUser.TabIndex = 32;
            this.lblUser.Text = "User";
            // 
            // txtConnection
            // 
            this.txtConnection.AcceptsReturn = true;
            this.txtConnection.AutoSize = false;
            this.txtConnection.BackColor = System.Drawing.SystemColors.Window;
            this.txtConnection.Cursor = System.Windows.Forms.Cursors.IBeam;
            this.txtConnection.ForeColor = System.Drawing.SystemColors.WindowText;
            this.txtConnection.Location = new System.Drawing.Point(82, 16);
            this.txtConnection.MaxLength = 16;
            this.txtConnection.Name = "txtConnection";
            this.txtConnection.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.txtConnection.Size = new System.Drawing.Size(246, 19);
            this.txtConnection.TabIndex = 0;
            this.txtConnection.Text = "";
            this.txtConnection.TextChanged += new System.EventHandler(this.txtConnection_TextChanged);
            // 
            // lblConnection
            // 
            this.lblConnection.BackColor = System.Drawing.SystemColors.Control;
            this.lblConnection.Cursor = System.Windows.Forms.Cursors.Default;
            this.lblConnection.ForeColor = System.Drawing.SystemColors.ControlText;
            this.lblConnection.Location = new System.Drawing.Point(8, 20);
            this.lblConnection.Name = "lblConnection";
            this.lblConnection.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.lblConnection.Size = new System.Drawing.Size(64, 17);
            this.lblConnection.TabIndex = 30;
            this.lblConnection.Text = "Connection";
            // 
            // pnlStep0
            // 
            this.pnlStep0.BackColor = System.Drawing.Color.White;
            this.pnlStep0.Controls.Add(this.imgStep0);
            this.pnlStep0.Controls.Add(this.lblHeader0);
            this.pnlStep0.Cursor = System.Windows.Forms.Cursors.Default;
            this.pnlStep0.ForeColor = System.Drawing.SystemColors.ControlText;
            this.pnlStep0.Location = new System.Drawing.Point(0, 0);
            this.pnlStep0.Name = "pnlStep0";
            this.pnlStep0.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.pnlStep0.Size = new System.Drawing.Size(484, 334);
            this.pnlStep0.TabIndex = 5;
            this.pnlStep0.Tag = "1000";
            this.pnlStep0.Text = "Introduction Screen";
            // 
            // imgStep0
            // 
            this.imgStep0.BorderStyle = System.Windows.Forms.BorderStyle.Fixed3D;
            this.imgStep0.Cursor = System.Windows.Forms.Cursors.Default;
            this.imgStep0.Image = ((System.Drawing.Image)(resources.GetObject("imgStep0.Image")));
            this.imgStep0.Location = new System.Drawing.Point(0, 0);
            this.imgStep0.Name = "imgStep0";
            this.imgStep0.Size = new System.Drawing.Size(144, 334);
            this.imgStep0.SizeMode = System.Windows.Forms.PictureBoxSizeMode.StretchImage;
            this.imgStep0.TabIndex = 15;
            this.imgStep0.TabStop = false;
            // 
            // lblHeader0
            // 
            this.lblHeader0.Font = new System.Drawing.Font("Times New Roman", 12.75F, System.Drawing.FontStyle.Bold);
            this.lblHeader0.Location = new System.Drawing.Point(160, 32);
            this.lblHeader0.Name = "lblHeader0";
            this.lblHeader0.Size = new System.Drawing.Size(312, 88);
            this.lblHeader0.TabIndex = 14;
            this.lblHeader0.Text = "Welcome to Rep++ Windows Application Wizard.";
            // 
            // pnlStep2
            // 
            this.pnlStep2.BackColor = System.Drawing.SystemColors.Control;
            this.pnlStep2.Controls.Add(this.grpUseSB);
            this.pnlStep2.Controls.Add(this.grpToolbarSize);
            this.pnlStep2.Controls.Add(this.pnlHeader2);
            this.pnlStep2.Controls.Add(this.fraGenerate);
            this.pnlStep2.Controls.Add(this.cboCards);
            this.pnlStep2.Controls.Add(this.lblCardGroup);
            this.pnlStep2.Cursor = System.Windows.Forms.Cursors.Default;
            this.pnlStep2.ForeColor = System.Drawing.SystemColors.ControlText;
            this.pnlStep2.Location = new System.Drawing.Point(0, 0);
            this.pnlStep2.Name = "pnlStep2";
            this.pnlStep2.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.pnlStep2.Size = new System.Drawing.Size(484, 334);
            this.pnlStep2.TabIndex = 7;
            this.pnlStep2.Tag = "2000";
            this.pnlStep2.Text = "Step 1";
            // 
            // grpUseSB
            // 
            this.grpUseSB.Controls.Add(this.chkUseDNetBar);
            this.grpUseSB.Controls.Add(this.chkUseSB);
            this.grpUseSB.Controls.Add(this.cboSBCards);
            this.grpUseSB.Controls.Add(this.lblSBCardName);
            this.grpUseSB.Location = new System.Drawing.Point(16, 200);
            this.grpUseSB.Name = "grpUseSB";
            this.grpUseSB.Size = new System.Drawing.Size(416, 96);
            this.grpUseSB.TabIndex = 22;
            this.grpUseSB.TabStop = false;
            // 
            // chkUseDNetBar
            // 
            this.chkUseDNetBar.Location = new System.Drawing.Point(24, 64);
            this.chkUseDNetBar.Name = "chkUseDNetBar";
            this.chkUseDNetBar.Size = new System.Drawing.Size(192, 24);
            this.chkUseDNetBar.TabIndex = 25;
            this.chkUseDNetBar.Text = "Use .Net Bar Components";
            // 
            // chkUseSB
            // 
            this.chkUseSB.Location = new System.Drawing.Point(10, 0);
            this.chkUseSB.Name = "chkUseSB";
            this.chkUseSB.Size = new System.Drawing.Size(128, 16);
            this.chkUseSB.TabIndex = 24;
            this.chkUseSB.Text = "Use Selection Buffer";
            this.chkUseSB.CheckedChanged += new System.EventHandler(this.chkUseSB_CheckedChanged);
            // 
            // cboSBCards
            // 
            this.cboSBCards.BackColor = System.Drawing.SystemColors.Window;
            this.cboSBCards.Cursor = System.Windows.Forms.Cursors.Default;
            this.cboSBCards.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
            this.cboSBCards.ForeColor = System.Drawing.SystemColors.WindowText;
            this.cboSBCards.Location = new System.Drawing.Point(112, 24);
            this.cboSBCards.Name = "cboSBCards";
            this.cboSBCards.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.cboSBCards.Size = new System.Drawing.Size(256, 21);
            this.cboSBCards.Sorted = true;
            this.cboSBCards.TabIndex = 22;
            this.cboSBCards.SelectedIndexChanged += new System.EventHandler(this.cboSBCards_SelectedIndexChanged);
            // 
            // lblSBCardName
            // 
            this.lblSBCardName.BackColor = System.Drawing.SystemColors.Control;
            this.lblSBCardName.Cursor = System.Windows.Forms.Cursors.Default;
            this.lblSBCardName.ForeColor = System.Drawing.SystemColors.ControlText;
            this.lblSBCardName.Location = new System.Drawing.Point(16, 24);
            this.lblSBCardName.Name = "lblSBCardName";
            this.lblSBCardName.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.lblSBCardName.Size = new System.Drawing.Size(88, 24);
            this.lblSBCardName.TabIndex = 23;
            this.lblSBCardName.Text = "Selection Buffer Card Name";
            // 
            // grpToolbarSize
            // 
            this.grpToolbarSize.Controls.Add(this.optLarge);
            this.grpToolbarSize.Controls.Add(this.optSmall);
            this.grpToolbarSize.Location = new System.Drawing.Point(312, 72);
            this.grpToolbarSize.Name = "grpToolbarSize";
            this.grpToolbarSize.Size = new System.Drawing.Size(120, 80);
            this.grpToolbarSize.TabIndex = 19;
            this.grpToolbarSize.TabStop = false;
            this.grpToolbarSize.Text = "Toolbar Size";
            // 
            // optLarge
            // 
            this.optLarge.Location = new System.Drawing.Point(24, 48);
            this.optLarge.Name = "optLarge";
            this.optLarge.Size = new System.Drawing.Size(88, 16);
            this.optLarge.TabIndex = 1;
            this.optLarge.Text = "Large";
            // 
            // optSmall
            // 
            this.optSmall.Location = new System.Drawing.Point(24, 24);
            this.optSmall.Name = "optSmall";
            this.optSmall.Size = new System.Drawing.Size(80, 16);
            this.optSmall.TabIndex = 0;
            this.optSmall.Text = "Small";
            // 
            // pnlHeader2
            // 
            this.pnlHeader2.BackColor = System.Drawing.SystemColors.Window;
            this.pnlHeader2.Controls.Add(this.Label2);
            this.pnlHeader2.Controls.Add(this.Label3);
            this.pnlHeader2.Location = new System.Drawing.Point(0, 0);
            this.pnlHeader2.Name = "pnlHeader2";
            this.pnlHeader2.Size = new System.Drawing.Size(478, 56);
            this.pnlHeader2.TabIndex = 18;
            // 
            // Label2
            // 
            this.Label2.Font = new System.Drawing.Font("Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
            this.Label2.Location = new System.Drawing.Point(16, 4);
            this.Label2.Name = "Label2";
            this.Label2.Size = new System.Drawing.Size(272, 16);
            this.Label2.TabIndex = 19;
            this.Label2.Text = "Choose Application or Form Type";
            // 
            // Label3
            // 
            this.Label3.BackColor = System.Drawing.Color.Transparent;
            this.Label3.Cursor = System.Windows.Forms.Cursors.Default;
            this.Label3.ForeColor = System.Drawing.SystemColors.WindowText;
            this.Label3.Location = new System.Drawing.Point(24, 22);
            this.Label3.Name = "Label3";
            this.Label3.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.Label3.Size = new System.Drawing.Size(384, 30);
            this.Label3.TabIndex = 18;
            this.Label3.Tag = "2001";
            this.Label3.Text = "For an application, choose its type and the corresponding card. For a form, choos" +
                "e its type and the corresponding card or group.";
            // 
            // fraGenerate
            // 
            this.fraGenerate.BackColor = System.Drawing.SystemColors.Control;
            this.fraGenerate.Controls.Add(this.optGroupForm);
            this.fraGenerate.Controls.Add(this.optGenerate2T);
            this.fraGenerate.Controls.Add(this.optGenerate3T);
            this.fraGenerate.Controls.Add(this.optCardForm);
            this.fraGenerate.ForeColor = System.Drawing.SystemColors.ControlText;
            this.fraGenerate.Location = new System.Drawing.Point(16, 72);
            this.fraGenerate.Name = "fraGenerate";
            this.fraGenerate.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.fraGenerate.Size = new System.Drawing.Size(280, 80);
            this.fraGenerate.TabIndex = 0;
            this.fraGenerate.TabStop = false;
            this.fraGenerate.Text = "Application or Form Type";
            // 
            // optGroupForm
            // 
            this.optGroupForm.BackColor = System.Drawing.SystemColors.Control;
            this.optGroupForm.Cursor = System.Windows.Forms.Cursors.Default;
            this.optGroupForm.ForeColor = System.Drawing.SystemColors.ControlText;
            this.optGroupForm.Location = new System.Drawing.Point(176, 48);
            this.optGroupForm.Name = "optGroupForm";
            this.optGroupForm.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.optGroupForm.Size = new System.Drawing.Size(88, 17);
            this.optGroupForm.TabIndex = 19;
            this.optGroupForm.TabStop = true;
            this.optGroupForm.Text = "Group form";
            this.optGroupForm.CheckedChanged += new System.EventHandler(this.optGroupForm_CheckedChanged);
            // 
            // optGenerate2T
            // 
            this.optGenerate2T.BackColor = System.Drawing.SystemColors.Control;
            this.optGenerate2T.Cursor = System.Windows.Forms.Cursors.Default;
            this.optGenerate2T.ForeColor = System.Drawing.SystemColors.ControlText;
            this.optGenerate2T.Location = new System.Drawing.Point(24, 24);
            this.optGenerate2T.Name = "optGenerate2T";
            this.optGenerate2T.Size = new System.Drawing.Size(120, 17);
            this.optGenerate2T.TabIndex = 0;
            this.optGenerate2T.TabStop = true;
            this.optGenerate2T.Text = "2 Tiers application";
            this.optGenerate2T.CheckedChanged += new System.EventHandler(this.optGenerate2T_CheckedChanged);
            // 
            // optGenerate3T
            // 
            this.optGenerate3T.BackColor = System.Drawing.SystemColors.Control;
            this.optGenerate3T.Cursor = System.Windows.Forms.Cursors.Default;
            this.optGenerate3T.Enabled = false;
            this.optGenerate3T.ForeColor = System.Drawing.SystemColors.ControlText;
            this.optGenerate3T.Location = new System.Drawing.Point(24, 48);
            this.optGenerate3T.Name = "optGenerate3T";
            this.optGenerate3T.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.optGenerate3T.Size = new System.Drawing.Size(120, 17);
            this.optGenerate3T.TabIndex = 17;
            this.optGenerate3T.TabStop = true;
            this.optGenerate3T.Text = "3 Tiers application";
            this.optGenerate3T.CheckedChanged += new System.EventHandler(this.optGenerate3T_CheckedChanged);
            // 
            // optCardForm
            // 
            this.optCardForm.BackColor = System.Drawing.SystemColors.Control;
            this.optCardForm.Cursor = System.Windows.Forms.Cursors.Default;
            this.optCardForm.ForeColor = System.Drawing.SystemColors.ControlText;
            this.optCardForm.Location = new System.Drawing.Point(176, 24);
            this.optCardForm.Name = "optCardForm";
            this.optCardForm.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.optCardForm.Size = new System.Drawing.Size(88, 17);
            this.optCardForm.TabIndex = 18;
            this.optCardForm.TabStop = true;
            this.optCardForm.Text = "Card form";
            this.optCardForm.CheckedChanged += new System.EventHandler(this.optCardForm_CheckedChanged);
            // 
            // cboCards
            // 
            this.cboCards.BackColor = System.Drawing.SystemColors.Window;
            this.cboCards.Cursor = System.Windows.Forms.Cursors.Default;
            this.cboCards.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
            this.cboCards.ForeColor = System.Drawing.SystemColors.WindowText;
            this.cboCards.Location = new System.Drawing.Point(128, 168);
            this.cboCards.Name = "cboCards";
            this.cboCards.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.cboCards.Size = new System.Drawing.Size(256, 21);
            this.cboCards.Sorted = true;
            this.cboCards.TabIndex = 1;
            this.cboCards.SelectedIndexChanged += new System.EventHandler(this.cboCards_SelectedIndexChanged);
            // 
            // lblCardGroup
            // 
            this.lblCardGroup.BackColor = System.Drawing.SystemColors.Control;
            this.lblCardGroup.Cursor = System.Windows.Forms.Cursors.Default;
            this.lblCardGroup.ForeColor = System.Drawing.SystemColors.ControlText;
            this.lblCardGroup.Location = new System.Drawing.Point(16, 168);
            this.lblCardGroup.Name = "lblCardGroup";
            this.lblCardGroup.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.lblCardGroup.Size = new System.Drawing.Size(72, 17);
            this.lblCardGroup.TabIndex = 14;
            this.lblCardGroup.Text = "Card Name";
            // 
            // pnlStep5
            // 
            this.pnlStep5.BackColor = System.Drawing.SystemColors.Control;
            this.pnlStep5.Controls.Add(this.txtSummary);
            this.pnlStep5.Controls.Add(this.lblStatus);
            this.pnlStep5.Controls.Add(this.pnlHeader5);
            this.pnlStep5.Cursor = System.Windows.Forms.Cursors.Default;
            this.pnlStep5.ForeColor = System.Drawing.SystemColors.ControlText;
            this.pnlStep5.Location = new System.Drawing.Point(0, 0);
            this.pnlStep5.Name = "pnlStep5";
            this.pnlStep5.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.pnlStep5.Size = new System.Drawing.Size(484, 334);
            this.pnlStep5.TabIndex = 9;
            this.pnlStep5.Tag = "3000";
            this.pnlStep5.Text = "Finished!";
            // 
            // txtSummary
            // 
            this.txtSummary.Location = new System.Drawing.Point(24, 104);
            this.txtSummary.Multiline = true;
            this.txtSummary.Name = "txtSummary";
            this.txtSummary.ReadOnly = true;
            this.txtSummary.ScrollBars = System.Windows.Forms.ScrollBars.Both;
            this.txtSummary.Size = new System.Drawing.Size(432, 200);
            this.txtSummary.TabIndex = 18;
            this.txtSummary.Text = "";
            // 
            // lblStatus
            // 
            this.lblStatus.Location = new System.Drawing.Point(24, 80);
            this.lblStatus.Name = "lblStatus";
            this.lblStatus.Size = new System.Drawing.Size(264, 16);
            this.lblStatus.TabIndex = 17;
            this.lblStatus.Text = "The Wizard will generate the follwing items:";
            // 
            // pnlHeader5
            // 
            this.pnlHeader5.BackColor = System.Drawing.SystemColors.Window;
            this.pnlHeader5.Controls.Add(this.lblHeader5);
            this.pnlHeader5.Controls.Add(this.lblStep5);
            this.pnlHeader5.Location = new System.Drawing.Point(0, 0);
            this.pnlHeader5.Name = "pnlHeader5";
            this.pnlHeader5.Size = new System.Drawing.Size(478, 56);
            this.pnlHeader5.TabIndex = 15;
            // 
            // lblHeader5
            // 
            this.lblHeader5.Font = new System.Drawing.Font("Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
            this.lblHeader5.Location = new System.Drawing.Point(16, 4);
            this.lblHeader5.Name = "lblHeader5";
            this.lblHeader5.Size = new System.Drawing.Size(216, 16);
            this.lblHeader5.TabIndex = 16;
            this.lblHeader5.Text = "Generate Application or Form";
            // 
            // lblStep5
            // 
            this.lblStep5.BackColor = System.Drawing.Color.Transparent;
            this.lblStep5.Cursor = System.Windows.Forms.Cursors.Default;
            this.lblStep5.ForeColor = System.Drawing.SystemColors.WindowText;
            this.lblStep5.Location = new System.Drawing.Point(24, 22);
            this.lblStep5.Name = "lblStep5";
            this.lblStep5.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.lblStep5.Size = new System.Drawing.Size(400, 30);
            this.lblStep5.TabIndex = 15;
            this.lblStep5.Tag = "3001";
            this.lblStep5.Text = "The Rep++ Application Wizard has finished collecting information. To generate you" +
                "r application or form, press the Finish button.";
            // 
            // pnlStepTypedInst
            // 
            this.pnlStepTypedInst.BackColor = System.Drawing.SystemColors.Control;
            this.pnlStepTypedInst.Controls.Add(this.pnlTypedInst);
            this.pnlStepTypedInst.Controls.Add(this.panel4);
            this.pnlStepTypedInst.Cursor = System.Windows.Forms.Cursors.Default;
            this.pnlStepTypedInst.ForeColor = System.Drawing.SystemColors.ControlText;
            this.pnlStepTypedInst.Location = new System.Drawing.Point(-4, 0);
            this.pnlStepTypedInst.Name = "pnlStepTypedInst";
            this.pnlStepTypedInst.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.pnlStepTypedInst.Size = new System.Drawing.Size(484, 336);
            this.pnlStepTypedInst.TabIndex = 33;
            this.pnlStepTypedInst.Tag = "2000";
            this.pnlStepTypedInst.Text = "Step 1";
            // 
            // pnlTypedInst
            // 
            this.pnlTypedInst.Location = new System.Drawing.Point(8, 56);
            this.pnlTypedInst.Name = "pnlTypedInst";
            this.pnlTypedInst.Size = new System.Drawing.Size(472, 280);
            this.pnlTypedInst.TabIndex = 19;
            // 
            // panel4
            // 
            this.panel4.BackColor = System.Drawing.SystemColors.Window;
            this.panel4.Controls.Add(this.label7);
            this.panel4.Controls.Add(this.label8);
            this.panel4.Location = new System.Drawing.Point(0, 0);
            this.panel4.Name = "panel4";
            this.panel4.Size = new System.Drawing.Size(478, 56);
            this.panel4.TabIndex = 18;
            // 
            // label7
            // 
            this.label7.Location = new System.Drawing.Point(16, 4);
            this.label7.Name = "label7";
            this.label7.Size = new System.Drawing.Size(272, 16);
            this.label7.TabIndex = 19;
            this.label7.Text = "Choose Typed Instances Generation  Parameters";
            // 
            // label8
            // 
            this.label8.BackColor = System.Drawing.Color.Transparent;
            this.label8.Cursor = System.Windows.Forms.Cursors.Default;
            this.label8.ForeColor = System.Drawing.SystemColors.WindowText;
            this.label8.Location = new System.Drawing.Point(24, 22);
            this.label8.Name = "label8";
            this.label8.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.label8.Size = new System.Drawing.Size(384, 30);
            this.label8.TabIndex = 18;
            this.label8.Tag = "2001";
            // 
            // cmdFinish
            // 
            this.cmdFinish.BackColor = System.Drawing.SystemColors.Control;
            this.cmdFinish.Cursor = System.Windows.Forms.Cursors.Default;
            this.cmdFinish.ForeColor = System.Drawing.SystemColors.ControlText;
            this.cmdFinish.Location = new System.Drawing.Point(394, 10);
            this.cmdFinish.Name = "cmdFinish";
            this.cmdFinish.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.cmdFinish.Size = new System.Drawing.Size(73, 23);
            this.cmdFinish.TabIndex = 4;
            this.cmdFinish.Tag = "104";
            this.cmdFinish.Text = "&Cancel";
            this.cmdFinish.Click += new System.EventHandler(this.cmdFinish_Click);
            // 
            // cmdNext
            // 
            this.cmdNext.BackColor = System.Drawing.SystemColors.Control;
            this.cmdNext.Cursor = System.Windows.Forms.Cursors.Default;
            this.cmdNext.ForeColor = System.Drawing.SystemColors.ControlText;
            this.cmdNext.Location = new System.Drawing.Point(308, 10);
            this.cmdNext.Name = "cmdNext";
            this.cmdNext.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.cmdNext.Size = new System.Drawing.Size(73, 23);
            this.cmdNext.TabIndex = 3;
            this.cmdNext.Tag = "103";
            this.cmdNext.Text = "&Next >";
            this.cmdNext.Click += new System.EventHandler(this.cmdNext_Click);
            // 
            // cmdBack
            // 
            this.cmdBack.BackColor = System.Drawing.SystemColors.Control;
            this.cmdBack.Cursor = System.Windows.Forms.Cursors.Default;
            this.cmdBack.ForeColor = System.Drawing.SystemColors.ControlText;
            this.cmdBack.Location = new System.Drawing.Point(234, 10);
            this.cmdBack.Name = "cmdBack";
            this.cmdBack.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.cmdBack.Size = new System.Drawing.Size(73, 23);
            this.cmdBack.TabIndex = 2;
            this.cmdBack.Tag = "102";
            this.cmdBack.Text = "< &Back";
            this.cmdBack.Click += new System.EventHandler(this.cmdBack_Click);
            // 
            // _Line1_1
            // 
            this._Line1_1.BackColor = System.Drawing.Color.FromArgb(((System.Byte)(128)), ((System.Byte)(128)), ((System.Byte)(128)));
            this._Line1_1.ForeColor = System.Drawing.SystemColors.WindowText;
            this._Line1_1.Location = new System.Drawing.Point(0, 0);
            this._Line1_1.Name = "_Line1_1";
            this._Line1_1.Size = new System.Drawing.Size(476, 1);
            this._Line1_1.TabIndex = 5;
            // 
            // _Line1_0
            // 
            this._Line1_0.BackColor = System.Drawing.Color.White;
            this._Line1_0.Font = new System.Drawing.Font("Arial", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
            this._Line1_0.ForeColor = System.Drawing.SystemColors.WindowText;
            this._Line1_0.Location = new System.Drawing.Point(0, 2);
            this._Line1_0.Name = "_Line1_0";
            this._Line1_0.Size = new System.Drawing.Size(476, 1);
            this._Line1_0.TabIndex = 6;
            // 
            // picNav
            // 
            this.picNav.BackColor = System.Drawing.SystemColors.Control;
            this.picNav.Controls.Add(this._Line1_1);
            this.picNav.Controls.Add(this.cmdFinish);
            this.picNav.Controls.Add(this.cmdNext);
            this.picNav.Controls.Add(this.cmdBack);
            this.picNav.Controls.Add(this._Line1_0);
            this.picNav.Cursor = System.Windows.Forms.Cursors.Default;
            this.picNav.Dock = System.Windows.Forms.DockStyle.Bottom;
            this.picNav.ForeColor = System.Drawing.SystemColors.WindowText;
            this.picNav.Location = new System.Drawing.Point(0, 336);
            this.picNav.Name = "picNav";
            this.picNav.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.picNav.Size = new System.Drawing.Size(477, 40);
            this.picNav.TabIndex = 0;
            this.picNav.TabStop = true;
            // 
            // frmMain
            // 
            this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
            this.ClientSize = new System.Drawing.Size(477, 376);
            this.Controls.Add(this.pnlStep2);
            this.Controls.Add(this.pnlStep3);
            this.Controls.Add(this.pnlStep0);
            this.Controls.Add(this.pnlStep5);
            this.Controls.Add(this.pnlStep4);
            this.Controls.Add(this.pnlStep1);
            this.Controls.Add(this.pnlStepTypedInst);
            this.Controls.Add(this.picNav);
            this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedSingle;
            this.KeyPreview = true;
            this.Location = new System.Drawing.Point(131, 121);
            this.MaximizeBox = false;
            this.MinimizeBox = false;
            this.Name = "frmMain";
            this.StartPosition = System.Windows.Forms.FormStartPosition.CenterScreen;
            this.Tag = "10";
            this.Text = "Rep++Windows Application Wizard";
            this.Load += new System.EventHandler(this.frmWizard_Load);
            this.pnlStep4.ResumeLayout(false);
            this.Panel2.ResumeLayout(false);
            this.fraFmtFormLayout.ResumeLayout(false);
            this.pnlStep3.ResumeLayout(false);
            this.pnlHeader3.ResumeLayout(false);
            this.Picture1.ResumeLayout(false);
            this.fraFrmLayout.ResumeLayout(false);
            this.fraChildLocation.ResumeLayout(false);
            this.pnlStep1.ResumeLayout(false);
            this.pnlHeader1.ResumeLayout(false);
            this.pnlConnection.ResumeLayout(false);
            this.pnlStep0.ResumeLayout(false);
            this.pnlStep2.ResumeLayout(false);
            this.grpUseSB.ResumeLayout(false);
            this.grpToolbarSize.ResumeLayout(false);
            this.pnlHeader2.ResumeLayout(false);
            this.fraGenerate.ResumeLayout(false);
            this.pnlStep5.ResumeLayout(false);
            this.pnlHeader5.ResumeLayout(false);
            this.pnlStepTypedInst.ResumeLayout(false);
            this.panel4.ResumeLayout(false);
            this.picNav.ResumeLayout(false);
            this.ResumeLayout(false);

        }
    }
}
